Package: EvaluateCore
Title: Quality Evaluation of Core Collections
Version: 0.1.5
Authors@R: c(
    person(given = "J.", family = "Aravind",
           email = "j.aravind@icar.org.in",
           role = c("aut", "cre"),
		       comment = c(ORCID = "0000-0002-4791-442X")),
    person(given = "Vikender", family = "Kaur",
           email = "vikender.kaur@icar.org.in",
		       role = "aut",
		       comment = c(ORCID = "0000-0001-9698-7329")),
	  person(given = c("Dhammaprakash", "Pandhari"), family = "Wankhede", 
           email = "d.wankhede@icar.org.in",
		       role = "aut",
		       comment = c(ORCID = "0000-0001-6384-8664")),
	  person(given = "Joghee", family = "Nanjundan", 
           email = "j.nanjundan@icar.org.in",
		       role = "aut",
		       comment = c(ORCID = "0000-0001-6254-7341")),
    person("ICAR-NBGPR",
           role = c("cph"),
		       comment = c(url = "https://nbpgr.org.in/")))
Description: Implements various quality evaluation statistics to assess the
    value of plant germplasm core collections using qualitative and 
    quantitative phenotypic trait data according to Odong et al. (2015) 
    <doi:10.1007/s00122-012-1971-y>.
Copyright: 2018-2026, ICAR-NBPGR
License: GPL-2 | GPL-3
Encoding: UTF-8
RoxygenNote: 7.3.3
URL: https://github.com/aravind-j/EvaluateCore
        https://CRAN.R-project.org/package=EvaluateCore
        https://aravind-j.github.io/EvaluateCore/
        https://doi.org/10.5281/zenodo.3875930
BugReports: https://github.com/aravind-j/EvaluateCore/issues
RdMacros: mathjaxr, Rdpack
Depends: R (>= 3.5.0)
Imports: agricolae, boot, car, cluster, dplyr, entropy, ggcorrplot,
        ggplot2, ggtext, grDevices, gridExtra, kSamples, mathjaxr,
        missMDA, psych, reshape2, Rdpack, stats, tibble, vegan
Suggests: corehunter, httr, pander, RCurl, rJava (>= 0.9-8), XML
LazyData: true
NeedsCompilation: no
Packaged: 2026-04-21 10:52:05 UTC; Aravind-DGC
Author: J. Aravind [aut, cre] (ORCID: <https://orcid.org/0000-0002-4791-442X>),
  Vikender Kaur [aut] (ORCID: <https://orcid.org/0000-0001-9698-7329>),
  Dhammaprakash Pandhari Wankhede [aut] (ORCID:
    <https://orcid.org/0000-0001-6384-8664>),
  Joghee Nanjundan [aut] (ORCID: <https://orcid.org/0000-0001-6254-7341>),
  ICAR-NBGPR [cph] (url: https://nbpgr.org.in/)
Maintainer: J. Aravind <j.aravind@icar.org.in>
Repository: CRAN
Date/Publication: 2026-04-22 07:20:09 UTC
Built: R 4.5.2; ; 2026-04-22 10:05:07 UTC; unix

# Generated by roxygen2: do not edit by hand

export(bar.evaluate.core)
export(box.evaluate.core)
export(chisquare.evaluate.core)
export(corr.evaluate.core)
export(coverage.evaluate.core)
export(cr.evaluate.core)
export(dist.evaluate.core)
export(diversity.evaluate.core)
export(freqdist.evaluate.core)
export(iqr.evaluate.core)
export(levene.evaluate.core)
export(pca.evaluate.core)
export(pdfdist.evaluate.core)
export(percentdiff.evaluate.core)
export(qq.evaluate.core)
export(rpr.evaluate.core)
export(scv.evaluate.core)
export(shannon.evaluate.core)
export(signtest.evaluate.core)
export(snk.evaluate.core)
export(ttest.evaluate.core)
export(vpf.evaluate.core)
export(vr.evaluate.core)
export(wilcox.evaluate.core)
import(ggcorrplot)
import(ggplot2)
import(ggtext)
import(mathjaxr)
importFrom(Rdpack,reprompt)
importFrom(agricolae,SNK.test)
importFrom(boot,boot)
importFrom(car,leveneTest)
importFrom(cluster,daisy)
importFrom(dplyr,bind_rows)
importFrom(dplyr,n)
importFrom(dplyr,summarise)
importFrom(entropy,KL.plugin)
importFrom(entropy,discretize)
importFrom(grDevices,col2rgb)
importFrom(grDevices,nclass.FD)
importFrom(grDevices,nclass.Sturges)
importFrom(grDevices,nclass.scott)
importFrom(gridExtra,grid.arrange)
importFrom(kSamples,ad.test)
importFrom(missMDA,imputePCA)
importFrom(psych,shannon)
importFrom(reshape2,melt)
importFrom(stats,IQR)
importFrom(stats,aov)
importFrom(stats,chisq.test)
importFrom(stats,cor)
importFrom(stats,dnorm)
importFrom(stats,formula)
importFrom(stats,ks.test)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,pchisq)
importFrom(stats,prcomp)
importFrom(stats,pt)
importFrom(stats,qqplot)
importFrom(stats,sd)
importFrom(stats,t.test)
importFrom(stats,var)
importFrom(stats,wilcox.test)
importFrom(tibble,as_tibble)
importFrom(tibble,deframe)
importFrom(vegan,mantel)

<!-- 
<img src="https://raw.githubusercontent.com/aravind-j/EvaluateCore/master/inst/extdata/EvaluateCore.png" alt="" width="20%" />
-->

## `EvaluateCore`: Quality Evaluation of Core Collections <img src="https://raw.githubusercontent.com/aravind-j/EvaluateCore/master/inst/extdata/EvaluateCore.png" align="right" alt="logo" width="173" height = "200" style = "border: none; float: right;">

###### Version : [0.1.5](https://aravind-j.github.io/EvaluateCore/); Copyright (C) 2018-2026: [ICAR-NBPGR](https://nbpgr.org.in/); License: [GPL-2\|GPL-3](https://www.r-project.org/Licenses/)

##### *Aravind, J.<sup>1</sup>, Kaur, V.<sup>2</sup>, Wankhede, D. P.<sup>3</sup> and Nanjundan, J.<sup>4</sup>*

1.  Division of Germplasm Conservation, ICAR-National Bureau of Plant
    Genetic Resources, New Delhi.
2.  Division of Germplasm Evaluation, ICAR-National Bureau of Plant
    Genetic Resources, New Delhi.
3.  Division of Genomic Resources, ICAR-National Bureau of Plant Genetic
    Resources, New Delhi.
4.  ICAR-Indian Agricultural Research Institute, Regional Station,
    Wellington, Tamil Nadu.

------------------------------------------------------------------------

[![minimal R
version](https://img.shields.io/badge/R%3E%3D-3.5.0-6666ff.svg?logo=R)](https://cran.r-project.org/)
[![License: GPL
v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version-last-release/EvaluateCore)](https://cran.r-project.org/package=EvaluateCore)
[![Dependencies](https://tinyverse.netlify.app/status/EvaluateCore)](https://cran.r-project.org/package=EvaluateCore)
[![rstudio mirror
downloads](https://cranlogs.r-pkg.org/badges/grand-total/EvaluateCore?color=green)](https://CRAN.R-project.org/package=EvaluateCore)
[![develVersion](https://img.shields.io/badge/devel%20version-0.1.5-orange.svg)](https://github.com/aravind-j/EvaluateCore)
[![Github Code
Size](https://img.shields.io/github/languages/code-size/aravind-j/EvaluateCore.svg)](https://github.com/aravind-j/EvaluateCore)
[![R-CMD-check](https://github.com/aravind-j/EvaluateCore/workflows/R-CMD-check/badge.svg)](https://github.com/aravind-j/EvaluateCore/actions)
[![Project Status:
WIP](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![lifecycle](https://img.shields.io/badge/lifecycle-stable-brightgreen.svg)](https://lifecycle.r-lib.org/articles/stages.html#stable)
[![Last-changedate](https://img.shields.io/badge/last%20change-2026--04--17-yellowgreen.svg)](https://github.com/aravind-j/EvaluateCore/)
[![Zenodo
DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3875930.svg)](https://doi.org/10.5281/zenodo.3875930)
[![Website -
pkgdown](https://img.shields.io/website-up-down-green-red/https/aravind-j.github.io/EvaluateCore.svg)](https://aravind-j.github.io/EvaluateCore/)
<!-- [![.](https://pro-pulsar-193905.appspot.com/UA-148941781-1/welcome-page)](https://github.com/aravind-j/google-analytics-beacon) -->
[![GoatCounter](https://evaluatecore-gh.goatcounter.com/count?p=/test)](https://evaluatecore-gh.goatcounter.com/)
<!-- [![packageversion](https://img.shields.io/badge/Package%20version-0.2.3.3-orange.svg)](https://github.com/aravind-j/EvaluateCore) -->
<!-- [![GitHub Download Count](https://github-basic-badges.herokuapp.com/downloads/aravind-j/EvaluateCore/total.svg)] -->
<!-- [![Rdoc](http://www.rdocumentation.org/badges/version/EvaluateCore)](http://www.rdocumentation.org/packages/EvaluateCore) -->

------------------------------------------------------------------------

## Description

Implements various quality evaluation statistics to assess the value of
plant germplasm core collections using qualitative and quantitative
phenotypic trait data according to Odong et al. (2015)
[doi:10.1007/s00122-012-1971-y](https://doi.org/10.1007/s00122-012-1971-y).

<!-- ## System Requirements
The function `dist.evaluate.core` is a wrapper around the `evaluateCore` function of the `corehunter` package which implemented in Java 8. Hence you need to have [Java Runtime Environment](http://www.oracle.com/technetwork/java/javase/downloads/jre8-downloads-2133155.html) (JRE) version 8 or higher for the package to work.-->

## Installation

The package can be installed from CRAN as follows:

``` r
# Install from CRAN
install.packages('EvaluateCore', dependencies=TRUE)
```

The development version can be installed from github as follows:

``` r
# Install development version from Github
devtools::install_github("aravind-j/EvaluateCore")
```

<!-- ## Detailed tutorial
For a detailed tutorial (vignette) on how to used this package type:
&#10;
``` r
browseVignettes(package = 'EvaluateCore')
```
The vignette for the latest version is also available [online](https://aravind-j.github.io/EvaluateCore/articles.html).-->

## What’s new

To know whats new in this version type:

``` r
news(package='EvaluateCore')
```

## Links

[CRAN page](https://cran.r-project.org/package=EvaluateCore)

[Github page](https://github.com/aravind-j/EvaluateCore)

[Documentation website](https://aravind-j.github.io/EvaluateCore/)

[Zenodo DOI](https://doi.org/10.5281/zenodo.3875930)

## CRAN checks

[![Linux](https://img.shields.io/badge/Linux-FCC624?style=for-the-badge&logo=linux&logoColor=black)](https://cran.r-project.org/web/checks/check_results_EvaluateCore.html)

| Flavour | CRAN check |
|----|----|
| r-devel-linux-x86_64-debian-clang | [![CRAN check - r-devel-linux-x86_64-debian-clang](https://badges.cranchecks.info/flavor/r-devel-linux-x86_64-debian-clang/EvaluateCore.svg)](https://cran.r-project.org/web/checks/check_results_EvaluateCore.html) |
| r-devel-linux-x86_64-debian-gcc | [![CRAN check - r-devel-linux-x86_64-debian-gcc](https://badges.cranchecks.info/flavor/r-devel-linux-x86_64-debian-gcc/EvaluateCore.svg)](https://cran.r-project.org/web/checks/check_results_EvaluateCore.html) |
| r-devel-linux-x86_64-fedora-clang | [![CRAN check - r-devel-linux-x86_64-fedora-clang](https://badges.cranchecks.info/flavor/r-devel-linux-x86_64-fedora-clang/EvaluateCore.svg)](https://cran.r-project.org/web/checks/check_results_EvaluateCore.html) |
| r-devel-linux-x86_64-fedora-gcc | [![CRAN check - r-devel-linux-x86_64-fedora-gcc](https://badges.cranchecks.info/flavor/r-devel-linux-x86_64-fedora-gcc/EvaluateCore.svg)](https://cran.r-project.org/web/checks/check_results_EvaluateCore.html) |
| r-patched-linux-x86_64 | [![CRAN check - r-patched-linux-x86_64](https://badges.cranchecks.info/flavor/r-patched-linux-x86_64/EvaluateCore.svg)](https://cran.r-project.org/web/checks/check_results_EvaluateCore.html) |
| r-release-linux-x86_64 | [![CRAN check - r-release-linux-x86_64](https://badges.cranchecks.info/flavor/r-release-linux-x86_64/EvaluateCore.svg)](https://cran.r-project.org/web/checks/check_results_EvaluateCore.html) |

[![Windows](https://img.shields.io/badge/Windows-0078D6?style=for-the-badge&logo=windows&logoColor=white)](https://cran.r-project.org/web/checks/check_results_EvaluateCore.html)

| Flavour | CRAN check |
|----|----|
| r-devel-windows-x86_64 | [![CRAN check - r-devel-windows-x86_64](https://badges.cranchecks.info/flavor/r-devel-windows-x86_64/EvaluateCore.svg)](https://cran.r-project.org/web/checks/check_results_EvaluateCore.html) |
| r-release-windows-x86_64 | [![CRAN check - r-release-windows-x86_64](https://badges.cranchecks.info/flavor/r-release-windows-x86_64/EvaluateCore.svg)](https://cran.r-project.org/web/checks/check_results_EvaluateCore.html) |
| r-oldrel-windows-x86_64 | [![CRAN check - r-oldrel-windows-x86_64](https://badges.cranchecks.info/flavor/r-oldrel-windows-x86_64/EvaluateCore.svg)](https://cran.r-project.org/web/checks/check_results_EvaluateCore.html) |

[![MacOS](https://img.shields.io/badge/mac%20os-000000?style=for-the-badge&logo=apple&logoColor=white)](https://cran.r-project.org/web/checks/check_results_EvaluateCore.html)

| Flavour | CRAN check |
|----|----|
| r-release-macos-x86_64 | [![CRAN check - r-release-macos-x86_64](https://badges.cranchecks.info/flavor/r-release-macos-x86_64/EvaluateCore.svg)](https://cran.r-project.org/web/checks/check_results_EvaluateCore.html) |
| r-oldrel-macos-x86_64 | [![CRAN check - r-oldrel-macos-x86_64](https://badges.cranchecks.info/flavor/r-oldrel-macos-x86_64/EvaluateCore.svg)](https://cran.r-project.org/web/checks/check_results_EvaluateCore.html) |

## Citing `EvaluateCore`

To cite the methods in the package use:

``` r
citation("EvaluateCore")
```

    To cite the R package 'EvaluateCore' in publications use:

      Aravind, J., Kaur, V., Wankhede, D. P. and Nanjundan, J. (2026).  EvaluateCore: Quality Evaluation of
      Core Collections. R package version 0.1.5,
      https://aravind-j.github.io/EvaluateCore/https://CRAN.R-project.org/package=EvaluateCore.

    A BibTeX entry for LaTeX users is

      @Manual{,
        title = {EvaluateCore: Quality Evaluation of Core Collections},
        author = {J. Aravind and Vikender Kaur and Dhammaprakash Pandhari Wankhede and J. Nanjundan},
        note = {R package version 0.1.5 https://aravind-j.github.io/EvaluateCore/ https://CRAN.R-project.org/package=EvaluateCore},
        year = {2026},
      }

    This free and open-source software implements academic research by the authors and co-workers. If you use
    it, please support the project by citing the package.

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Distance Between Probability Distributions
#'
#' Compute Kullback-Leibler
#' \insertCite{kullback_information_1951}{EvaluateCore}, Kolmogorov-Smirnov
#' \insertCite{kolmogorov_sulla_1933,smirnov_table_1948}{EvaluateCore} and
#' Anderson-Darling distances
#' \insertCite{anderson_asymptotic_1952}{EvaluateCore} between the probability
#' distributions of collection (EC) and core set (CS) for quantitative traits.
#'
#' @inheritParams snk.evaluate.core
#'
#' @return A data frame with the following columns. \item{Trait}{The
#'   quantitative trait.} \item{Count}{The accession count (excluding missing
#'   data).} \item{KL_Distance}{The Kullback-Leibler distance
#'   \insertCite{kullback_information_1951}{EvaluateCore} between EC and CS.}
#'   \item{KS_Distance}{The Kolmogorov-Smirnov distance
#'   \insertCite{kolmogorov_sulla_1933,smirnov_table_1948}{EvaluateCore} between
#'   EC and CS.} \item{KS_pvalue}{The p value of the Kolmogorov-Smirnov
#'   distance.} \item{AD_Distance}{Anderson-Darling distance
#'   \insertCite{anderson_asymptotic_1952}{EvaluateCore} between EC and CS.}
#'   \item{AD_pvalue}{The p value of the Anderson-Darling distance.}
#'   \item{KS_significance}{The significance of the Kolmogorov-Smirnov distance
#'   (*: p \mjseqn{\leq} 0.01; **: p \mjseqn{\leq} 0.05; ns: p \mjseqn{>}
#'   0.05).} \item{AD_pvalue}{The significance of the Anderson-Darling distance
#'   (*: p \mjseqn{\leq} 0.01; **: p \mjseqn{\leq} 0.05; ns: p \mjseqn{>}
#'   0.05).}
#'
#' @seealso \code{\link[entropy]{KL.plugin}}, \code{\link[stats]{ks.test}},
#'   \code{\link[kSamples]{ad.test}}
#'
#' @importFrom entropy KL.plugin
#' @importFrom entropy discretize
#' @importFrom stats ks.test
#' @importFrom kSamples ad.test
#' @importFrom grDevices nclass.FD
#' @importFrom dplyr bind_rows
#' @export
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                      function(x) factor(as.factor(x)))
#'
#' pdfdist.evaluate.core(data = ec, names = "genotypes",
#'                       quantitative = quant, selected = core)
#'
pdfdist.evaluate.core <- function(data, names, quantitative, selected) {
  # Checks
  checks.evaluate.core(data = data, names = names,
                       quantitative = quantitative,
                       selected = selected)

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  dataf <- data[, c(names, quantitative)]

  datafcore <- dataf[dataf[, names] %in% selected, ]

  dataf$`[Type]` <- "EC"
  datafcore$`[Type]` <- "CS"

  dataf <- rbind(dataf, datafcore)
  rm(datafcore)

  outdf <- vector(mode = "list", length = length(quantitative))
  names(outdf) <- quantitative

  for (i in seq_along(quantitative)) {

    # Kullback–Leibler distance
    nbinscs <- grDevices::nclass.FD(dataf[dataf$`[Type]` == "CS" &
                                            !is.na(dataf[, quantitative[i]]),
                                          quantitative[i]])
    rangeec <- range(dataf[dataf$`[Type]` == "EC", quantitative[i]],
                     na.rm = TRUE)

    g1 <- entropy::discretize(dataf[dataf$`[Type]` == "EC" &
                                      !is.na(dataf[, quantitative[i]]),
                                    quantitative[i]],
                              nbinscs, rangeec)
    g1[g1 == 0] <- 0.000000001 #Smoothing
    g2 <- entropy::discretize(dataf[dataf$`[Type]` == "CS" &
                                      !is.na(dataf[, quantitative[i]]),
                                    quantitative[i]],
                              nbinscs, rangeec)
    g2[g2 == 0] <- 0.000000001 #Smoothing

    kl <- entropy::KL.plugin(g1, g2)

    # Kolmogorov-Smirnov distance
    ks <- ks.test(dataf[dataf$`[Type]` == "EC" &
                          !is.na(dataf[, quantitative[i]]), quantitative[i]],
                  dataf[dataf$`[Type]` == "CS" &
                          !is.na(dataf[, quantitative[i]]), quantitative[i]],
                  exact = FALSE)

    # Anderson-Darling distance
    ad <- kSamples::ad.test(dataf[dataf$`[Type]` == "EC" &
                                    !is.na(dataf[, quantitative[i]]),
                                  quantitative[i]],
                            dataf[dataf$`[Type]` == "CS" &
                                    !is.na(dataf[, quantitative[i]]),
                                  quantitative[i]],
                            dist = TRUE)

    outdf[[i]] <- data.frame(Trait = quantitative[i],
                             `Count` = sum(!is.na(dataf[dataf$`[Type]` == "EC",
                                                        quantitative[i]])),
                             `KL_Distance` = kl,
                             `KS_Distance` = ks$statistic,
                             `KS_pvalue` = ks$p.value,
                             `AD_Distance` = ad$ad["version 1:", "AD"],
                             `AD_pvalue` = ad$ad["version 1:", " asympt. P-value"],
                             stringsAsFactors = FALSE)

    rm(nbinscs, g1, g2, kl)
  }

  outdf <- dplyr::bind_rows(outdf)

  outdf$KS_significance <- ifelse(outdf$KS_pvalue <= 0.01, "**",
                                  ifelse(outdf$KS_pvalue <= 0.05, "*", "ns"))
  outdf$AD_significance <- ifelse(outdf$AD_pvalue <= 0.01, "**",
                                  ifelse(outdf$AD_pvalue <= 0.05, "*", "ns"))

  rownames(outdf) <- NULL

  return(outdf)

}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Variable Rate of Coefficient of Variation
#'
#' Compute the Variable Rate of Coefficient of Variation (\mjseqn{VR})
#' \insertCite{hu_methods_2000}{EvaluateCore} to compare quantitative traits of
#' the entire collection (EC) and core set (CS).
#'
#' The Variable Rate of Coefficient of Variation (\mjseqn{VR}) is computed as
#' follows.
#'
#' \mjsdeqn{VR = \left ( \frac{1}{n} \sum_{i=1}^{n}
#' \frac{CV_{CS_{i}}}{CV_{EC_{i}}} \right ) \times 100}
#'
#' Where, \mjseqn{CV_{CS_{i}}} is the coefficients of variation for the
#' \mjseqn{i}th trait in the CS, \mjseqn{CV_{EC_{i}}} is the coefficients of
#' variation for the \mjseqn{i}th trait in the EC and \mjseqn{n} is the total
#' number of traits
#'
#' @inheritParams snk.evaluate.core
#'
#' @return The \mjseqn{VR} value.
#'
#' @export
#'
#' @references
#'
#' \insertAllCited{}
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                      function(x) factor(as.factor(x)))
#'
#' vr.evaluate.core(data = ec, names = "genotypes",
#'                  quantitative = quant, selected = core)
#'
vr.evaluate.core <- function(data, names, quantitative, selected) {
  # Checks
  checks.evaluate.core(data = data, names = names,
                       quantitative = quantitative,
                       selected = selected)

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  vdiff <- levene.evaluate.core(data, names, quantitative,
                                selected)

  VR <- (sum(vdiff$CS_CV / vdiff$EC_CV) / length(quantitative)) * 100

  return(VR)

}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Ratio of Phenotype Retained
#'
#' Compute the Ratio of Phenotype Retained (\mjseqn{RPR})
#' \insertCite{li_studies_2002}{EvaluateCore} to compare qualitative traits
#' between entire collection (EC) and core set (CS).
#'
#' Ratio of Phenotype Retained (\mjseqn{RPR})
#' \insertCite{kim_PowerCore_2007}{EvaluateCore} is computed as follows.
#'
#' \mjsdeqn{RPR = \frac{\sum_{i=1}^{n} k_{CS_{i}}}{\sum_{i=1}^{n} k_{EC_{i}}}}
#'
#' Where, \mjseqn{k_{CS_{i}}} is the number of phenotypic classes in CS for the
#' \mjseqn{i}th trait, \mjseqn{k_{EC_{i}}} is the number of phenotypic classes
#' in EC for the \mjseqn{i}th trait and \mjseqn{n} is the total number of
#' traits.
#'
#' @inheritParams chisquare.evaluate.core
#'
#' @return The Ratio of Phenotype Retained value.
#'
#' @import mathjaxr
#' @export
#'
#' @references
#'
#' \insertAllCited{}
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                      function(x) factor(as.factor(x)))
#'
#' rpr.evaluate.core(data = ec, names = "genotypes",
#'                   qualitative = qual, selected = core)
#'
rpr.evaluate.core <- function(data, names, qualitative, selected,
                              na.omit = TRUE) {
  # Checks
  checks.evaluate.core(data = data, names = names,
                       qualitative = qualitative,
                       selected = selected)

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  cdiff <- chisquare.evaluate.core(data, names, qualitative,
                                   selected, na.omit = na.omit)

  rpr <- sum(cdiff$CS_No.Classes) / sum(cdiff$EC_No.Classes)

  return(rpr)

}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Sign Test
#'
#' Test difference between means and variances of entire collection (EC) and
#' core set (CS) for quantitative traits by Sign test (\mjseqn{+} versus
#' \mjseqn{-})
#' \insertCite{basigalup_development_1995,tai_core_2001}{EvaluateCore}.
#'
#' The test statistic for Sign test (\mjseqn{\chi^{2}}) is computed as follows.
#'
#' \mjsdeqn{\chi^{2} = \frac{(N_{1}-N_{2})^{2}}{N_{1}+N_{2}}}
#'
#' Where, where \mjseqn{N_{1}} is the number of variables for which the mean or
#' variance of the CS is greater than the mean or variance of the EC (number of
#' \mjseqn{+} signs); \mjseqn{N_{2}} is the number of variables for which the
#' mean or variance of the CS is less than the mean or variance of the EC
#' (number of \mjseqn{-} signs). The value of \mjseqn{\chi^{2}} is compared with
#' a Chi-square distribution with 1 degree of freedom.
#'
#' @param data The data as a data frame object. The data frame should possess
#'   one row per individual and columns with the individual names and multiple
#'   trait/character data.
#' @param names Name of column with the individual names as a character string
#' @param quantitative Name of columns with the quantitative traits as a
#'   character vector.
#' @param selected Character vector with the names of individuals selected in
#'   core collection and present in the \code{names} column.
#'
#' @return A data frame with the following components. \item{Comparison}{The
#'   comparison measure.} \item{ChiSq}{The test statistic (\mjseqn{\chi^{2}}).}
#'   \item{p.value}{The p value for the test statistic.} \item{significance}{The
#'   significance of the test statistic (*: p \mjseqn{\leq} 0.01; **: p
#'   \mjseqn{\leq} 0.05; ns: p \mjseqn{ > } 0.05).}
#'
#' @export
#'
#' @references
#'
#' \insertAllCited{}
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                      function(x) factor(as.factor(x)))
#'
#' signtest.evaluate.core(data = ec, names = "genotypes",
#'                        quantitative = quant, selected = core)
#'
signtest.evaluate.core <- function(data, names, quantitative, selected) {
  # Checks
  checks.evaluate.core(data = data, names = names,
                       quantitative = quantitative,
                       selected = selected)

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  mdiff <- snk.evaluate.core(data, names, quantitative,
                             selected)
  vdiff <- levene.evaluate.core(data, names, quantitative,
                                selected)

  mn1 <- sum(mdiff$CS_Mean > mdiff$EC_Mean)
  mn2 <- sum(mdiff$CS_Mean < mdiff$EC_Mean)
  mteststat <- ((mn1 - mn2)^2) / (mn1 + mn2)

  vn1 <- sum(vdiff$CS_CV > vdiff$EC_CV)
  vn2 <- sum(vdiff$CS_CV < vdiff$EC_CV)
  vteststat <- ((vn1 - vn2)^2) / (vn1 + vn2)

  mpvalue <- pchisq(mteststat, df = 1, lower.tail = FALSE)

  vpvalue <- pchisq(vteststat, df = 1, lower.tail = FALSE)

  outdf <- data.frame(Comparison = c("Mean", "Variance"),
                      ChiSq = c(mteststat, vteststat),
                      p.value = c(mpvalue, vpvalue),
                      stringsAsFactors = FALSE, row.names = NULL)

  outdf$significance <- ifelse(outdf$p.value <= 0.01, "**",
         ifelse(outdf$p.value <= 0.05, "*", "ns"))

  return(outdf)

}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Frequency Distribution Histogram
#'
#' Plot stacked frequency distribution histogram to graphically compare the
#' probability distributions of traits between entire collection (EC) and core
#' set (CS).
#'
#' @inheritParams snk.evaluate.core
#' @inheritParams chisquare.evaluate.core
#' @param highlight Individual names to be highlighted as a character vector.
#' @param include.highlight If \code{TRUE}, the highlighted individuals are
#'   included in the frequency distribution histogram. Default is \code{TRUE}.
#' @param highlight.se Optional data frame of standard errors for the
#'   individuals specified in \code{highlight}. It should have the same column
#'   names as in \code{data}.
#' @param highlight.col The colour(s) to be used to highlighting individuals in
#'   the plot as a character vector of the same length as \code{highlight}. Must
#'   be valid colour values in R (named colours, hexadecimal representation,
#'   index of colours [\code{1:8}] in default R \code{palette()} etc.).
#' @param show.count logical. If \code{TRUE}, the accession count excluding
#'   missing values will also be displayed. Default is \code{FALSE}.
#'
#' @return A list with the \code{ggplot} objects of stacked frequency
#'   distribution histograms plots for each trait specified as
#'   \code{quantitative} and \code{qualitative}.
#'
#' @seealso \code{\link[graphics]{hist}}, \code{\link[ggplot2]{geom_histogram}}
#'
#' @import ggplot2
#' @importFrom gridExtra grid.arrange
#' @importFrom grDevices col2rgb
#' @importFrom grDevices nclass.Sturges
#' @importFrom grDevices nclass.scott
#' @importFrom stats dnorm
#' @importFrom stats na.omit
#' @importFrom tibble as_tibble deframe
#' @export
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                      function(x) factor(as.factor(x)))
#'
#' \donttest{
#' freqdist.evaluate.core(data = ec, names = "genotypes",
#'                        quantitative = quant, qualitative = qual,
#'                        selected = core)
#'
#' checks <- c("TMe-1199", "TMe-1957", "TMe-3596", "TMe-3392")
#'
#' freqdist.evaluate.core(data = ec, names = "genotypes",
#'                        quantitative = quant, qualitative = qual,
#'                        selected = core,
#'                        highlight = checks, highlight.col = "red")
#'
#' quant.se <- data.frame(genotypes = checks,
#'                        NMSR = c(0.107, 0.099, 0.106, 0.062),
#'                        TTRN = c(0.081, 0.072, 0.057, 0.049),
#'                        TFWSR = c(0.089, 0.031, 0.092, 0.097),
#'                        TTRW = c(0.064, 0.031, 0.071, 0.071),
#'                        TFWSS = c(0.106, 0.071, 0.121, 0.066),
#'                        TTSW = c(0.084, 0.045, 0.066, 0.054),
#'                        TTPW = c(0.098, 0.052, 0.111, 0.082),
#'                        AVPW = c(0.074, 0.038, 0.054, 0.061),
#'                        ARSR = c(0.104, 0.019, 0.204, 0.044),
#'                        SRDM = c(0.078, 0.138, 0.076, 0.079))
#'
#' freqdist.evaluate.core(data = ec, names = "genotypes",
#'                        quantitative = quant,
#'                        selected = core,
#'                        highlight = checks, highlight.col = "red",
#'                        highlight.se = quant.se)
#'
#' freqdist.evaluate.core(data = ec, names = "genotypes",
#'                        quantitative = quant, qualitative = qual,
#'                        selected = core,
#'                        highlight = checks, highlight.col = "red",
#'                        show.count = TRUE)
#' }
#'
freqdist.evaluate.core <- function(data, names, quantitative, qualitative,
                                   selected, highlight = NULL,
                                   include.highlight = TRUE,
                                   highlight.se = NULL,
                                   highlight.col = "red",
                                   show.count = FALSE) {

  if (missing(quantitative)) {
    quantitative <- NULL
  }

  if (missing(qualitative)) {
    qualitative <- NULL
  }

  # Checks
  checks.evaluate.core(data = data, names = names,
                       quantitative = quantitative,
                       qualitative = qualitative,
                       selected = selected)

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  if (!is.null(highlight)) {
    if (!is.character(highlight)) {
      stop('"highlight" should be a character vector')
    }
    # highlight are present in treatment levels
    if (FALSE %in% c(highlight %in% data[, names])) {
      miss <- paste(highlight[!(highlight %in% data[, names])], collapse = ", ")
      stop(paste('Following individual(s) specified in "highlight"',
                 'are not present in', names, 'column of "data":\n',
                 paste(miss, collapse = ", ")))
    }
  }

  if (!is.null(highlight) & !all(iscolour(highlight.col))) {
    stop('"highlight.col" specifies invalid colour(s)')
  }

  if (!is.null(highlight) & length(highlight.col) != 1) {
    if (length(highlight.col) != length(highlight)) {
      stop('"highlight" and "highlight.col" are of unequal lengths')
    }
  }

  if (!is.null(highlight) & !is.null(highlight.se)) {
    # check if 'data' is a data frame object
    if (!is.data.frame(highlight.se)) {
      stop('"highlight.se" should be a data frame object')
    }

    if (any(c("tbl_dataf", "tbl") %in% class(highlight.se))) {
      warning('"highlight.se" is of type tibble\nCoercing to data frame')
      highlight.se <- as.data.frame(highlight.se)
    }

    if (dim(highlight.se)[1] != length(highlight)) {
      stop('"highlight.se" is of incorrect dimensions')
    }

    # check if 'names' column is present in 'data'
    if (!(names %in% colnames(highlight.se))) {
      stop(paste('Column ', names,
                 ' specified as the "names" column is not present in "highlight.se"',
                 sep = ""))
    }

    # check if 'quantitative' columns are present in 'highlight.se'
    if (!is.null(quantitative)) {
      if (FALSE %in% (quantitative %in% colnames(highlight.se)))  {
        stop(paste('The following column(s) specified in "quantitative" not present in "highlight.se":\n',
                   paste(quantitative[!(quantitative %in% colnames(highlight.se))],
                         collapse = ", "),
                   sep = ""))
      }
    }

    # check if 'qualitative' columns are present in 'highlight.se'
    if (!is.null(qualitative)) {
      if (FALSE %in% (qualitative %in% colnames(highlight.se)))  {
        stop(paste('The following column(s) specified in "qualitative" not present in "highlight.se":\n',
                   paste(qualitative[!(qualitative %in% colnames(highlight.se))],
                         collapse = ", "),
                   sep = ""))
      }
    }

    # check if names to be highlighted are present in highlight.se
    if (!all(highlight %in% highlight.se[, names])) {
      miss <- paste(highlight[!(highlight %in% highlight.se[, names])], collapse = ", ")
      stop(paste('Following individual(s) specified in "highlight"',
                 'are not present in', names, 'column of "highlight.se":\n',
                 paste(miss, collapse = ", ")))
    }
  }

  dataf <- data[, c(names, quantitative, qualitative)]

  datafcore <- dataf[dataf[, names] %in% selected, ]

  dataf$`[Type]` <- "EC"
  datafcore$`[Type]` <- "CS"

  dataf <- rbind(dataf, datafcore)
  rm(datafcore)

  dataf <- tibble::as_tibble(dataf)

  # dataf[, qualitative] <- lapply(dataf[, qualitative],
  #                                function(x) as.numeric(as.factor(x)))
  traits <- c(quantitative, qualitative)

  outlist <- vector(mode = "list", length = length(traits))
  names(outlist) <- traits

  # traits2 <- paste("`", traits, "`", sep = "")

  dataf$`[Type]` <- factor(dataf$`[Type]`)
  dataf$`[Type]` <- factor(dataf$`[Type]`, levels(dataf$`[Type]`)[c(2, 1)])

  # Fetch highlights
  if (!is.null(highlight)) {
    datah <- unique(dataf[tibble::deframe(dataf[, names]) %in% highlight,
                          c(names, traits)])
    datah[, names] <- as.factor(tibble::deframe(datah[, names]))
  }

  # Remove highlights
  if (!is.null(highlight) & !include.highlight) {
    dataf <- dataf[!(dataf[, names] %in% highlight), ]
  }

  dataf <- as.data.frame(dataf)

  for (i in seq_along(traits)) {

    if (show.count) {

      dataf_type_levels <-  levels(dataf$`[Type]`)

      dataf_count <-
        dplyr::summarise(.data = dataf[!is.na(dataf[, traits[i]]),],
                         .by = c("[Type]"),
                         Count = dplyr::n())
      dataf_count <- dataf_count[order(dataf_count$`[Type]`), ]

      levels(dataf$`[Type]`) <- paste(dataf_count$`[Type]`,
                                      " (n = ", dataf_count$Count, ")",
                                      sep = "")

      rm(dataf_count)
    }

    # Generate the freq dist histogram
    bw <- binw(as.numeric(dataf[, traits[i]]), "sturges")
    NN <- length(dataf[, traits[i]])

    if (traits[i] %in% quantitative) {
      G1 <- ggplot(data = dataf,
                   aes(x = .data[[traits[i]]], fill = `[Type]`)) +
        geom_histogram(position = "stack", alpha = 0.5,
                       colour = "black", binwidth = bw) +
        scale_fill_manual(values = c("lemonchiffon", "grey20")) +
        ylab("Frequency") +
        xlab(traits[i]) +
        theme_bw() +
        theme(axis.text = element_text(colour = "black"))
    } else {
      G1 <- ggplot(data = dataf,
                   aes(x = .data[[traits[i]]], fill = `[Type]`)) +
        # geom_histogram(position = "stack", alpha = 0.5,
        #                colour = "black", stat = "count") +
        stat_count(position = "stack", alpha = 0.5,
                   colour = "black") +
        scale_fill_manual(values = c("lemonchiffon", "grey20")) +
        ylab("Frequency") +
        xlab(traits[i]) +
        theme_bw() +
        theme(axis.text = element_text(colour = "black"))
    }

    # plot normal distribution curve if quantitative
    if (traits[i] %in% quantitative) {
      G1 <- G1 +
        stat_function(geom = "line", fun = function(x, mean, sd, n, bw) {
          dnorm(x = x, mean = mean, sd = sd) * n * bw},
          args = list(mean = mean(data[, traits[i]], na.rm = TRUE),
                      sd = sd(data[, traits[i]], na.rm = TRUE),
                      n = NN, bw = bw), colour = "blue")
    }


    # if (traits[i] %in% quantitative) {
    #   G1 <- G1 +
    #     scale_x_continuous(limits = c((min(dataf[, traits[i]],
    #                                        na.rm = TRUE)),
    #                                   (max(dataf[, traits[i]],
    #                                        na.rm = TRUE))))
    # }
    #
    # if (traits[i] %in% qualitative) {
    #   G1 <- G1 +
    #     scale_x_continuous(limits = c((min(dataf[, traits[i]],
    #                                        na.rm = TRUE)) - 1,
    #                                   (max(dataf[, traits[i]],
    #                                        na.rm = TRUE)) + 1))
    # }

    if (!is.null(highlight)) {

      sedf <- dataf[dataf[, names] %in% highlight, c(names, traits[i])]

      if (!is.null(highlight) & !is.null(highlight.se)) {

        sedf <- highlight.se[, c(names, traits[i])]
        names(sedf)[2] <- "se"
        sedf <- merge(datah[, c(names, traits[i])], sedf, by = names)
        sedf$lower <- sedf[, traits[i]] - sedf$se
        sedf$upper <- sedf[, traits[i]] + sedf$se

      }

      G2 <- ggplot(data = sedf,
                   aes(y = .data[[names]], x = .data[[traits[i]]])) +
        geom_point(colour = highlight.col) +
        labs(x = NULL, y = NULL) +
        theme_bw() +
        theme(axis.text.x = element_blank(),
              axis.ticks.x = element_blank()) +
        theme(legend.position = "none") +
        theme(plot.margin = unit(c(0.25, 0.1, 0, 0.25), "cm"),
              axis.text = element_text(colour = "black"))

      # if (traits[i] %in% quantitative) {
      #   G2 <- G2 +
      #     scale_x_continuous(limits = c((min(dataf[, traits[i]],
      #                                        na.rm = TRUE)),
      #                                   (max(dataf[, traits[i]],
      #                                        na.rm = TRUE))))
      # }
      #
      # if (traits[i] %in% qualitative) {
      #   G2 <- G2 +
      #     scale_x_continuous(limits = c((min(dataf[, traits[i]],
      #                                        na.rm = TRUE)) - 1,
      #                                   (max(dataf[, traits[i]],
      #                                        na.rm = TRUE)) + 1))
      # }

      if (!is.null(highlight) & !is.null(highlight.se)) {

        G2 <- G2 +
          geom_errorbar(aes(xmin = lower, xmax = upper),
                        colour = highlight.col,
                        width  = 0.25)
      }

      legind <- grep("guide-box", ggplotGrob(G1)$grobs)
      leg <- ggplotGrob(G1)$grobs[[legind]]
      G1 <- G1 + theme(legend.position = "none")

      G <- rbind(ggplotGrob(G2), ggplotGrob(G1), size = "max")
      G <- resize_heights(G, c(1, 3))
      G <- grid.arrange(G, leg, nrow = 1, widths = c(10, 1))

      outlist[[i]] <- G

    } else  {

      outlist[[i]] <- G1

    }

    if (show.count) {
      levels(dataf$`[Type]`) <- dataf_type_levels
    }

    rm(bw, NN)
  }

  return(outlist)

}


binw <- function(x, method = c("fd", "scott", "sturges")) {
  method <- match.arg(method)

  if (method == "fd") {
    bw <-   pretty(range(x, na.rm = TRUE), n = nclass.FD(na.omit(x)),
                   min.n = 1, right = TRUE)[2] -
      pretty(range(x, na.rm = TRUE), n = nclass.FD(na.omit(x)),
             min.n = 1, right = TRUE)[1]
  }
  if (method == "scott") {
    bw <-   pretty(range(x, na.rm = TRUE), n = nclass.scott(na.omit(x)),
                   min.n = 1, right = TRUE)[2] -
      pretty(range(x, na.rm = TRUE), n = nclass.scott(na.omit(x)),
             min.n = 1, right = TRUE)[1]
  }
  if (method == "sturges") {
    bw <-   pretty(range(x, na.rm = TRUE), n = nclass.Sturges(na.omit(x)),
                   min.n = 1, right = TRUE)[2] -
      pretty(range(x, na.rm = TRUE), n = nclass.Sturges(na.omit(x)),
             min.n = 1, right = TRUE)[1]
  }
  return(bw)
}

if (getRversion() >= "4.0.0")  {
  resize_heights <- function(g, heights = rep(1, length(idpanels))) {
    idpanels <- unique(g$layout[grepl("panel", g$layout$name), "t"])
    g$heights <- grid::unit(g$heights, "null")
    g$heights[idpanels] <- grid::unit(do.call(grid::unit,
                                              list(heights, 'null')), "null")
    g
  }
} else {
  unit.list <- getFromNamespace("unit.list", "grid")

  resize_heights <- function(g, heights = rep(1, length(idpanels))) {
    idpanels <- unique(g$layout[grepl("panel", g$layout$name), "t"])
    g$heights <- unit.list(g$heights)
    hunits <- lapply(heights, unit, "null")
    class(hunits) <- class(g$heights[idpanels])
    g$heights[idpanels] <- hunits
    g
  }
}

iscolour <- function(x) {
  sapply(x, function(X) {
    tryCatch(is.matrix(col2rgb(X)),
             error = function(e) FALSE)
  })
}

# add to yml

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Student-Newman-Keuls Test
#'
#' Test difference between means of entire collection (EC) and core set (CS) for
#' quantitative traits by Newman-Keuls or Student-Newman-Keuls test
#' \insertCite{newman_distribution_1939,keuls_use_1952}{EvaluateCore}.
#'
#' @param data The data as a data frame object. The data frame should possess
#'   one row per individual and columns with the individual names and multiple
#'   trait/character data.
#' @param names Name of column with the individual names as a character string.
#' @param quantitative Name of columns with the quantitative traits as a
#'   character vector.
#' @param selected Character vector with the names of individuals selected in
#'   core collection and present in the \code{names} column.
#'
#' @return A data frame with the following components. \item{Trait}{The
#'   quantitative trait.} \item{Count}{The accession count (excluding missing
#'   data).} \item{Df}{The degrees of freedom for the test.} \item{EC_Min}{The
#'   minimum value of the trait in EC.} \item{EC_Max}{The maximum value of the
#'   trait in EC.} \item{EC_Mean}{The mean value of the trait in EC.}
#'   \item{EC_SE}{The standard error of the trait in EC.} \item{CS_Min}{The
#'   minimum value of the trait in CS.} \item{CS_Max}{The maximum value of the
#'   trait in CS.} \item{CS_Mean}{The mean value of the trait in CS.}
#'   \item{CS_SE}{The standard error of the trait in CS.} \item{SNK_pvalue}{The
#'   p value of the Student-Newman-Keuls test for equality of means of EC and
#'   CS.} \item{SNK_significance}{The significance of the Student-Newman-Keuls
#'   test for equality of means of EC and CS.}
#'
#' @seealso \code{\link[agricolae]{SNK.test}}
#'
#' @importFrom agricolae SNK.test
#' @importFrom dplyr bind_rows
#' @importFrom stats formula
#' @importFrom stats aov
#' @importFrom stats sd
#' @importFrom Rdpack reprompt
#' @export
#'
#' @references
#'
#' \insertAllCited{}
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                      function(x) factor(as.factor(x)))
#'
#' snk.evaluate.core(data = ec, names = "genotypes",
#'                   quantitative = quant, selected = core)
#'
snk.evaluate.core <- function(data, names, quantitative, selected) {
  # Checks
  checks.evaluate.core(data = data, names = names,
                      quantitative = quantitative,
                      selected = selected)

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  dataf <- data[, c(names, quantitative)]

  datafcore <- dataf[dataf[, names] %in% selected, ]

  dataf$`[Type]` <- "EC"
  datafcore$`[Type]` <- "CS"

  dataf <- rbind(dataf, datafcore)
  rm(datafcore)

  outdf <- vector(mode = "list", length = length(quantitative))
  names(outdf) <- quantitative

  for (i in seq_along(quantitative)) {
    frmla <- stats::formula(paste("`", quantitative[i], "` ~ `[Type]`",
                                       sep = ""))
    model <- stats::aov(frmla, data = dataf[!is.na(dataf[, quantitative[i]]), ])
    snkout <- agricolae::SNK.test(model, "[Type]", group = FALSE,
                                  console = FALSE)
    snkdf <- snkout$statistics$Df
    snkpvalue <- snkout$comparison$pvalue

    # out <- mutoss::snk(frmla, data = dataf,
    #                    alpha=0.05, MSE=NULL, df = NULL, silent = FALSE)
    # out <- t.test(dataf[dataf$`[Type]` == "EC", quantitative[i]],
    #               dataf[dataf$`[Type]` == "CS", quantitative[i]])

    outdf[[quantitative[i]]] <-
      data.frame(`Trait` = quantitative[i],
                 `Count` = sum(!is.na(dataf[dataf$`[Type]` == "EC",
                                            quantitative[i]])),
                 `Df` = snkdf,
                 `EC_Min` = min(dataf[dataf$`[Type]` == "EC", quantitative[i]],
                                na.rm = TRUE),
                 `EC_Max` = max(dataf[dataf$`[Type]` == "EC", quantitative[i]],
                                na.rm = TRUE),
                 `EC_Mean` = mean(dataf[dataf$`[Type]` == "EC",
                                        quantitative[i]],
                                  na.rm = TRUE),
                 `EC_SE` = stats::sd(dataf[dataf$`[Type]` == "EC",
                                           quantitative[i]],
                                     na.rm = TRUE) /
                   sqrt(length(dataf[dataf$`[Type]` == "EC" &
                                       !is.na(dataf[, quantitative[i]]),
                                     quantitative[i]])),
                 `CS_Min` = min(dataf[dataf$`[Type]` == "CS", quantitative[i]],
                                na.rm = TRUE),
                 `CS_Max` = max(dataf[dataf$`[Type]` == "CS", quantitative[i]],
                                na.rm = TRUE),
                 `CS_Mean` = mean(dataf[dataf$`[Type]` == "CS",
                                        quantitative[i]],
                                  na.rm = TRUE),
                 `CS_SE` = stats::sd(dataf[dataf$`[Type]` == "CS",
                                           quantitative[i]],
                                     na.rm = TRUE) /
                   sqrt(length(dataf[dataf$`[Type]` == "CS" &
                                       !is.na(dataf[, quantitative[i]]),
                                     quantitative[i]])),
                 `SNK_pvalue` = snkpvalue,
                 stringsAsFactors = FALSE)

    rm(snkout, snkpvalue, frmla, model)
  }

  outdf <- dplyr::bind_rows(outdf)

  outdf$SNK_significance <- ifelse(outdf$SNK_pvalue <= 0.01, "**",
                                   ifelse(outdf$SNK_pvalue <= 0.05, "*", "ns"))

  return(outdf)

}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


wlcm <- paste0("\n",
               "--------------------------------------------------------------------------------\n",
               "Welcome to EvaluateCore version ", utils::packageDescription("EvaluateCore")$Version, "\n",
               "\n", "\n",
               # "# To know how to use this package type:", "\n",
               # "  browseVignettes(package = 'EvaluateCore')", "\n", "  for the package vignette.", "\n",
               # "\n",
               "# To know whats new in this version type:", "\n",
               "  news(package='EvaluateCore')", "\n", "  for the NEWS file.", "\n",
               "\n",
               "# To cite the methods in the package type:", "\n",
               "  citation(package='EvaluateCore')", "\n",
               "\n",
               "# To suppress this message use:", "\n",
               "  suppressPackageStartupMessages(library(EvaluateCore))", "\n",
               "--------------------------------------------------------------------------------\n")

.onAttach <- function(lib, pkg, ...) {
  packageStartupMessage(wlcm)


}

# #' @import rJava
# .onLoad <- function(libname, pkgname) {
#   rJava::.jpackage("corehunter")
#   rJava::.jpackage(pkgname, lib.loc = libname)
#
#   # # check Java version
#   # req.version <- 8
#   # version.string <- J("java.lang.System")$getProperty("java.version")
#   # version <- as.integer(strsplit(version.string, ".", fixed = TRUE)[[1]][2])
#   # if (version < req.version) {
#   #   stop(sprintf(
#   #     'Java version %d or later required for "dist.evaluate.core()". Found version %d.',
#   #     req.version, version
#   #   ))
#   # }
#
#   # check Java version
#   .jinit()
#   jv <- .jcall("java/lang/System", "S", "getProperty", "java.runtime.version")
#   if(substr(jv, 1L, 1L) == "1") {
#     jvn <- as.numeric(paste0(strsplit(jv, "[.]")[[1L]][1:2], collapse = "."))
#     if(jvn < 1.8) {
#       stop("Java >= 8 is needed for this package but not available.")
#     }
#   }
# }

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Synthetic Variation Coefficient
#'
#' Compute the Synthetic Variation Coefficient
#' (\mjteqn{CV\\\%}{CV\\\\\\\%}{CV\%})
#' \insertCite{dong_exploration_1998,dong_genetic_2001}{EvaluateCore} to compare
#' quantitative traits of the entire collection (EC) and core set (CS).
#'
#' Synthetic Variation Coefficient (\mjteqn{CV\\\%}{CV\\\\\\\%}{CV\%})
#' \insertCite{dong_exploration_1998,dong_genetic_2001}{EvaluateCore} is
#' computed as follows for the core set (CS).
#'
#' \mjtdeqn{CV(\\\%) = \left ( \frac{1}{n} \sum_{i=1}^{n} \frac{SE_{i}}{\mu_{i}}
#' \right ) \times 100}{CV(\\\\\\\%) = \left ( \frac{1}{n} \sum_{i=1}^{n}
#' \frac{SE_{j}}{\mu_{i}}  \right ) \times 100}{CV(\%) = \left ( \frac{1}{n} \sum_{i=1}^{n} \frac{SE_{j}}{\mu_{i}}  \right ) \times 100}
#'
#' Where, \mjseqn{SE_{i}} is the standard error of the \mjseqn{i}th trait,
#' \mjseqn{\mu_{i}} is the mean of the \mjseqn{i}th trait and \mjseqn{n} is the
#' total number of traits.
#'
#' @inheritParams snk.evaluate.core
#'
#' @return The Synthetic Variation Coefficient values for EC and CS
#'
#' @import mathjaxr
#' @export
#'
#' @references
#'
#' \insertAllCited{}
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                       function(x) factor(as.factor(x)))
#'
#' scv.evaluate.core(data = ec, names = "genotypes",
#'                   quantitative = quant, selected = core)
#'
scv.evaluate.core <- function(data, names, quantitative, selected) {
  # Checks
  checks.evaluate.core(data = data, names = names,
                       quantitative = quantitative,
                       selected = selected)

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  dataf <- data[, c(names, quantitative)]

  datafcore <- dataf[dataf[, names] %in% selected, ]

  dataf$`[Type]` <- "EC"
  datafcore$`[Type]` <- "CS"

  dataf <- rbind(dataf, datafcore)
  rm(datafcore)

  dataf$`[Type]` <- as.factor(dataf$`[Type]`)

  scv_ec <- lapply(dataf[dataf$`[Type]` == "EC", quantitative],
                function(x) {sd(x, na.rm = TRUE) /
                    sqrt(length(x[!is.na(x)]))})
  scv_ec <- unlist(scv_ec)
  scv_ec <- mean(scv_ec) * 100

  scv_cs <- lapply(dataf[dataf$`[Type]` == "CS", quantitative],
                function(x) {sd(x, na.rm = TRUE) /
                    sqrt(length(x[!is.na(x)]))})
  scv_cs <- unlist(scv_cs)
  scv_cs <- mean(scv_cs) * 100

  return(c(EC_SCV = scv_ec, CS_SCV = scv_cs))
}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' @title Deprecated functions in package \pkg{EvaluateCore}.
#' @description The functions listed below are deprecated and will be defunct in
#'   the near future. When possible, alternative functions with similar
#'   functionality are also mentioned. Help pages for deprecated functions are
#'   available at \code{help("<function>-deprecated")}.
#' @name EvaluateCore-deprecated
#' @keywords internal
NULL

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/

#' Distance Measures
#'
#' Compute average Entry-to-nearest-entry distance
#' (\mjteqn{E\textrm{-}EN}{E\text{-}EN}{E-EN}),
#' Accession-to-nearest-entry distance
#' (\mjteqn{A\textrm{-}EN}{E\text{-}EN}{A-EN}) and
#' Entry-to-entry distance (\mjteqn{E\textrm{-}E}{E\text{-}EN}{E-E})
#' \insertCite{odong_quality_2013}{EvaluateCore}
#' to evaluate a core set (CS) selected from an entire collection (EC).
#'
# #' This function is a wrapper around the
# #' \code{\link[corehunter]{evaluateCore}}
# #' function of the \code{\link[corehunter]{corehunter}} package.
#'
#' @inheritParams snk.evaluate.core
#' @inheritParams chisquare.evaluate.core
#' @param d A distance matrix of class "\code{dist}" with individual names in
#' the \code{names} column in \code{data} as labels. If \code{NULL} (default),
#' then a distance matrix is computed using Gower's metric.
#' \insertCite{gower_general_1971}{EvaluateCore}.
#'
#' @return A data frame with the average values of
#' \mjteqn{E\textrm{-}EN}{E\text{-}EN}{E-EN},
#' \mjteqn{A\textrm{-}EN}{E\text{-}EN}{A-EN} and
#' \mjteqn{E\textrm{-}E}{E\text{-}EN}{E-E}.
#'
#' @references
#'
#' \insertAllCited{}
#'
#' @seealso \code{\link[corehunter]{evaluateCore}}
#'
# #' @importFrom corehunter evaluateCore
# #' @importFrom corehunter phenotypes
# #' @importFrom corehunter objective
#' @importFrom cluster daisy
#' @export
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                      function(x) factor(as.factor(x)))
#'
#' dist.evaluate.core(data = ec, names = "genotypes", quantitative = quant,
#'                    qualitative = qual, selected = core)
#'
#' \donttest{
#' ####################################
#' # Compare with corehunter
#' ####################################
#'
#' library(corehunter)
#' # Prepare phenotype dataset
#' dtype <- c(rep("RD", length(quant)),
#'            rep("NS", length(qual)))
#' rownames(ec) <- ec[, "genotypes"]
#' ecdata <- corehunter::phenotypes(data = ec[, c(quant, qual)],
#'                                  types = dtype)
#'
#' # Compute average distances
#' EN <- evaluateCore(core = rownames(cassava_CC), data = ecdata,
#'                    objective = objective("EN", "GD"))
#' AN <- evaluateCore(core = rownames(cassava_CC), data = ecdata,
#'                    objective = objective("AN", "GD"))
#' EE <- evaluateCore(core = rownames(cassava_CC), data = ecdata,
#'                    objective = objective("EE", "GD"))
#' EN
#' AN
#' EE
#' }
#'
dist.evaluate.core <- function(data, names, quantitative, qualitative,
                               selected, d = NULL) {
  if (missing(quantitative)) {
    quantitative <- NULL
  }

  if (missing(qualitative)) {
    qualitative <- NULL
  }

  if (length(c(quantitative, qualitative)) == 1) {
    stop("Only one trait specified")
  }

  # Checks
  checks.evaluate.core(data = data, names = names,
                       quantitative = quantitative,
                       qualitative = qualitative,
                       selected = selected)

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  # traits <- c(quantitative, qualitative)
  # # quantitative (RD); qualitative(NS)
  # dtype <- c(rep("RD", length(quantitative)),
  #            rep("NS", length(qualitative)))

  # dataf <- data[, c(names, traits)]
  # rownames(dataf) <- dataf[, names]

  if (!is.null(d)) {
    # check if d is a distance matrix
    if (!("dist" %in% class(d))) {
        stop('Distance matrix "d" is not an object of class "dist".')
    }
    dsize <- as.integer(attr(d, "Size"))
    if (nrow(data) != dsize) {
      stop('Dimensions of distance matrix "d" and "data" do not match.')
    }

    if (!(all(labels(d) %in% data[, names]) &
          all(data[, names] %in% labels(d)))) {
      stop('Labels of distance matrix "d" and "data" do not match.')
    }
  } else {
    rownames(data) <- data[, names]
    d <- cluster::daisy(data[, c(quantitative, qualitative)],
                        metric = "gower")

    missvcols <- unlist(lapply(data[, quantitative],
                               function(x) TRUE %in% is.na(x)))
    if (TRUE %in% missvcols) {
      warning('Missing values are ignored for calculation of distances ',
              'between traits.')
    }
  }

  # # Prep phenotype
  # dataf <- corehunter::phenotypes(data = dataf[, c(quantitative,
  #                                                  qualitative)],
  #                                 types = dtype)
  # # Compute average distances
  # EN <- evaluateCore(core = selected, data = dataf,
  #                    objective = objective("EN", "GD"))
  # AN <- evaluateCore(core = selected, data = dataf,
  #                    objective = objective("AN", "GD"))
  # EE <- evaluateCore(core = selected, data = dataf,
  #                    objective = objective("EE", "GD"))

  dmat <- as.matrix(d)
  selind <- which(rownames(dmat) %in% selected)
  subdist <- dmat[selind, selind]

  #EE
  EE <- mean(subdist[upper.tri(subdist)])

  #EN
  EN <- mean(apply(subdist, 1, FUN = function(x) {min(x[x > 0])}))

  #AN
  subdist2 <- dmat[-selind, selind]
  dsize <- as.integer(attr(d, "Size"))
  AN <- sum(apply(subdist2, 1, FUN = function(x) {min(x[x > 0])})) / dsize

  outdf <- data.frame(`Average distance` = c("E-NE", "A-NE", "E-E"),
                     `Value` = c(EN, AN, EE))

  return(outdf)

}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Phenotypic Correlations
#'
#' Compute phenotypic correlations \insertCite{pearson_note_1895}{EvaluateCore}
#' between traits, plot correlation matrices as correlograms
#' \insertCite{friendly_corrgrams_2002}{EvaluateCore} and calculate mantel
#' correlation \insertCite{legendre_interpretation_2012}{EvaluateCore} between
#' them to compare entire collection (EC) and core set (CS).
#'
#' @inheritParams snk.evaluate.core
#' @inheritParams chisquare.evaluate.core
#'
#' @return A list with the following components. \item{Correlation Matrix}{The
#'   matrix with phenotypic correlations between traits in EC (below diagonal)
#'   and CS (above diagonal).} \item{Correologram}{A correlogram of phenotypic
#'   correlations between traits in EC (below diagonal) and CS (above diagonal)
#'   as a \code{ggplot} object.} \item{Mantel Correlation}{A data frame with
#'   Mantel correlation coefficient (\mjseqn{r}) between EC and CS phenotypic
#'   correlation matrices, it's p value and significance (*: p \mjseqn{\leq}
#'   0.01; **: p \mjseqn{\leq} 0.05; ns: p \mjseqn{ > } 0.05).}
#'
#' @note Missing values are ignored for the computation of correlation
#'   coefficient.
#'
#' @seealso \code{\link[stats]{cor}},
#'   \code{\link[ggcorrplot:ggcorrplot]{cor_pmat}}
#'   \code{\link[ggcorrplot]{ggcorrplot}}, \code{\link[vegan]{mantel}}
#'
#' @import ggcorrplot
#' @import ggplot2
#' @importFrom stats cor
#' @importFrom vegan mantel
#' @importFrom tibble as_tibble
#' @export
#'
#' @references
#'
#' \insertAllCited{}
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                      function(x) factor(as.factor(x)))
#'
#' corr.evaluate.core(data = ec, names = "genotypes", quantitative = quant,
#'                    qualitative = qual, selected = core)
#'
corr.evaluate.core <- function(data, names, quantitative, qualitative,
                               selected) {

  if (missing(quantitative)) {
    quantitative <- NULL
  }

  if (missing(qualitative)) {
    qualitative <- NULL
  }

  if (length(c(quantitative, qualitative)) == 1) {
    stop("Only one trait specified")
  }

  # Checks
  checks.evaluate.core(data = data, names = names,
                       quantitative = quantitative,
                       qualitative = qualitative,
                       selected = selected)

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  dataf <- data[, c(names, quantitative, qualitative)]

  datafcore <- dataf[dataf[, names] %in% selected, ]

  dataf$`[Type]` <- "EC"
  datafcore$`[Type]` <- "CS"

  dataf <- rbind(dataf, datafcore)
  rm(datafcore)

  dataf <- tibble::as_tibble(dataf)

  dataf[, qualitative] <- lapply(dataf[, qualitative],
                                 function(x) as.numeric(as.factor(x)))

  # EC corr
  #########
  eccorr <- stats::cor(dataf[dataf$`[Type]` == "EC",
                             c(quantitative, qualitative)],
                       use = "complete.obs")
  ecpmat <- ggcorrplot::cor_pmat(dataf[dataf$`[Type]` == "EC",
                                       c(quantitative, qualitative)])

  eccorrdf <- formatC(round(eccorr, 2), digits = 2, format = "f")
  eccorrdf[] <- paste0(eccorrdf,
                        ifelse(ecpmat < .01, "**",
                               ifelse(ecpmat < .05, "*", "")),
                        sep = "")

 # CS corr
  #########
  cscorr <- stats::cor(dataf[dataf$`[Type]` == "CS",
                             c(quantitative, qualitative)],
                       use = "complete.obs")
  cspmat <- ggcorrplot::cor_pmat(dataf[dataf$`[Type]` == "CS",
                                       c(quantitative, qualitative)])

  cscorrdf <- formatC(round(cscorr, 2), digits = 2, format = "f")
  cscorrdf[] <- paste0(cscorrdf,
                       ifelse(cspmat < .01, "**",
                              ifelse(cspmat < .05, "*", "")),
                       sep = "")

  # Combine
  #########
  corrdf <- eccorrdf
  corrdf[upper.tri(cscorrdf)] <- cscorrdf[upper.tri(cscorrdf)]
  diag(corrdf) <- NA

  corrdf <- data.frame(corrdf, stringsAsFactors = FALSE)


  corr <- eccorr
  corr[upper.tri(corr)] <- cscorr[upper.tri(cscorr)]
  diag(corr) <- NA

  pmat <- ecpmat
  pmat[upper.tri(pmat)] <- cspmat[upper.tri(cspmat)]
  diag(pmat) <- NA


  corrg <- ggcorrplot(corr, hc.order = FALSE, type = "full",
                      outline.color = "white", p.mat = pmat,
                      ggtheme = theme_bw, show.diag = TRUE,
                      lab = TRUE, legend.title = "Corr")
  corrg <- corrg +
    ggtitle("Below diagonal:EC\nAbove diagonal:CS")

  corrg <- corrg +
    theme(axis.text = element_text(colour = "black"))

 # lower tri - EC below diagonal
 # upper tri - CS above diagonal

  # Mantel test
  ##############

  mcorr <- vegan::mantel(eccorr, cscorr)

  outlist <- list(`Correlation Matrix` = corrdf,
                  `Correologram` = corrg,
                  `Mantel Correlation` = data.frame(r = mcorr$statistic,
                                                    p.value = mcorr$signif,
                                                    significance =
                                                      ifelse(mcorr$signif <= 0.01, "**",
                                                             ifelse(mcorr$signif <= 0.05, "*", "ns"))))


  return(outlist)

}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Bar Plots
#'
#' Plot Bar plots to graphically compare the frequency distributions of
#' qualitative traits between entire collection (EC) and core set (CS).
#'
#' @inheritParams chisquare.evaluate.core
#' @param na.omit logical. If \code{TRUE}, missing values (\code{NA}) are
#'   ignored and not included in the plot as a distinct factor level. Default is
#'   \code{TRUE}.
#' @param show.count logical. If \code{TRUE}, the accession count excluding
#'   missing values will also be displayed. Default is \code{FALSE}.
#'
#' @return A list with the \code{ggplot} objects of relative frequency bar plots
#'   of CS and EC for each trait specified as \code{qualitative}.
#'
#'
#' @seealso \code{\link[graphics]{barplot}}, \code{\link[ggplot2]{geom_bar}}
#'
#' @importFrom dplyr summarise n
#' @import ggplot2
#' @export
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                      function(x) factor(as.factor(x)))
#'
#' \donttest{
#' bar.evaluate.core(data = ec, names = "genotypes",
#'                   qualitative = qual, selected = core)
#' bar.evaluate.core(data = ec, names = "genotypes",
#'                   qualitative = qual, selected = core,
#'                   show.count = TRUE)
#' }
#'
bar.evaluate.core <- function(data, names, qualitative, selected,
                              na.omit = TRUE, show.count = FALSE) {
  # Checks
  checks.evaluate.core(data = data, names = names,
                       qualitative = qualitative,
                       selected = selected)

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  dataf <- data[, c(names, qualitative)]

  datafcore <- dataf[dataf[, names] %in% selected, ]

  dataf$`[Type]` <- "EC"
  datafcore$`[Type]` <- "CS"

  dataf <- rbind(dataf, datafcore)
  rm(datafcore)

  dataf$`[Type]` <- as.factor(dataf$`[Type]`)

  outlist <- vector(mode = "list", length = length(qualitative))
  names(outlist) <- qualitative

  # qualitative2 <- paste("`", qualitative, "`", sep = "")

  for (i in seq_along(qualitative)) {

    if (show.count) {

      dataf_type_levels <-  levels(dataf$`[Type]`)

      dataf_count <-
        dplyr::summarise(.data = dataf[!is.na(dataf[, qualitative[i]]),],
                         .by = c("[Type]"),
                         Count = dplyr::n())
      dataf_count <- dataf_count[order(dataf_count$`[Type]`), ]

      levels(dataf$`[Type]`) <- paste(dataf_count$`[Type]`,
                                      " (n = ", dataf_count$Count, ")",
                                      sep = "")

      rm(dataf_count)
    }

    if(na.omit) {
      outlist[[i]] <- ggplot(dataf[!is.na(dataf[, qualitative[i]]), ],
                             aes(.data[[qualitative[i]]]))
    } else {
      outlist[[i]] <- ggplot(dataf, aes(.data[[qualitative[i]]]))
    }

    # Generate the bar plot
    outlist[[i]] <- outlist[[i]] +
      geom_bar(aes(y = after_stat(prop), group = 1),
               fill = "gray80", colour = "black") +
      ylab("Relative frequency") +
      xlab(qualitative[i]) +
      facet_grid(~`[Type]`) +
      theme_bw() +
      theme(axis.text = element_text(colour = "black"),
            axis.text.x = element_text(angle = 45, hjust = 1))

    if (show.count) {
      levels(dataf$`[Type]`) <- dataf_type_levels
    }

  }

  return(outlist)

}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Quantile-Quantile Plots
#'
#' Plot Quantile-Quantile (QQ) plots
#' \insertCite{wilk_probability_1968}{EvaluateCore} to graphically compare the
#' probability distributions of quantitative traits between entire collection
#' (EC) and core set (CS).
#'
#' @inheritParams snk.evaluate.core
#' @param show.count logical. If \code{TRUE}, the accession count excluding
#'   missing values will also be displayed. Default is \code{FALSE}.
#' @param annotate Adds the divergence/distance value between probability
#'   distributions of CS and EC as an annotation to the QQ plot. Either
#'   \code{"none"} (no annotation (Default)) or \code{"kl"} (Kullback-Leibler
#'   divergence) or  \code{"ks"} (Kolmogorov-Smirnov distance) or  \code{"ad"}
#'   (Anderson-Darling distance).
#'
#' @return A list with the \code{ggplot} objects of QQ plots of CS vs EC for
#'   each trait specified as \code{quantitative}.
#'
#' @seealso \code{\link[stats:qqnorm]{qqplot}} \code{\link[entropy]{KL.plugin}},
#'   \code{\link[stats]{ks.test}}, \code{\link[kSamples]{ad.test}},
#'   \code{\link[EvaluateCore]{pdfdist.evaluate.core}}
#'
#' @import ggplot2
#' @import ggtext
#' @importFrom stats qqplot
#' @importFrom entropy KL.plugin
#' @importFrom entropy discretize
#' @importFrom stats ks.test
#' @importFrom kSamples ad.test
#' @importFrom grDevices nclass.FD
#' @export
#'
#' @references
#'
#' \insertAllCited{}
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                      function(x) factor(as.factor(x)))
#'
#' \donttest{
#' qq.evaluate.core(data = ec, names = "genotypes",
#'                  quantitative = quant, selected = core)
#'
#' qq.evaluate.core(data = ec, names = "genotypes",
#'                  quantitative = quant, selected = core, show.count = TRUE)
#'
#' qq.evaluate.core(data = ec, names = "genotypes",
#'                  quantitative = quant, selected = core, annotate = "kl")
#'
#' qq.evaluate.core(data = ec, names = "genotypes",
#'                  quantitative = quant, selected = core, annotate = "ks")
#'
#' qq.evaluate.core(data = ec, names = "genotypes",
#'                  quantitative = quant, selected = core, annotate = "ad")
#' }
#'
qq.evaluate.core <- function(data, names, quantitative, selected,
                             annotate = c("none", "kl", "ks", "ad"),
                             show.count = FALSE) {
  # Checks
  checks.evaluate.core(data = data, names = names,
                       quantitative = quantitative,
                       selected = selected)

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  annotate <- match.arg(annotate)

  dataf <- data[, c(names, quantitative)]

  datafcore <- dataf[dataf[, names] %in% selected, ]

  dataf$`[Type]` <- "EC"
  datafcore$`[Type]` <- "CS"

  dataf <- rbind(dataf, datafcore)
  rm(datafcore)

  avec <- vector(mode = "list", length = length(quantitative))
  names(avec) <- quantitative

  if (annotate != "none") {

    for (i in seq_along(quantitative)) {

      if (annotate == "kl") {
        # Kullback–Leibler distance
        nbinscs <-
          grDevices::nclass.FD(dataf[dataf$`[Type]` == "CS" &
                                       !is.na(dataf[, quantitative[i]]),
                                     quantitative[i]])
        rangeec <- range(dataf[dataf$`[Type]` == "EC", quantitative[i]],
                         na.rm = TRUE)

        g1 <- entropy::discretize(dataf[dataf$`[Type]` == "EC" &
                                          !is.na(dataf[, quantitative[i]]),
                                        quantitative[i]],
                                  nbinscs, rangeec)
        g1[g1 == 0] <- 0.000000001 #Smoothing
        g2 <- entropy::discretize(dataf[dataf$`[Type]` == "CS" &
                                          !is.na(dataf[, quantitative[i]]),
                                        quantitative[i]],
                                  nbinscs, rangeec)
        g2[g2 == 0] <- 0.000000001 #Smoothing

        kl <- entropy::KL.plugin(g1, g2)

        avec[[i]] <- paste("<i>D<sub>KL</sub></i> = ",
                           round(kl, 3), sep = "")
        rm(nbinscs, g1, g2, kl)
      }

      if (annotate == "ks") {
        # Kolmogorov-Smirnov distance
        ks <- ks.test(dataf[dataf$`[Type]` == "EC" &
                              !is.na(dataf[, quantitative[i]]),
                            quantitative[i]],
                      dataf[dataf$`[Type]` == "CS" &
                              !is.na(dataf[, quantitative[i]]),
                            quantitative[i]],
                      exact = FALSE)

        avec[[i]] <- paste("<i>D<sub>KS</sub></i> = ",
                           round(ks$statistic, 3), "<sup>",
                           ifelse(ks$p.value <= 0.01, "**",
                                  ifelse(ks$p.value <= 0.05, "*", "ns")),
                           "</sup>", sep = "")

      }

      if (annotate == "ad") {
        # Anderson-Darling distance
        ad <- kSamples::ad.test(dataf[dataf$`[Type]` == "EC" &
                                        !is.na(dataf[, quantitative[i]]),
                                      quantitative[i]],
                                dataf[dataf$`[Type]` == "CS" &
                                        !is.na(dataf[, quantitative[i]]),
                                      quantitative[i]],
                                dist = TRUE)

        avec[[i]] <- paste("<i><i>D<sub>AD</sub></i> = ",
                           round(ad$ad["version 1:", "AD"], 3), "<sup>",
                           ifelse(ad$ad["version 1:",
                                        " asympt. P-value"] <= 0.01, "**",
                                  ifelse(ad$ad["version 1:",
                                               " asympt. P-value"] <= 0.05,
                                         "*",
                                         "ns")),
                           "</sup>", sep = "")
      }
    }
  }


  outlist <- vector(mode = "list", length = length(quantitative))
  names(outlist) <- quantitative

  for (i in seq_along(quantitative)) {
    # Create the quantile-quantile data table
    qqdf <- qqplot(x = dataf[dataf$`[Type]` == "EC" &
                               !is.na(dataf[, quantitative[i]]),
                             quantitative[i]],
                   y = dataf[dataf$`[Type]` == "CS" &
                               !is.na(dataf[, quantitative[i]]),
                             quantitative[i]],
                   plot.it = FALSE)
    qqdf <- as.data.frame(qqdf)

    # Set the x and y limits
    xylim <- range(c(qqdf$x, qqdf$y))

    xlab_val <- "Core Set"
    ylab_val <- "Entire Collection"

    if (show.count) {
      dataf_count <-
        dplyr::summarise(.data = dataf[!is.na(dataf[, quantitative[i]]),],
                         .by = c("[Type]"),
                         Count = dplyr::n(),
                         Mean = mean(get(quantitative[i]), na.rm = TRUE))
      dataf_count[order(dataf_count$`[Type]`), ]

      xlab_val <- paste(xlab_val, "\n(n = ",
                        dataf_count[dataf_count$`[Type]` == "CS", ]$Count, ")",
                        sep = "")
      ylab_val <- paste(ylab_val, "\n(n = ",
                        dataf_count[dataf_count$`[Type]` == "EC", ]$Count, ")",
                        sep = "")

    }

    # Generate the QQ plot
    outlist[[i]] <- ggplot(qqdf, aes(x = x, y = y)) +
      geom_point() +
      geom_abline(intercept = 0, slope = 1) +
      coord_fixed(ratio = 1, xlim = xylim, ylim = xylim) +
      xlab(xlab_val) +
      ylab(ylab_val) +
      ggtitle(quantitative[i]) +
      theme_bw() +
      theme(axis.text = element_text(colour = "black"))


    if (annotate != "none") {
      outlist[[i]] <- outlist[[i]] +
        geom_richtext(x = (.05 * diff(xylim)) + xylim[1],
                      y = (.85 * diff(xylim)) + xylim[1],
                      hjust = 0, size = 3,
                      label = avec[[quantitative[i]]], fill = NA,
                      label.color = NA,
                      label.padding = grid::unit(rep(0, 4), "pt"))
    }

    rm(xylim, qqdf)
  }


  return(outlist)

}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Percentage Difference of Means and Variances
#'
#' Compute the following differences between the entire collection (EC) and core
#' set (CS). \itemize{ \item Percentage of significant differences of mean
#' (\mjteqn{MD\\\%_{Hu}}{MD\\\\\\\%_{Hu}}{MD\%_{Hu}})
#' \insertCite{hu_methods_2000}{EvaluateCore} \item Percentage of significant
#' differences of variance (\mjteqn{VD\\\%_{Hu}}{VD\\\\\\\%_{Hu}}{VD\%_{Hu}})
#' \insertCite{hu_methods_2000}{EvaluateCore} \item Average of absolute
#' differences between means
#' (\mjteqn{MD\\\%_{Kim}}{MD\\\\\\\%_{Kim}}{MD\%_{Kim}})
#' \insertCite{kim_PowerCore_2007}{EvaluateCore} \item Average of absolute
#' differences between variances
#' (\mjteqn{VD\\\%_{Kim}}{VD\\\\\\\%_{Kim}}{VD\%_{Kim}})
#' \insertCite{kim_PowerCore_2007}{EvaluateCore} \item Percentage difference
#' between the mean squared Euclidean distance among accessions
#' (\mjteqn{\overline{d}D\\\%}{\overline{d}D\\\\\\\%}{\overline{d}D\%})
#' \insertCite{studnicki_comparing_2013}{EvaluateCore} \item Percentage of range
#' ratios smaller than 0.70 (\mjseqn{S_{RR_{0.7}}})
#' \insertCite{diwan_methods_1995}{EvaluateCore} }
#'
#' The differences are computed as follows.
#'
#' \mjtdeqn{MD\\\%_{Hu} = \left ( \frac{S_{t}}{n} \right ) \times
#' 100}{MD\\\\\\\%_{Hu} = \left ( \frac{S_{t}}{n} \right ) \times 100}{MD\%_{Hu}
#' = \left ( \frac{S_{t}}{n} \right ) \times 100}
#'
#' Where, \mjseqn{S_{t}} is the number of traits with a significant difference
#' between the means of the EC and the CS and \mjseqn{n} is the total number of
#' traits. A representative core should have
#' \mjteqn{MD\\\%_{Hu}}{MD\\\\\\\%_{Hu}}{MD\%_{Hu}} < 20 \% and \mjseqn{CR} > 80
#' \% \insertCite{hu_methods_2000}{EvaluateCore}.
#'
#' \mjtdeqn{VD\\\%_{Hu} = \left ( \frac{S_{F}}{n} \right ) \times
#' 100}{VD\\\\\\\%_{Hu} = \left ( \frac{S_{F}}{n} \right ) \times 100}{VD\%_{Hu}
#' = \left ( \frac{S_{F}}{n} \right ) \times 100}
#'
#' Where, \mjseqn{S_{F}} is the number of traits with a significant difference
#' between the variances of the EC and the CS and \mjseqn{n} is the total number
#' of traits. Larger \mjteqn{VD\\\%_{Hu}}{VD\\\\\\\%_{Hu}}{VD\%_{Hu}} value
#' indicates a more diverse core set.
#'
#' \mjtdeqn{MD\\\%_{Kim} = \left ( \frac{1}{n}\sum_{i=1}^{n} \frac{\left |
#' M_{EC_{i}}-M_{CS_{i}} \right |}{M_{CS_{i}}} \right ) \times
#' 100}{MD\\\\\\\%_{Kim} = \left ( \frac{1}{n}\sum_{i=1}^{n} \frac{\left |
#' M_{EC_{i}}-M_{CS_{i}} \right |}{M_{CS_{i}}} \right ) \times 100}{MD\%_{Kim} =
#' \left ( \frac{1}{n}\sum_{i=1}^{n} \frac{\left | M_{EC_{i}}-M_{CS_{i}} \right
#' |}{M_{CS_{i}}} \right ) \times 100}
#'
#' Where, \mjseqn{M_{EC_{i}}} is the mean of the EC for the \mjseqn{i}th trait,
#' \mjseqn{M_{CS_{i}}} is the mean of the CS for the \mjseqn{i}th trait and
#' \mjseqn{n} is the total number of traits.
#'
#' \mjtdeqn{VD\\\%_{Kim} = \left ( \frac{1}{n}\sum_{i=1}^{n} \frac{\left |
#' V_{EC_{i}}-V_{CS_{i}} \right |}{V_{CS_{i}}} \right ) \times
#' 100}{VD\\\\\\\%_{Kim} = \left ( \frac{1}{n}\sum_{i=1}^{n} \frac{\left |
#' V_{EC_{i}}-V_{CS_{i}} \right |}{V_{CS_{i}}} \right ) \times 100}{VD\%_{Kim} =
#' \left ( \frac{1}{n}\sum_{i=1}^{n} \frac{\left | V_{EC_{i}}-V_{CS_{i}} \right
#' |}{V_{CS_{i}}} \right ) \times 100}
#'
#' Where, \mjseqn{V_{EC_{i}}} is the variance of the EC for the \mjseqn{i}th
#' trait, \mjseqn{V_{CS_{i}}} is the variance of the CS for the \mjseqn{i}th
#' trait and \mjseqn{n} is the total number of traits.
#'
#' \mjtdeqn{\overline{d}D\\\% =
#' \frac{\overline{d}_{CS}-\overline{d}_{EC}}{\overline{d}_{EC}} \times
#' 100}{\overline{d}D\\\\\\\% =
#' \frac{\overline{d}_{CS}-\overline{d}_{EC}}{\overline{d}_{EC}} \times
#' 100}{\overline{d}D\\% =
#' \frac{\overline{d}_{CS}-\overline{d}_{EC}}{\overline{d}_{EC}} \times 100}
#'
#' Where, \mjseqn{\overline{d}_{CS}} is the mean squared Euclidean distance
#' among accessions in the CS and \mjseqn{\overline{d}_{EC}} is the mean squared
#' Euclidean distance among accessions in the EC.
#'
#' Percentage of range ratios smaller than 0.70
#' \insertCite{diwan_methods_1995}{EvaluateCore} is computed as follows.
#'
#' \mjtdeqn{RR\\\%_{0.7} = \left ( \frac{S_{RR_{0.7}}}{n} \right ) \times
#' 100}{RR\\\\\\\%_{0.7} = \left ( \frac{S_{RR_{0.7}}}{n} \right ) \times
#' 100}{RR\%_{0.7} = \left ( \frac{S_{RR_{0.7}}}{n} \right ) \times 100}
#'
#' Where, \mjseqn{S_{RR_{0.7}}} is the number of traits with a range ratio
#' smaller than 0.7 (\mjteqn{\frac{R_{CS_{i}}}{R_{EC_{i}}} <
#' 0.7}{\frac{R_{CS_{i}}}{R_{EC_{i}}} &lt; 0.7}{(R_CS_i / R_EC_i) < 0.7}).
#' \mjseqn{R_{CS_{i}}} is the range of the \mjseqn{i}th trait in the CS,
#' \mjseqn{R_{EC_{i}}} is the range of the \mjseqn{i}th trait in the EC and
#' \mjseqn{n} is the total number of traits.
#'
#' @inheritParams snk.evaluate.core
#' @param alpha Type I error probability (Significance level) of difference.
#' @param rr.crit The critical value of range ratio considered to be acceptable
#'   for a representative CS. The default value is 0.7.
#'
#' @return A data frame with the values of
#'   \mjteqn{MD\\\%_{Hu}}{MD\\\\\\\%_{Hu}}{MD\%_{Hu}},
#'   \mjteqn{VD\\\%_{Hu}}{VD\\\\\\\%_{Hu}}{VD\%_{Hu}},
#'   \mjteqn{MD\\\%_{Kim}}{MD\\\\\\\%_{Kim}}{MD\%_{Kim}},
#'   \mjteqn{VD\\\%_{Kim}}{VD\\\\\\\%_{Kim}}{VD\%_{Kim}} and
#'   \mjteqn{\overline{d}D\\\%}{\overline{d}D\\\\\\\%}{\overline{d}D\%}.
#'
#' @seealso \code{\link[EvaluateCore]{snk.evaluate.core}},
#'   \code{\link[EvaluateCore]{snk.evaluate.core}}
#'
#' @importFrom cluster daisy
#' @export
#'
#' @references
#'
#' \insertAllCited{}
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                      function(x) factor(as.factor(x)))
#'
#' percentdiff.evaluate.core(data = ec, names = "genotypes",
#'                           quantitative = quant, selected = core)
#'
percentdiff.evaluate.core <- function(data, names, quantitative,
                              selected, alpha = 0.05, rr.crit = 0.7) {
  # Checks
  checks.evaluate.core(data = data, names = names,
                       quantitative = quantitative,
                       selected = selected)

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  # Check alpha value
  if (!(0 < alpha && alpha < 1)) {
    stop('"alpha" should be between 0 and 1 (0 < alpha < 1)')
  }

  # Check rr.crit value
  if (!(0 < rr.crit && rr.crit < 1)) {
    stop('"rr.crit" should be between 0 and 1 (0 < rr.crit < 1)')
  }

  dataf <- data[, c(names, quantitative)]

  datafcore <- dataf[dataf[, names] %in% selected, ]

  dataf$`[Type]` <- "EC"
  datafcore$`[Type]` <- "CS"

  dataf <- rbind(dataf, datafcore)
  rm(datafcore)

  dataf$`[Type]` <- as.factor(dataf$`[Type]`)

  d_EC <- mean(cluster::daisy(dataf[dataf$`[Type]` == "EC", quantitative],
                              metric = "euclidean"))
  d_CS <- mean(cluster::daisy(dataf[dataf$`[Type]` == "CS", quantitative],
                              metric = "euclidean"))

  mdiff <- snk.evaluate.core(data, names, quantitative, selected)
  vdiff <- levene.evaluate.core(data, names, quantitative, selected)

  RR_crit <- length(which(((mdiff$CS_Max - mdiff$CS_Min) /
                             (mdiff$EC_Max - mdiff$EC_Min) < rr.crit) == TRUE))

  outdf <- data.frame(MDPercent_Hu =
                        (sum(mdiff$SNK_pvalue <= alpha) /
                           length(quantitative)) * 100,
                      VDPercent_Hu =
                        (sum(vdiff$Levene_pvalue <= alpha) /
                           length(quantitative)) * 100,
                      MDPercent_Kim =
                        (sum(abs(mdiff$EC_Mean - mdiff$CS_Mean) /
                               mdiff$CS_Mean) / length(quantitative)) * 100,
                      VDPercent_Kim =
                        (sum(abs(vdiff$EC_V - vdiff$CS_V) /
                               vdiff$CS_V) / length(quantitative)) * 100,
                      DDPercent = ((d_CS - d_EC) / d_EC) * 100,
                      RR = (RR_crit / length(quantitative)) * 100)

  return(outdf)

}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Interquartile Range
#'
#' Compute the Interquartile Range (IQR)
#' \insertCite{upton_general_1996}{EvaluateCore} to compare quantitative traits
#' of the entire collection (EC) and core set (CS).
#'
#' @inheritParams snk.evaluate.core
#'
#' @return A data frame with the accession count (excluding missing  data) as
#'   well as the IQR values of the EC and CS for the traits specified as
#'   \code{quantitative}.
#'
#' @seealso \code{\link[stats]{IQR}}
#'
#' @importFrom stats IQR
#' @importFrom tibble as_tibble
#' @export
#'
#' @references
#'
#' \insertAllCited{}
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                      function(x) factor(as.factor(x)))
#'
#' iqr.evaluate.core(data = ec, names = "genotypes",
#'                   quantitative = quant, selected = core)
#'
iqr.evaluate.core <- function(data, names, quantitative, selected) {
  # Checks
  checks.evaluate.core(data = data, names = names,
                       quantitative = quantitative,
                       selected = selected)

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  dataf <- data[, c(names, quantitative)]

  datafcore <- dataf[dataf[, names] %in% selected, ]

  dataf$`[Type]` <- "EC"
  datafcore$`[Type]` <- "CS"

  dataf <- rbind(dataf, datafcore)
  rm(datafcore)

  dataf <- tibble::as_tibble(dataf)

  outdf <- data.frame(`Trait` = quantitative,
                      `Count` = unlist(lapply(dataf[dataf$`[Type]` == "EC",
                                                    quantitative],
                                              function(x) {
                                                sum(!is.na(x))
                                              })),
                      `EC_IQR` = unlist(lapply(dataf[dataf$`[Type]` == "EC",
                                                     quantitative],
                                               stats::IQR, na.rm = TRUE)),
                      `CS_IQR` = unlist(lapply(dataf[dataf$`[Type]` == "CS",
                                                     quantitative],
                                               stats::IQR, na.rm = TRUE)))
  rownames(outdf) <- NULL
  return(outdf)
}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Diversity Indices
#'
#' Compute the following diversity indices and perform corresponding statistical
#' tests to compare the phenotypic diversity for qualitative traits between
#' entire collection (EC) and core set (CS). \itemize{ \item{Simpson's and
#' related indices} \itemize{ \item{Simpson's Index (\mjseqn{d})
#' \insertCite{simpson_measurement_1949,peet_measurement_1974}{EvaluateCore}}
#' \item{Simpson's Index of Diversity or Gini's Diversity Index or Gini-Simpson
#' Index or Nei's Diversity Index or Nei's Variation Index (\mjseqn{D}) or
#' Hurlbert’s probability of interspecific encounter (\mjseqn{PIE})
#' \insertCite{gini_variabilita_1912,gini_variabilita_1912-2,greenberg_measurement_1956,berger_diversity_1970,hurlbert_nonconcept_1971,nei_analysis_1973,peet_measurement_1974}{EvaluateCore}}
#' \item{Maximum Simpson's Index of Diversity or Maximum Nei's
#' Diversity/Variation Index (\mjseqn{D_{max}})
#' \insertCite{hennink_interpretation_1990}{EvaluateCore}} \item{Simpson's
#' Reciprocal Index or Hill's \mjseqn{N_{2}} (\mjseqn{D_{R}}) or Effective
#' number of Species (or Classes) (\mjseqn{ENS_{d}})
#' \insertCite{williams_patterns_1964,hill_diversity_1973}{EvaluateCore}}
#' \item{Relative Simpson's Index of Diversity or Relative Nei's
#' Diversity/Variation Index (\mjseqn{D'})
#' \insertCite{hennink_interpretation_1990}{EvaluateCore}} \item{Simpson’s
#' evenness or equitability (\mjseqn{D_{e}})
#' \insertCite{pielou_measurement_1966,hill_diversity_1973}{EvaluateCore}} }
#' \item{Shannon-Weaver and related indices} \itemize{ \item{Shannon or
#' Shannon-Weaver or Shannon-Wiener Diversity Index or Shannon entropy
#' (\mjseqn{H}) \insertCite{shannon_mathematical_1949,peet_measurement_1974}{EvaluateCore}}
#' \item{Maximum Shannon-Weaver Diversity Index (\mjseqn{H_{max}})
#' \insertCite{hennink_interpretation_1990}{EvaluateCore}} \item{Relative
#' Shannon-Weaver Diversity Index or Shannon Equitability Index (\mjseqn{H'})
#' or Pielou's Evenness (\mjseqn{J})
#' \insertCite{pielou_measurement_1966,hennink_interpretation_1990}{EvaluateCore}}
#' \item{Effective number of species (or Classes) for the Shannon - Weaver
#' Diversity Index (\mjseqn{ENS_{H}}) or Hill's \mjseqn{N_{1}}
#' \insertCite{macarthur_patterns_1965,hill_diversity_1973}{EvaluateCore}} }
#' \item{McIntosh's measures of diversity} \itemize{ \item{McIntosh Diversity
#' Index (\mjseqn{D_{Mc}}) \insertCite{mcintosh_index_1967,peet_measurement_1974}{EvaluateCore}}
#' \item{McIntosh Evenness Index (\mjseqn{E_{Mc}})
#' \insertCite{pielou_Ecological_1975}{EvaluateCore}} } }
#'
#' @section Details: The diversity indices and the corresponding statistical
#'   tests implemented in \code{diversity.evaluate.core} are as follows.
#'
#'   \subsection{Simpson's and Related Indices}{Simpson's index (\mjseqn{d})
#'   which estimates the probability that two accessions randomly selected will
#'   belong to the same phenotypic class of a trait, is computed as follows
#'   \insertCite{simpson_measurement_1949,peet_measurement_1974}{EvaluateCore}.
#'
#'   \mjsdeqn{d = \sum_{i = 1}^{k}p_{i}^{2}}
#'
#'   Where, \mjseqn{p_{i}} denotes the proportion/fraction/frequency of
#'   accessions in the \mjseqn{i}th phenotypic class for a trait and \mjseqn{k}
#'   is the number of phenotypic classes for the trait.
#'
#'   The value of \mjseqn{d} can range from 0 to 1 with 0 representing maximum
#'   diversity and 1, no diversity.
#'
#'   \mjseqn{d} is subtracted from 1 to give Simpson's index of diversity
#'   (\mjseqn{D})
#'   \insertCite{greenberg_measurement_1956,berger_diversity_1970,hurlbert_nonconcept_1971,peet_measurement_1974,hennink_interpretation_1990}{EvaluateCore}
#'    originally suggested by
#'   \insertCite{gini_variabilita_1912,gini_variabilita_1912-2;textual}{EvaluateCore}
#'    and described in literature as Gini's diversity index or Gini-Simpson
#'   index. It is the same as Nei's diversity index or Nei's variation index
#'   \insertCite{nei_analysis_1973,hennink_interpretation_1990}{EvaluateCore}.
#'   Greater the value of \mjseqn{D}, greater the diversity with a range from 0
#'   to 1.
#'
#'   \mjsdeqn{D = 1 - d}
#'
#'   The maximum value of \mjseqn{D}, \mjseqn{D_{max}} occurs when accessions
#'   are uniformly distributed across the phenotypic classes and is computed as
#'   follows \insertCite{hennink_interpretation_1990}{EvaluateCore}.
#'
#'   \mjsdeqn{D_{max} = 1 - \frac{1}{k}}
#'
#'   Reciprocal of \mjseqn{d} gives the Simpson's reciprocal index
#'   (\mjseqn{D_{R}})
#'   \insertCite{williams_patterns_1964,hennink_interpretation_1990}{EvaluateCore}
#'    and can range from 1 to \mjseqn{k}. This was also described in
#'   \insertCite{hill_diversity_1973;textual}{EvaluateCore} as \mjseqn{N_{2}} or
#'   as Effective number of Species (or Classes) (\mjseqn{ENS_{d}}).
#'
#'   \mjsdeqn{D_{R} = \frac{1}{d}}
#'
#'   Relative Simpson's index of diversity or Relative Nei's diversity/variation
#'   index (\mjseqn{H'}) \insertCite{hennink_interpretation_1990}{EvaluateCore}
#'   is defined as follows \insertCite{peet_measurement_1974}{EvaluateCore}.
#'
#'   \mjsdeqn{D' = \frac{D}{D_{max}}}
#'
#'   Simpson’s evenness or equitability (\mjseqn{D_{e}} is described as follows
#'   \insertCite{pielou_measurement_1966,hill_diversity_1973}{EvaluateCore}.
#'
#'   \mjsdeqn{D_{e} = \frac{1}{d \cdot k}}
#'
#'   Differences in Simpson's diversity index for qualitative traits of EC and
#'   CS can be tested by a t-test using the associated variance estimate
#'   described in \insertCite{simpson_measurement_1949;textual}{EvaluateCore}
#'   \insertCite{lyons_c20_1978}{EvaluateCore}.
#'
#'   The t statistic is computed as follows.
#'
#'   \mjsdeqn{t = \frac{d_{EC} - d_{CS}}{\sqrt{V_{d_{EC}} + V_{d_{CS}}}}}
#'
#'   Where, the variance of \mjseqn{d} (\mjseqn{V_{d}}) is,
#'
#'   \mjsdeqn{V_{d} = \frac{4N(N-1)(N-2)\sum_{i=1}^{k}(p_{i})^{3} +
#'   2N(N-1)\sum_{i=1}^{k}(p_{i})^{2} - 2N(N-1)(2N-3) \left(
#'   \sum_{i=1}^{k}(p_{i})^{2} \right)^{2}}{[N(N-1)]^{2}}}
#'
#'   The associated degrees of freedom is computed as follows.
#'
#'   \mjsdeqn{df = (k_{EC} - 1) + (k_{CS} - 1)}
#'
#'   Where, \mjseqn{k_{EC}} and \mjseqn{k_{CS}} are the number of phenotypic
#'   classes in the trait for EC and CS respectively.
#'
#'   }
#'
#'   \subsection{Shannon-Weaver and Related Indices}{An index of information
#'   \mjseqn{H}, was described by
#'   \insertCite{shannon_mathematical_1949;textual}{EvaluateCore} as follows.
#'
#'   \mjsdeqn{H = -\sum_{i=1}^{k}p_{i} \log_{2}(p_{i})}
#'
#'   \mjseqn{H} is described as Shannon or Shannon-Weaver or Shannon-Wiener
#'   diversity index or Shannon entropy in literature
#'   \insertCite{shannon_mathematical_1949,peet_measurement_1974}{EvaluateCore}.
#'
#'   Alternatively, \mjseqn{H} is also computed using natural logarithm instead
#'   of logarithm to base 2.
#'
#'   \mjsdeqn{H = -\sum_{i=1}^{k}p_{i} \ln(p_{i})}
#'
#'   The maximum value of \mjseqn{H} (\mjseqn{H_{max}}) is \mjseqn{\ln(k)}. This
#'   value occurs when each phenotypic class for a trait has the same proportion
#'   of accessions \insertCite{hennink_interpretation_1990}{EvaluateCore}.
#'
#'   \mjsdeqn{H_{max} = \log_{2}(k)\;\; \textrm{OR} \;\; H_{max} = \ln(k)}
#'
#'   The relative Shannon-Weaver diversity index or Shannon equitability index
#'   (\mjseqn{H'}) or Pielou's Evenness (\mjseqn{J}) is the Shannon diversity
#'   index (\mjseqn{I}) divided by the maximum diversity (\mjseqn{H_{max}})
#'   \insertCite{pielou_measurement_1966,hennink_interpretation_1990}{EvaluateCore}.
#'
#'   \mjsdeqn{H' = \frac{H}{H_{max}}}
#'
#'   \insertCite{macarthur_patterns_1965;textual}{EvaluateCore} described the
#'   Effective number of Species (or Classes) for the Shannon index
#'   (\mjseqn{ENS_{H}}) as follows.
#'
#'   \mjsdeqn{ENS_{H} = e^{H}}
#'
#'   Differences in Shannon-Weaver diversity index for qualitative traits of EC
#'   and CS can be tested by Hutcheson t-test
#'   \insertCite{hutcheson_test_1970}{EvaluateCore}.
#'
#'   The Hutcheson t statistic is computed as follows.
#'
#'   \mjsdeqn{t = \frac{H_{EC} - H_{CS}}{\sqrt{V_{H_{EC}} + V_{H_{CS}}}}}
#'
#'   Where, the variance of \mjseqn{H} (\mjseqn{V_{H}}) is,
#'
#'   \mjsdeqn{V_{H} = \frac{\sum_{i=1}^{k}n_{i}(\log_{2}{n_{i}})^{2}
#'   \frac{(\sum_{i=1}^{k}\log_{2}{n_{i}})^2}{N}}{N^{2}}}
#'
#'   \mjsdeqn{\textrm{OR}}
#'
#'   \mjsdeqn{V_{H} = \frac{\sum_{i=1}^{k}n_{i}(\ln{n_{i}})^{2}
#'   \frac{(\sum_{i=1}^{k}\ln{n_{i}})^2}{N}}{N^{2}}}
#'
#'   The associated degrees of freedom is approximated as follows.
#'
#'   \mjsdeqn{df = \frac{(V_{H_{EC}} +
#'   V_{H_{CS}})^{2}}{\frac{V_{H_{EC}}^{2}}{N_{EC}} +
#'   \frac{V_{H_{CS}}^{2}}{N_{CS}}}}
#'
#'   }
#'
#'   \subsection{McIntosh's Measure of Diversity}{A similar index of diversity was
#'   described by \insertCite{mcintosh_index_1967;textual}{EvaluateCore} as
#'   follows (\mjseqn{D_{Mc}}) \insertCite{peet_measurement_1974}{EvaluateCore}.
#'
#'   \mjsdeqn{D_{Mc} = \frac{N - \sqrt{\sum_{i=1}^{k}n_{i}^2}}{N - \sqrt{N}}}
#'
#'   Where, \mjseqn{n_{i}} denotes the number of accessions in the \mjseqn{i}th
#'   phenotypic class for a trait and \mjseqn{N} is the total number of
#'   accessions so that \mjseqn{p_{i} = {n_{i}}/{N}}.}
#'
#'   An additional measure of evenness was proposed by
#'   \insertCite{pielou_Ecological_1975;textual}{EvaluateCore} as follows.
#'
#'   \mjsdeqn{E_{Mc} = \frac{N - \sqrt{\sum_{i=1}^{k}n_{i}^2}}{N -
#'   \frac{N}{\sqrt{S}}}}
#'
#'   \subsection{Testing for difference with bootstrapping}{Bootstrap statistics
#'   are employed to test the difference between the Simpson, Shannon-Weaver and
#'   McIntosh indices for  qualitative traits of EC and CS
#'   \insertCite{solow_simple_1993}{EvaluateCore}.
#'
#'   If \mjseqn{I_{EC}} and \mjseqn{I_{CS}} are the diversity indices with the
#'   original number of accessions, then random samples of the same size as the
#'   original are repeatedly generated (with replacement) \mjseqn{R} times and
#'   the corresponding diversity index is computed for each sample.
#'
#'   \mjsdeqn{I_{EC}^{*} = \lbrace H_{EC_{1}}, H_{EC_{}}, \cdots, H_{EC_{R}}
#'   \rbrace}
#'
#'   \mjsdeqn{I_{CS}^{*} = \lbrace H_{CS_{1}}, H_{CS_{}}, \cdots, H_{CS_{R}}
#'   \rbrace}
#'
#'   Then the bootstrap null sample {\mjseqn{I_{0}}} is computed as follows.
#'
#'   \mjsdeqn{\Delta^{*} = I_{EC}^{*} - I_{CS}^{*}}
#'
#'   \mjsdeqn{I_{0} = \Delta^{*} - \overline{\Delta^{*}}}
#'
#'   Where, \mjseqn{\overline{\Delta^{*}}} is the mean of \mjseqn{\Delta^{*}}.
#'
#'   Now the original difference in diversity indices (\mjseqn{\Delta_{0} =
#'   I_{EC} - I_{CS}}) is tested against mean of bootstrap null sample
#'   (\mjseqn{I_{0}}) by a z test. The z score test statistic is computed as
#'   follows.
#'
#'   \mjsdeqn{z = \frac{\Delta_{0} - \overline{H_{0}}}{\sqrt{V_{H_{0}}}}}
#'
#'   Where,  \mjseqn{\overline{H_{0}}} and \mjseqn{V_{H_{0}}} are the mean and
#'   variance of the bootstrap null sample \mjseqn{H_{0}}.
#'
#'   The corresponding degrees of freedom is estimated as follows.
#'
#'   \mjsdeqn{df = (k_{EC} - 1) + (k_{CS} - 1)}
#'
#'   }
#'
#' @inheritParams chisquare.evaluate.core
#' @param na.omit logical. If \code{TRUE}, missing values (\code{NA}) are
#'   ignored and not included as a distinct factor level for computation.
#'   Default is \code{TRUE}.
#' @param base The logarithm base to be used for computation of Shannon-Weaver
#'   Diversity Index (\mjseqn{I}). Default is 2.
#' @param R The number of bootstrap replicates. Default is 1000.
#'
#' @return A list with three data frames as follows. \item{simpson}{
#'   \describe{\item{Trait}{The qualitative trait.}
#'   \item{EC_No.Classes}{The number of classes in the trait for EC.}
#'   \item{CS_No.Classes}{The number of classes in the trait for CS.}
#'   \item{EC_d}{The Simpson's Index (\mjseqn{d}) for EC.}
#'   \item{EC_D}{The Simpson's Index of Diversity (\mjseqn{D}) for EC.}
#'   \item{EC_D.max}{The Maximum Simpson's Index of Diversity
#'   (\mjseqn{D_{max}}) for EC.} \item{EC_D.inv}{The Simpson's Reciprocal
#'   Index (\mjseqn{D_{R}}) for EC.} \item{EC_D.rel}{The Relative
#'   Reciprocal Index (\mjseqn{D'}) for EC.} \item{EC_D.e}{The Shannon's
#'   evenness or equitability (\mjseqn{D_{e}}) for EC.} \item{EC_d.V}{The
#'   variance of \mjseqn{d} for EC according to
#'   \insertCite{simpson_measurement_1949}{EvaluateCore}.}
#'   \item{EC_d.boot.V}{The bootstrap variance of \mjseqn{d} for EC.}
#'   \item{CS_d}{The Simpson's Index (\mjseqn{d}) for CS.}
#'   \item{CS_D}{The Simpson's Index of Diversity (\mjseqn{D}) for CS.}
#'   \item{CS_D.max}{The Maximum Simpson's Index of Diversity
#'   (\mjseqn{D_{max}}) for CS.} \item{CS_D.inv}{The Simpson's Reciprocal
#'   Index (\mjseqn{D_{R}}) for CS.} \item{CS_D.rel}{The Relative
#'   Reciprocal Index (\mjseqn{D'}) for CS.} \item{CS_D.e}{The Shannon's
#'   evenness or equitability (\mjseqn{D_{e}}) for CS.} \item{CS_d.V}{The
#'   variance of \mjseqn{d} for CS according to
#'   \insertCite{simpson_measurement_1949}{EvaluateCore}.}
#'   \item{CS_d.boot.V}{The bootstrap variance of \mjseqn{d} for CS.}
#'   \item{d.t.df}{The degrees of freedom for t test.}
#'   \item{d.t.stat}{The t statistic.} \item{d.t.pvalue}{The p
#'   value for t test.} \item{d.t.significance}{The  significance of t
#'   test for t-test} \item{d.boot.z.df}{The degrees of freedom for
#'   bootstrap z score.} \item{d.boot.z.stat}{The bootstrap z score.}
#'   \item{d.boot.z.pvalue}{The p value of z score.}
#'   \item{d.boot.z.significance}{The significance of z score.}} }
#'   \item{shannon}{ \describe{\item{Trait}{The qualitative
#'   trait.} \item{EC_No.Classes}{The number of classes in the trait for
#'   EC.} \item{CS_No.Classes}{The number of classes in the trait for
#'   CS.} \item{EC_I}{The Shannon-Weaver Diversity Index (\mjseqn{I}) for
#'   EC.} \item{EC_I.max}{The Maximum Shannon-Weaver Diversity Index
#'   (\mjseqn{I_{max}}) for EC.} \item{EC_I.rel}{The Relative
#'   Shannon-Weaver Diversity Index (\mjseqn{I'}) for EC.} \item{EC_I.ens}{The
#'   Effective Number of Species (or Classes) for Shannon-Weaver Diversity Index
#'   (\mjseqn{ENS_{H}}) for EC} \item{EC_I.V}{The variance of \mjseqn{I} for EC
#'   according to \insertCite{hutcheson_test_1970}{EvaluateCore}.}
#'   \item{EC_I.boot.V}{The bootstrap variance of \mjseqn{I} for EC.}
#'   \item{CS_I}{The Shannon-Weaver Diversity Index (\mjseqn{I}) for CS.}
#'   \item{CS_I.max}{The Maximum Shannon-Weaver Diversity Index
#'   (\mjseqn{I_{max}}) for CS.} \item{CS_I.rel}{The Relative
#'   Shannon-Weaver Diversity Index (\mjseqn{I'}) for CS.} \item{CS_I.ens}{The
#'   Effective Number of Species (or Classes) for Shannon-Weaver Diversity Index
#'   (\mjseqn{ENS_{H}}) for CS.} \item{CS_I.V}{The variance of \mjseqn{I} for
#'   CS according to \insertCite{hutcheson_test_1970}{EvaluateCore}.}
#'   \item{CS_I.boot.V}{The bootstrap variance of \mjseqn{I} for CS.}
#'   \item{I.t.stat}{The t statistic.} \item{I.t.df}{The degrees
#'   of freedom for t test.} \item{I.t.pvalue}{The p value for t test.}
#'   \item{I.t.significance}{The  significance of t test for t-test}
#'   \item{I.boot.z.df}{The degrees of freedom for bootstrap z score.}
#'   \item{I.boot.z.stat}{The bootstrap z score.}
#'   \item{I.boot.z.pvalue}{The p value of z score.}
#'   \item{I.boot.z.significance}{The significance of z score.}} }
#'   \item{mcintosh}{ \describe{\item{EC_No.Classes}{The number of
#'   classes in the trait for EC.} \item{CS_No.Classes}{The number of
#'   classes in the trait for CS.} \item{EC_D.Mc}{The McIntosh Diversity Index
#'   (\mjseqn{D_{Mc}}) for EC.} \item{EC_E.Mc}{The McIntosh Evenness Index
#'   (\mjseqn{E_{Mc}}) for EC.} \item{CS_D.Mc}{The McIntosh Diversity Index
#'   (\mjseqn{D_{Mc}}) for CS.} \item{CS_E.Mc}{The McIntosh Evenness Index
#'   (\mjseqn{E_{Mc}}) for CS.} \item{M.boot.z.stat}{The bootstrap z
#'   score.} \item{M.boot.z.df}{The degrees of freedom for bootstrap z
#'   score.} \item{M.boot.z.pvalue}{The p value of z score.}
#'   \item{M.boot.z.significance}{The significance of z score.}} }
#'
#' @seealso \code{\link[psych:misc]{shannon}}, \code{\link[vegan]{diversity}},
#'   \code{\link[boot]{boot}}
#'
#' @importFrom boot boot
#' @importFrom stats pt
#' @export
#'
#' @references
#'
#' \insertAllCited{}
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                      function(x) factor(as.factor(x)))
#'
#' \donttest{
#' diversity.evaluate.core(data = ec, names = "genotypes",
#'                         qualitative = qual, selected = core)
#' }
#'
diversity.evaluate.core <- function(data, names, qualitative, selected,
                                    base = 2, R = 1000, na.omit = TRUE) {

  # Checks
  checks.evaluate.core(data = data, names = names,
                       qualitative = qualitative,
                       selected = selected)

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  dataf <- data[, c(names, qualitative)]

  datafcore <- dataf[dataf[, names] %in% selected, ]

  dataf$`[Type]` <- "EC"
  datafcore$`[Type]` <- "CS"

  dataf <- rbind(dataf, datafcore)
  rm(datafcore)

  dataf$`[Type]` <- as.factor(dataf$`[Type]`)

  if (!na.omit) {
    dataf[, qualitative] <- lapply(dataf[, qualitative], function(x) {
      if (any(is.na(x))) {
        addNA(x)
      } else {
        x
      }
    })
  }

  dataf <- tibble::as_tibble(dataf)

  div.indices <- lapply(dataf[, !colnames(dataf) %in% c(names, "[Type]")],
                        function(x) {
                          diversity.test(ECx = x[dataf$`[Type]` == "EC"],
                                         CSx = x[dataf$`[Type]` == "CS"],
                                         base = base, R = R)
                        })

  simpson <- do.call(rbind,
                     lapply(div.indices,
                            function(x) {x[["simpson"]]}))
  shannon <- do.call(rbind,
                     lapply(div.indices,
                            function(x) {x[["shannon"]]}))
  mcintosh <- do.call(rbind,
                      lapply(div.indices,
                             function(x) {x[["mcintosh"]]}))

  out <- list(simpson = data.frame(simpson),
              shannon = data.frame(shannon),
              mcintosh = data.frame(mcintosh))

  out <- lapply(out, function(x) {
    x$Trait <- rownames(x)
    rownames(x) <- NULL
    cols <- setdiff(colnames(x), "Trait")
    x <- x[, c("Trait", cols)]
  })

  return(out)

}


diversity.test <- function(ECx, CSx, base = 2, R = 1000) {
  if (is.factor(ECx) && is.factor(CSx)) {

    x1 <- droplevels(ECx)
    x2 <- droplevels(CSx)

    count1 <- as.vector(table(x1))
    total.count1 <- sum(count1, na.rm = TRUE)

    count2 <- as.vector(table(x2))
    total.count2 <- sum(count2, na.rm = TRUE)

    k1 <- length(count1)
    k2 <- length(count2)

    prob1 <- count1 / total.count1
    prob2 <- count2 / total.count2

    total.count <- total.count1 + total.count2

    # Simpson's Index (d)
    #---------------------------------------------------------------------------

    EC_d <- sum(prob1 ^ 2)
    CS_d <- sum(prob2 ^ 2)

    # EC_d <- sum(count1 * (count1 - 1)) / (total.count1 * (total.count1 - 1))
    # CS_d <- sum(count2 * (count2 - 1)) / (total.count2 * (total.count2 - 1))

    # Simpson's Index of Diversity (D) / Gini-Simpson Index (D)
    #---------------------------------------------------------------------------

    EC_D <- 1 - EC_d
    CS_D <- 1 - CS_d

    # Max Simpson's index of diversity
    #---------------------------------------------------------------------------

    EC_D.max <- 1 - (1 / k1)
    CS_D.max <- 1 - (1 / k2)

    # Reciprocal Simpson's Index
    #---------------------------------------------------------------------------

    EC_D.inv <- 1 / EC_d
    CS_D.inv <- 1 / CS_d

    # Relative Simpson's Index
    #---------------------------------------------------------------------------

    EC_D.rel <- EC_D / EC_D.max
    CS_D.rel <- CS_D / CS_D.max

    # Simpson's evenness
    #---------------------------------------------------------------------------

    EC_D.e <- 1 / (EC_D * k1)
    CS_D.e <- 1 / (CS_D * k2)

    # t-test for Simpson's Index
    #---------------------------------------------------------------------------

    EC_d.V <- ((4 * total.count1 * (total.count1 - 1) *
                  (total.count1 - 2) * sum(prob1 ^ 3)) +
                 (2 * total.count1 * (total.count1 - 1) * sum(prob1 ^ 2)) -
                 (2 * total.count1 * (total.count1 - 1) *
                    ((2 * total.count1) - 3) * (sum(prob1 ^ 2) ^ 2))) /
      ((total.count1 * (total.count1 - 1)) ^ 2)
    CS_d.V <- ((4 * total.count2 * (total.count2 - 1) *
                  (total.count2 - 2) * sum(prob2 ^ 3)) +
                 (2 * total.count2 * (total.count2 - 1) * sum(prob2 ^ 2)) -
                 (2 * total.count2 * (total.count2 - 1) *
                    ((2 * total.count2) - 3) * (sum(prob2 ^ 2) ^ 2))) /
      ((total.count2 * (total.count2 - 1)) ^ 2)

    # EC_d.V <- (4 / total.count1) * (sum(prob2 ^ 3) - (sum(prob2 ^ 2) ^ 2))
    # CS_d.V <- (4 / total.count2) * (sum(prob2 ^ 3) - (sum(prob2 ^ 2) ^ 2))

    # d.t.df <- (total.count1 - 1) + (total.count2 - 1)
    d.t.df <- (k1 - 1) + (k2 - 1)
    d.t.stat <- (EC_d - CS_d) / (sqrt(EC_d.V + CS_d.V))
    d.t.pvalue <- 2 * pt(-abs(d.t.stat), d.t.df)

    # Bootstrap test for Simpson's Index
    #---------------------------------------------------------------------------

    simpson.boot <- function(data, i) {
      data <- data[i]
      data <- droplevels(data)

      count <- as.vector(table(data))
      total.count <- sum(count, na.rm = TRUE)

      prob <- count / total.count

      sum(prob ^ 2)
    }

    EC_d.boot <- boot(data = x1,
                      statistic = simpson.boot,
                      R = 1000)

    CS_d.boot <-  boot(data = x2,
                       statistic = simpson.boot,
                       R = 1000)

    EC_d.boot.V <- as.vector(var(EC_d.boot$t))
    CS_d.boot.V <- as.vector(var(CS_d.boot$t))

    d.diff0 <- abs(EC_d.boot$t0 - CS_d.boot$t0)
    d.diff <- EC_d.boot$t - CS_d.boot$t
    d.H0 <- d.diff - mean(d.diff)

    d.boot.z.stat <- (d.diff0 - mean(d.H0)) / sd(d.H0)
    # d.boot.z.df <- (total.count1 - 1) + (total.count2 - 1)
    d.boot.z.df <- (k1 - 1) + (k2 - 1)
    d.boot.z.pvalue <- 2 * pt(-abs(d.boot.z.stat), d.boot.z.df)

    # Shannon-Wiener Diversity Index (H)
    #---------------------------------------------------------------------------

    EC_I <- - sum(prob1 * log(prob1, base = base))
    CS_I <- - sum(prob2 * log(prob2, base = base))

    # Maximum Shannon-Weaver Diversity Index
    #---------------------------------------------------------------------------

    EC_I.max <- log(k1)
    CS_I.max <- log(k2)

    # Relative Shannon-Weaver Diversity Index
    #---------------------------------------------------------------------------

    EC_I.rel <- EC_I / EC_I.max
    CS_I.rel <- CS_I / CS_I.max

    # Effective number of species (or Classes)
    #---------------------------------------------------------------------------

    EC_I.ens <- exp(EC_I)
    CS_I.ens <- exp(CS_I)

    # Hutcheson t-test (Shannon-Weaver Index)
    #---------------------------------------------------------------------------

    EC_I.V <- ((sum(count1 * ((log(count1, base = base)) ^ 2))) -
                 (((sum(count1 * log(count1, base = base))) ^ 2) /
                    total.count1)) /
      (total.count1 ^ 2)
    CS_I.V <- ((sum(count2 * ((log(count2, base = base)) ^ 2))) -
                 (((sum(count2 * log(count2, base = base))) ^ 2) /
                    total.count2)) /
      (total.count2 ^ 2)

    I.t.stat <- (EC_I - CS_I) / (sqrt(EC_I.V + CS_I.V))
    I.t.df <- ((EC_I.V + CS_I.V) ^ 2) /
      (((EC_I.V ^ 2) / total.count1) + ((CS_I.V ^ 2) / total.count2))
    I.t.pvalue <- 2 * pt(-abs(I.t.stat), I.t.df)


    # Bootstrap test (Shannon Weaver Index)
    #---------------------------------------------------------------------------

    shannon.boot <- function(data, i, base) {
      data <- data[i]
      data <- droplevels(data)

      count <- as.vector(table(data))
      total.count <- sum(count, na.rm = TRUE)

      prob <- count / total.count

      - sum(prob * log(prob, base = base))
    }

    EC_I.boot <- boot(data = x1,
                      statistic = shannon.boot,
                      R = 1000,
                      base = base)

    CS_I.boot <-  boot(data = x2,
                       statistic = shannon.boot,
                       R = 1000,
                       base = base)

    EC_I.boot.V <- as.vector(var(EC_I.boot$t))
    CS_I.boot.V <- as.vector(var(CS_I.boot$t))

    I.diff0 <- abs(EC_I.boot$t0 - CS_I.boot$t0)
    I.diff <- EC_I.boot$t - CS_I.boot$t
    I.H0 <- I.diff - mean(I.diff)

    I.boot.z.stat <- (I.diff0 - mean(I.H0)) / sd(I.H0)
    # I.boot.z.df <- (total.count1 - 1) + (total.count2 - 1)
    I.boot.z.df <- (k1 - 1) + (k2 - 1)
    I.boot.z.pvalue <- 2 * pt(-abs(I.boot.z.stat), I.boot.z.df)

    # McIntosh Index
    #---------------------------------------------------------------------------

    EC_D.Mc <- (total.count1 - sqrt(sum(count1 ^ 2))) /
      (total.count1 - sqrt(total.count1))
    CS_D.Mc <- (total.count2 - sqrt(sum(count2 ^ 2))) /
      (total.count2 - sqrt(total.count2))

    # McIntosh Evenness
    #---------------------------------------------------------------------------

    EC_E.Mc <- (total.count1 - sqrt(sum(count1 ^ 2))) /
      (total.count1 - (total.count1 / k1))
    CS_E.Mc <- (total.count2 - sqrt(sum(count2 ^ 2))) /
      (total.count2 - (total.count2 / k2))

    # Bootstrap test (McIntosh Index)
    #---------------------------------------------------------------------------

    mcintosh.boot <- function(data, i) {
      data <- data[i]
      data <- droplevels(data)

      count <- as.vector(table(data))
      total.count <- sum(count, na.rm = TRUE)

      (total.count - sqrt(sum(count ^ 2))) /
        (total.count - sqrt(total.count))
    }

    EC_M.boot <- boot(data = x1,
                      statistic = mcintosh.boot,
                      R = 1000)

    CS_M.boot <- boot(data = x2,
                      statistic = mcintosh.boot,
                      R = 1000)

    M.diff0 <- abs(EC_M.boot$t0 - CS_M.boot$t0)
    M.diff <- EC_M.boot$t - CS_M.boot$t
    M.H0 <- M.diff - mean(M.diff)

    M.boot.z.stat <- (M.diff0 - mean(M.H0)) / sd(M.H0)
    # M.boot.z.df <- (total.count1 - 1) + (total.count2 - 1)
    M.boot.z.df <- (k1 - 1) + (k2 - 1)
    M.boot.z.pvalue <- 2 * pt(-abs(M.boot.z.stat), M.boot.z.df)

    #---------------------------------------------------------------------------

    out <- list(simpson = c(EC_No.Classes = k1,
                            CS_No.Classes = k2,
                            EC_d = EC_d,
                            EC_D = EC_D,
                            EC_D.max = EC_D.max,
                            EC_D.inv = EC_D.inv,
                            EC_D.rel = EC_D.rel,
                            EC_D.e = EC_D.e,
                            EC_d.V = EC_d.V,
                            EC_d.boot.V = EC_d.boot.V,
                            CS_d = CS_d,
                            CS_D = CS_D,
                            CS_D.max = CS_D.max,
                            CS_D.inv = CS_D.inv,
                            CS_D.rel = CS_D.rel,
                            CS_D.e = CS_D.e,
                            CS_d.V = CS_d.V,
                            CS_d.boot.V = CS_d.boot.V,
                            d.t.df = d.t.df,
                            d.t.stat = d.t.stat,
                            d.t.pvalue = d.t.pvalue,
                            d.t.significance = ifelse(d.t.pvalue <= 0.01, "**",
                                                      ifelse(d.t.pvalue <= 0.05,
                                                             "*", "ns")),
                            d.boot.z.df = d.boot.z.df,
                            d.boot.z.stat = d.boot.z.stat,
                            d.boot.z.pvalue = d.boot.z.pvalue,
                            d.boot.z.significance = ifelse(d.boot.z.pvalue <= 0.01,
                                                           "**",
                                                           ifelse(d.boot.z.pvalue <= 0.05,
                                                                  "*", "ns"))),
                shannon = c(EC_No.Classes = k1,
                            CS_No.Classes = k2,
                            EC_I = EC_I,
                            EC_I.max = EC_I.max,
                            EC_I.rel = EC_I.rel,
                            EC_I.ens = EC_I.ens,
                            EC_I.V = EC_I.V,
                            EC_I.boot.V = EC_I.boot.V,
                            CS_I = CS_I,
                            CS_I.max = CS_I.max,
                            CS_I.rel = CS_I.rel,
                            CS_I.ens = CS_I.ens,
                            CS_I.V = CS_I.V,
                            CS_I.boot.V = CS_I.boot.V,
                            I.t.stat = I.t.stat,
                            I.t.df = I.t.df,
                            I.t.pvalue = I.t.pvalue,
                            I.t.significance = ifelse(I.t.pvalue <= 0.01, "**",
                                                      ifelse(I.t.pvalue <= 0.05,
                                                             "*", "ns")),
                            I.boot.z.df = I.boot.z.df,
                            I.boot.z.stat = I.boot.z.stat,
                            I.boot.z.pvalue = I.boot.z.pvalue,
                            I.boot.z.significance = ifelse(I.boot.z.pvalue <= 0.01, "**",
                                                           ifelse(I.boot.z.pvalue <= 0.05,
                                                                  "*", "ns"))),
                mcintosh = c(EC_No.Classes = k1,
                             CS_No.Classes = k2,
                             EC_D.Mc = EC_D.Mc,
                             EC_E.Mc = EC_E.Mc,
                             CS_D.Mc = CS_D.Mc,
                             CS_E.Mc = CS_E.Mc,
                             M.boot.z.stat = M.boot.z.stat,
                             M.boot.z.df = M.boot.z.df,
                             M.boot.z.pvalue = M.boot.z.pvalue,
                             M.boot.z.significance = ifelse(M.boot.z.pvalue <= 0.01, "**",
                                                            ifelse(M.boot.z.pvalue <= 0.05,
                                                                   "*", "ns"))))

    return(out)

  } else{
    stop('"ECx" and "CSx" should be vectors of type factor.')
  }
}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Box Plots
#'
#' Plot Box-and-Whisker plots
#' \insertCite{tukey_exploratory_1970,mcgill_variations_1978}{EvaluateCore} to
#' graphically compare the probability distributions of quantitative traits
#' between entire collection (EC) and core set (CS).
#'
#' @inheritParams snk.evaluate.core
#' @param show.count logical. If \code{TRUE}, the accession count excluding
#'   missing values will also be displayed. Default is \code{FALSE}.
#'
#' @return A list with the \code{ggplot} objects of box plots of CS and EC for
#'   each trait specified as \code{quantitative}.
#'
#' @seealso \code{\link[graphics]{boxplot}}, \code{\link[ggplot2]{geom_boxplot}}
#'
#' @importFrom dplyr summarise n
#' @import ggplot2
#' @export
#'
#' @references
#'
#' \insertAllCited{}
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                      function(x) factor(as.factor(x)))
#'
#' \donttest{
#' box.evaluate.core(data = ec, names = "genotypes",
#'                   quantitative = quant, selected = core)
#'
#' box.evaluate.core(data = ec, names = "genotypes",
#'                   quantitative = quant, selected = core, show.count = TRUE)
#' }
#'
box.evaluate.core <- function(data, names, quantitative, selected,
                              show.count = FALSE) {
  # Checks
  checks.evaluate.core(data = data, names = names,
                       quantitative = quantitative,
                       selected = selected)

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  dataf <- data[, c(names, quantitative)]

  datafcore <- dataf[dataf[, names] %in% selected, ]

  dataf$`[Type]` <- "EC"
  datafcore$`[Type]` <- "CS"

  dataf <- rbind(dataf, datafcore)
  rm(datafcore)

  outlist <- vector(mode = "list", length = length(quantitative))
  names(outlist) <- quantitative

  # quantitative2 <- paste("`", quantitative, "`", sep = "")

  for (i in seq_along(quantitative)) {

    if (show.count) {
      dataf_count <-
        dplyr::summarise(.data = dataf[!is.na(dataf[, quantitative[i]]),],
                         .by = c("[Type]"),
                         Count = dplyr::n(),
                         Mean = mean(get(quantitative[i]), na.rm = TRUE))
      dataf_count <- dataf_count[order(dataf_count$`[Type]`), ]
    }

    # Generate the box plot
    outlist[[i]] <- ggplot(dataf[!is.na(dataf[, quantitative[i]]), ],
                           aes(y = .data[[quantitative[i]]], x = `[Type]`)) +
      geom_boxplot(fill = "lemonchiffon") +
      stat_summary(fun = mean, geom = "point",
                   shape = 18, size = 3, color = "red", na.rm = TRUE) +
      xlab("Collection") +
      ylab(quantitative[i]) +
      theme_bw() +
      theme(axis.text = element_text(colour = "black"))

    if (show.count) {
      outlist[[i]] <-
        outlist[[i]] +
        scale_x_discrete(labels = paste(dataf_count$`[Type]`,
                                        "\n(n = ", dataf_count$Count, ")",
                                        sep = ""))
      rm(dataf_count)
    }

  }

  return(outlist)

}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Shannon-Weaver Diversity Index
#'
#' Compute the Shannon-Weaver Diversity Index (\mjseqn{H'}), Maximum diversity
#' (\mjseqn{H'_{max}}) and Shannon Equitability Index (\mjseqn{E_{H}})
#' \insertCite{shannon_mathematical_1949}{EvaluateCore} to compare the
#' phenotypic diversity for qualitative traits between entire collection (EC)
#' and core set (CS).
#'
#' Shannon-Weaver Diversity Index (\mjseqn{H'}) is computed as follows.
#'
#' \mjsdeqn{H' = -\sum_{i=1}^{k}p_{i} \ln(p_{i})}
#'
#' Where \mjseqn{p_{i}} denotes the proportion in the group \mjseqn{k}.
#'
#' The maximum value of the index (\mjseqn{H'_{max}}) is \mjseqn{\ln(k)}. This
#' value occurs when each group has the same frequency.
#'
#' The Shannon equitability index (\mjseqn{E_{H}}) is the Shannon diversity
#' index divided by the maximum diversity.
#'
#' \mjsdeqn{E_{H} = \frac{H'}{\ln{(k)}}}
#'
#'
#' @return A data frame with the following columns. \item{Trait}{The qualitative
#'   trait.} \item{EC_H}{The Shannon-Weaver Diversity Index (\mjseqn{H'}) for
#'   EC.} \item{EC_H}{The Shannon-Weaver Diversity Index (\mjseqn{H'}) for CS.}
#'   \item{EC_Hmax}{The Maximum diversity value (\mjseqn{H'_{max}}) for EC.}
#'   \item{CS_Hmax}{The Maximum diversity value (\mjseqn{H'_{max}}) for CS.}
#'   \item{EC_EH}{The Shannon Equitability Index (\mjseqn{E_{H}}) for EC.}
#'   \item{CS_EH}{The Shannon Equitability Index (\mjseqn{E_{H}}) for CS.}
#'
#' @seealso \code{\link[psych:misc]{shannon}}
#'
#' @importFrom psych shannon
#' @importFrom dplyr bind_rows
#'
#' @references
#'
#' \insertAllCited{}
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                      function(x) factor(as.factor(x)))
#'
#' shannon.evaluate.core(data = ec, names = "genotypes",
#'                       qualitative = qual, selected = core)
#'
#' @name shannon.evaluate.core-deprecated
#' @usage shannon.evaluate.core(data, names, qualitative, selected)
#' @seealso \code{\link{EvaluateCore-deprecated}}
#' @keywords internal
NULL

#' @rdname EvaluateCore-deprecated
#' @section \code{shannon.evaluate.core}:
#' For \code{shannon.evaluate.core}, use \code{\link{diversity.evaluate.core}}.
#'
#' @export
shannon.evaluate.core <- function(data, names, qualitative, selected) {

  .Deprecated("diversity.evaluate.core",
              msg = c("`shannon.evaluate.core()` was deprecated in EvaluateCore 0.1.3.\n",
                      "Please use `diversity.evaluate.core()` instead."))

  # Checks
  checks.evaluate.core(data = data, names = names,
                       qualitative = qualitative,
                       selected = selected)

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  dataf <- data[, c(names, qualitative)]

  datafcore <- dataf[dataf[, names] %in% selected, ]

  dataf$`[Type]` <- "EC"
  datafcore$`[Type]` <- "CS"

  dataf <- rbind(dataf, datafcore)
  rm(datafcore)

  dataf$`[Type]` <- as.factor(dataf$`[Type]`)

  # dataf[, qualitative] <- lapply(dataf[, qualitative], as.integer)

  EC_H <- psych::shannon(dataf[dataf$`[Type]` == "EC",
                               !colnames(dataf) %in% c(names, "[Type]")],
                         base =  exp(1), correct = FALSE)
  CS_H <- psych::shannon(dataf[dataf$`[Type]` == "CS",
                               !colnames(dataf) %in% c(names, "[Type]")],
                         base =  exp(1), correct = FALSE)

  EC_EH <- psych::shannon(dataf[dataf$`[Type]` == "EC",
                                !colnames(dataf) %in% c(names, "[Type]")],
                         base =  exp(1), correct = TRUE)
  CS_EH <- psych::shannon(dataf[dataf$`[Type]` == "CS",
                                !colnames(dataf) %in% c(names, "[Type]")],
                          base =  exp(1), correct = TRUE)

  EC_No.Classes <- unlist(lapply(dataf[dataf$`[Type]` == "EC",
                                       !colnames(dataf) %in% c(names,
                                                               "[Type]")],
                          function(x) length(levels(droplevels(x)))))
  CS_No.Classes <- unlist(lapply(dataf[dataf$`[Type]` == "CS",
                                       !colnames(dataf) %in% c(names,
                                                               "[Type]")],
                          function(x) length(levels(droplevels(x)))))

  outdf <- cbind(EC_H = EC_H[qualitative],
                 CS_H = CS_H[qualitative],
                 EC_Hmax = log(EC_No.Classes[qualitative]),
                 CS_Hmax = log(CS_No.Classes[qualitative]),
                 EC_EH = EC_EH[qualitative],
                 CS_EH = CS_EH[qualitative])
  outdf <- data.frame(outdf)

  outdf$Trait <- rownames(outdf)
  rownames(outdf) <- NULL
  cols <- setdiff(colnames(outdf), "Trait")
  outdf <- outdf[, c("Trait", cols)]

  return(outdf)

}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Common checks for all functions
#'
#' Not exported. Strictly internal
#'
#' @keywords internal
#'
#' @inheritParams snk.evaluate.core
#' @inheritParams chisquare.evaluate.core
#
checks.evaluate.core <- function(data, names, quantitative = NULL,
                                 qualitative = NULL, selected) {
  # check if 'data' is a data frame object
  if (!is.data.frame(data)) {
    stop('"data" should be a data frame object.')
  }

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame.')
    data <- as.data.frame(data)
  }

  # check if 'names' argument is character vector of unit length
  if (!(is.character(names) && length(names) == 1)) {
    stop('"names" should be a character vector of unit length.')
  }

  # check if 'quantitative' argument is a character vector
  if (!is.null(quantitative)) {
    if (!is.character(quantitative)) {
      stop('"quantitative" should be a character vector.')
    }
  }

  # check if 'qualitative' argument is a character vector
  if (!is.null(qualitative)) {
    if (!is.character(qualitative)) {
      stop('"qualitative" should be a character vector.')
    }
  }

  # check if 'names' column is present in 'data'
  if (!(names %in% colnames(data))) {
    stop(paste('Column ', names,
               ' specified as the "names" column is not present in "data".',
               sep = ""))
  }

  # check if 'quantitative' columns are present in 'data'
  if (!is.null(quantitative)) {
    if (FALSE %in% (quantitative %in% colnames(data)))  {
      stop(paste('The following column(s) specified in "quantitative" are not present in "data":\n',
                 paste(quantitative[!(quantitative %in% colnames(data))],
                       collapse = ", "),
                 sep = ""))
    }
  }

  # check if 'qualitative' columns are present in 'data'
  if (!is.null(qualitative)) {
    if (FALSE %in% (qualitative %in% colnames(data)))  {
      stop(paste('The following column(s) specified in "qualitative" are not present in "data":\n',
                 paste(qualitative[!(qualitative %in% colnames(data))],
                       collapse = ", "),
                 sep = ""))
    }
  }

  # check if overlap exists between 'quantitative' and 'qualitative'
  if ((!is.null(quantitative)) & (!is.null(qualitative))) {
    if (length(intersect(quantitative, qualitative)) != 0) {
      stop(paste('The following column(s) is/are specified in both "quantitative" and "qualitative":\n',
                 paste(intersect(quantitative, qualitative),
                       collapse = ", "),
                 sep = ""))
    }
  }

  # check if 'names' column is of type character
  if (!is.character(data[, names])) {
    stop('"names" column in "data" should be of type character.')
  }

  # check if 'quantitative' columns are of type numeric/integer
  if (!is.null(quantitative)) {
    intquantcols <- unlist(lapply(data[, quantitative],
                                  function(x) FALSE %in% (is.vector(x, mode = "integer") | is.vector(x, mode = "numeric"))))
    if (TRUE %in% intquantcols) {
      stop(paste('The following "quantitative" column(s) in "data" are not of type numeric:\n',
                 paste(names(intquantcols[intquantcols]), collapse = ", ")))
    }
  }

  # check if 'qualitative' columns are of type factor
  if (!is.null(qualitative)) {
    intqualcols <- unlist(lapply(data[, qualitative],
                                 function(x) is.factor(x)))
    if (FALSE %in% intqualcols) {
      stop(paste('The following "qualitative" column(s) in "data" are not of type factor:\n',
                 paste(names(intqualcols[!intqualcols]), collapse = ", ")))
    }
  }

  # check if 'selected' is a vector of type character
  if (!is.vector(selected, mode = "character")) {
    stop('"selected" should be a character vector.')
  }

  # check if selected > entire collection
  if (length(selected) > nrow(data)) {
    stop('"selected" is more than the number of records in "data".')
  }

  # check if 'selected' present in 'names' column
  if (!all(selected %in% data[, names])) {
    stop('All "selected" not present in "names" column of "data".')
  }

  # check for missing values
  missvcols <- unlist(lapply(data[, quantitative],
                             function(x) TRUE %in% is.na(x)))
  if (TRUE %in% missvcols) {
    warning(paste('The following column(s) in "data" have missing values:\n',
               paste(names(missvcols[missvcols]), collapse = ", ")))
  }

  # check for duplication in names
  if (any(duplicated(data[, names]))) {
    warning('Duplicated entries exist in "names" column.')
  }
}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/

#' IITA Cassava Germplasm Data - Core Collection
#'
#' An example germplasm characterisation data of a core collection generated
#' from 1591 accessions of IITA Cassava collection
#' \insertCite{international_institute_of_tropical_agriculture_cassava_2019}{EvaluateCore}
#' using 10 quantitative and 48 qualitative trait data with CoreHunter3
#' (\code{\link[corehunter]{corehunter}}). The core set was generated using
#' distance based measures giving equal weightage to Average
#' entry-to-nearest-entry distance (EN) and Average accession-to-nearest-entry
#' distance (AN). Includes data on 26 descriptors for 168 (10 \% of
#' \code{\link[EvaluateCore]{cassava_EC}}) accessions. It is used to demonstrate
#' the various functions of \code{EvaluateCore} package.
#'
#' Further details on how the example dataset was built from the original data
#' is available
#' \href{https://aravind-j.github.io/EvaluateCore/articles/additional/Example_Core_Data.html}{online}.
#'
#' @format A data frame with 58 columns: \describe{ \item{CUAL}{Colour of
#'   unexpanded apical leaves} \item{LNGS}{Length of stipules}
#'   \item{PTLC}{Petiole colour} \item{DSTA}{Distribution of anthocyanin}
#'   \item{LFRT}{Leaf retention} \item{LBTEF}{Level of branching at the end of
#'   flowering} \item{CBTR}{Colour of boiled tuberous root} \item{NMLB}{Number
#'   of levels of branching} \item{ANGB}{Angle of branching}
#'   \item{CUAL9M}{Colours of unexpanded apical leaves at 9 months}
#'   \item{LVC9M}{Leaf vein colour at 9 months} \item{TNPR9M}{Total number of
#'   plants remaining per accession at 9 months} \item{PL9M}{Petiole length at 9
#'   months} \item{STRP}{Storage root peduncle} \item{STRC}{Storage root
#'   constrictions} \item{PSTR}{Position of root} \item{NMSR}{Number of storage
#'   root per plant} \item{TTRN}{Total root number per plant} \item{TFWSR}{Total
#'   fresh weight of storage root per plant} \item{TTRW}{Total root weight per
#'   plant} \item{TFWSS}{Total fresh weight of storage shoot per plant}
#'   \item{TTSW}{Total shoot weight per plant} \item{TTPW}{Total plant weight}
#'   \item{AVPW}{Average plant weight} \item{ARSR}{Amount of rotted storage root
#'   per plant} \item{SRDM}{Storage root dry matter} }
#'
#' @references
#'
#' \insertAllCited{}
#'
#' @examples
#'
#' data(cassava_CC)
#' summary(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' lapply(seq_along(cassava_CC[, qual]),
#'        function(i) barplot(table(cassava_CC[, qual][, i]),
#'                            xlab = names(cassava_CC[, qual])[i]))
#'
#' lapply(seq_along(cassava_CC[, quant]),
#'        function(i) hist(table(cassava_CC[, quant][, i]),
#'                         xlab = names(cassava_CC[, quant])[i],
#'                         main = ""))
#'
"cassava_CC"

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Variance of Phenotypic Frequency
#'
#' Compute the Variance of Phenotypic Frequency (\mjseqn{VPF})
#' \insertCite{li_studies_2002}{EvaluateCore} to compare qualitative traits
#' between entire collection (EC) and core set (CS).
#'
#' Variance of Phenotypic Frequency (\mjseqn{VPF})
#' \insertCite{li_studies_2002}{EvaluateCore} is computed as follows.
#'
#' \mjsdeqn{VPF = \frac{1}{n} \sum_{i=1}^{n}\left ( \frac{\sum_{j=1}^{k} (p_{ij}
#' - \overline{p_{i}})^{2}}{k - 1} \right )}
#'
#' Where, \mjseqn{p_{ij}} denotes the proportion/fraction/frequency of
#' accessions in the \mjseqn{i}th phenotypic class for the \mjseqn{i}th trait,
#' \mjseqn{\overline{p_{i}}} is the mean frequency of phenotypic classes for the
#' \mjseqn{i}th trait, \mjseqn{k} is the number of phenotypic classes for the
#' \mjseqn{i}th trait and \mjseqn{n} is the total number of traits.
#'
#' @inheritParams chisquare.evaluate.core
#'
#' @return The Variance of Phenotypic Frequency values for EC and CS.
#'
#' @import mathjaxr
#' @export
#'
#' @references
#'
#' \insertAllCited{}
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                      function(x) factor(as.factor(x)))
#'
#' vpf.evaluate.core(data = ec, names = "genotypes",
#'                   qualitative = qual, selected = core)
#'
vpf.evaluate.core <- function(data, names, qualitative, selected,
                              na.omit = TRUE) {
  # Checks
  checks.evaluate.core(data = data, names = names,
                       qualitative = qualitative,
                       selected = selected)

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  dataf <- data[, c(names, qualitative)]

  datafcore <- dataf[dataf[, names] %in% selected, ]

  dataf$`[Type]` <- "EC"
  datafcore$`[Type]` <- "CS"

  dataf <- rbind(dataf, datafcore)
  rm(datafcore)

  dataf$`[Type]` <- as.factor(dataf$`[Type]`)

  if (!na.omit) {
    dataf[, qualitative] <- lapply(dataf[, qualitative], function(x) {
      if (any(is.na(x))) {
        addNA(x)
      } else {
        x
      }
    })
  }

  vpf_ec <- lapply(dataf[dataf$`[Type]` == "EC", qualitative],
                pf_deviance)
  vpf_ec <- unlist(vpf_ec)
  vpf_ec <- sum(vpf_ec) / length(qualitative)

  vpf_cs <- lapply(dataf[dataf$`[Type]` == "CS", qualitative],
                   pf_deviance)
  vpf_cs <- unlist(vpf_cs)
  vpf_cs <- sum(vpf_cs) / length(qualitative)

  out <- c(EC_VPF = vpf_ec, CS_VPF = vpf_cs)

  return(out)

}

pf_deviance <- function(x) {

  x <- droplevels(x)

  count <- as.vector(table(x))
  total.count <- sum(count, na.rm = TRUE)

  k <- length(count)

  prob <- count / total.count

  sum(((prob - mean(prob)) ^ 2)) / (k - 1)

}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Principal Component Analysis
#'
#' Compute Principal Component Analysis Statistics
#' \insertCite{mardia_multivariate_1979}{EvaluateCore} to compare the
#' probability distributions of quantitative traits between entire collection
#' (EC) and core set (CS).
#'
#' @inheritParams snk.evaluate.core
#' @inheritParams base::scale
#' @param npc.plot The number of principal components for which eigen values are
#'   to be plotted. The default value is 6.
#'
#' @return A list with the following components. \item{EC PC Importance}{A data
#'   frame of importance of principal components for EC} \item{EC PC Loadings}{A
#'   data frame with eigen vectors of principal components for EC} \item{CS PC
#'   Importance}{A data frame of importance of principal components for CS}
#'   \item{CS PC Loadings}{A data frame with eigen vectors of principal
#'   components for CS} \item{Scree Plot}{The scree plot of principal components
#'   for EC and CS as a \code{ggplot} object.} \item{PC Loadings Plot}{A plot of
#'   the eigen vector values of principal components for EC and CS as specified
#'   by \code{npc.plot} as a \code{ggplot2} object.}
#'
#' @note If there are missing values in the quantitative data, then they will be
#'   imputed using the \code{\link[missMDA]{imputePCA}} function from
#'   \code{\link[missMDA]{missMDA}}.
#'
#' @seealso \code{\link[stats]{prcomp}}
#'
#' @importFrom stats prcomp
#' @importFrom reshape2 melt
#' @importFrom missMDA imputePCA
#' @import ggplot2
#' @export
#'
#' @references
#'
#' \insertAllCited{}
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                      function(x) factor(as.factor(x)))
#'
#' pca.evaluate.core(data = ec, names = "genotypes",
#'                   quantitative = quant, selected = core,
#'                   center = TRUE, scale = TRUE, npc.plot = 4)
#'
pca.evaluate.core <- function(data, names, quantitative, selected,
                              center = TRUE, scale = TRUE, npc.plot = 6) {
  # Checks
  checks.evaluate.core(data = data, names = names,
                       quantitative = quantitative,
                       selected = selected)

  if (length(quantitative) < npc.plot) {
    stop('Length of "quantitative" is less than "npc.plot" specified')
  }

  if (length(quantitative) == 1) {
    stop('Only one trait specified as "quantitative"')
  }

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  # Imputation if missing data is present

  missvcols <- unlist(lapply(data[, quantitative],
                             function(x) TRUE %in% is.na(x)))
  if (TRUE %in% missvcols) {
    warning('Missing values in "data" have been imputed.')

    data_impt <- missMDA::imputePCA(data[, quantitative], scale = scale)
    data[, quantitative] <- data_impt$completeObs[, quantitative]
  }


  dataf <- data[, c(names, quantitative)]

  datafcore <- dataf[dataf[, names] %in% selected, ]

  dataf$`[Type]` <- "EC"
  datafcore$`[Type]` <- "CS"

  dataf <- rbind(dataf, datafcore)
  rm(datafcore)

  outlist <- vector(mode = "list", length = length(quantitative))
  names(outlist) <- quantitative


  ecpca <- prcomp(dataf[dataf$`[Type]` == "EC", quantitative],
                  center = center, scale = scale)
  cspca <- prcomp(dataf[dataf$`[Type]` == "CS", quantitative],
                  center = center, scale = scale)

  # Rotation - loadings
  ecrot <- summary(ecpca)$rotation
  csrot <- summary(cspca)$rotation

  # Importance
  ecimp <- summary(ecpca)$importance
  csimp <- summary(cspca)$importance


  # Scree plot
  ecimp2 <- as.data.frame(t(ecimp))
  ecimp2$PC <- gsub("PC", "", rownames(ecimp2))
  ecimp2$Ty <- "EC"

  csimp2 <- as.data.frame(t(csimp))
  csimp2$PC <- gsub("PC", "", rownames(csimp2))
  csimp2$Ty <- "CS"

  PCAimp <- rbind(ecimp2, csimp2)
  rm(ecimp2, csimp2)
  PCAimp$PC <- as.numeric(PCAimp$PC)

  gscree <- ggplot(data = PCAimp, aes(y = `Proportion of Variance`,
                                              x = PC)) +
    geom_bar(stat = "identity", fill = "gray", colour = "black") +
    geom_line() +
    geom_point(colour = "red") +
    scale_x_continuous(breaks = 1:10) +
    ylab("Proporiton of variance") +
    xlab("Principal component") +
    facet_grid(rows = vars(Ty)) +
    theme_bw() +
    theme(axis.text = element_text(colour = "black"))

  # Rotation plot
  ecrot2 <- as.data.frame(ecrot[, 1:npc.plot])
  ecrot2$Trait <- rownames(ecrot2)
  ecrot2$Ty <- "EC"

  csrot2 <- as.data.frame(csrot[, 1:npc.plot])
  csrot2$Trait <- rownames(csrot2)
  csrot2$Ty <- "CS"

  PCArot <- rbind(ecrot2, csrot2)
  rm(ecrot2, csrot2)

  PCArot <- reshape2::melt(data = PCArot, id.vars = c("Trait", "Ty"))

  grot <- ggplot(data = PCArot, aes(x = value, y = Trait)) +
    geom_vline(xintercept = 0, colour = "red") +
    geom_point() +
    geom_segment(aes(x = 0, xend = value, yend = Trait)) +
    theme_bw() +
    facet_grid(Ty~variable) +
    theme(axis.text = element_text(colour = "black"))

  outlist <- list(`EC PC Importance` = as.data.frame(ecimp),
                  `EC PC Loadings` = as.data.frame(ecrot),
                  `CS PC Importance` = as.data.frame(csimp),
                  `CS PC Loadings` = as.data.frame(csrot),
                  `Scree Plot` = gscree,
                  `PC Loadings Plot` = grot)

  return(outlist)

}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/



if (getRversion() >= "2.15.1")  {
  utils::globalVariables(
    c(
      "PC", "Proportion of Variance", "Trait", "Ty", "quantitative",
      "value", "x", "y", "lower", "upper", "prop", "[Type]"
    )
  )
}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Coincidence Rate of Range
#'
#' Compute the following metrics to compare quantitative traits of the entire
#' collection (EC) and core set (CS). \itemize{\item{Coincidence Rate of Range
#' (\mjseqn{CR}) \insertCite{hu_methods_2000}{EvaluateCore} (originally
#' described by \insertCite{diwan_methods_1995}{EvaluateCore} as Mean range
#' ratio)} \item{Changeable Rate of Maximum (\mjseqn{CR_{\max}})
#' \insertCite{wang_assessment_2007}{EvaluateCore}} \item{Changeable Rate of
#' Minimum (\mjseqn{CR_{\min}}) \insertCite{wang_assessment_2007}{EvaluateCore}}
#' \item{Changeable Rate of Mean (\mjseqn{CR_{\mu}})
#' \insertCite{wang_assessment_2007}{EvaluateCore}} }
#'
#' The Coincidence Rate of Range (\mjseqn{CR}) is computed as follows.
#'
#' \mjsdeqn{CR = \left ( \frac{1}{n} \sum_{i=1}^{n}
#' \frac{R_{CS_{i}}}{R_{EC_{i}}} \right ) \times 100}
#'
#' Where, \mjseqn{R_{CS_{i}}} is the range of the \mjseqn{i}th trait in the CS,
#' \mjseqn{R_{EC_{i}}} is the range of the \mjseqn{i}th trait in the EC and
#' \mjseqn{n} is the total number of traits.
#'
#' A representative CS should have a \mjseqn{CR} value no less than 70\%
#' \insertCite{diwan_methods_1995}{EvaluateCore} or 80\%
#' \insertCite{hu_methods_2000}{EvaluateCore}.
#'
#' The Changeable Rate of Maximum (\mjseqn{CR_{\max}}) is computed as follows.
#'
#' \mjsdeqn{CR_{\max} = \left ( \frac{1}{n} \sum_{i=1}^{n}
#' \frac{\max_{CS_{i}}}{\max_{EC_{i}}} \right ) \times 100}
#'
#' Where, \mjseqn{\max_{CS_{i}}} is the maximum value of the \mjseqn{i}th trait
#' in the CS, \mjseqn{\max_{EC_{i}}} is the maximum value of the \mjseqn{i}th
#' trait in the EC and \mjseqn{n} is the total number of traits.
#'
#' The Changeable Rate of Minimum (\mjseqn{CR_{\min}}) is computed as follows.
#'
#' \mjsdeqn{CR_{\min} = \left ( \frac{1}{n} \sum_{i=1}^{n}
#' \frac{\min_{CS_{i}}}{\min_{EC_{i}}} \right ) \times 100}
#'
#' Where, \mjseqn{\min_{CS_{i}}} is the minimum value of the \mjseqn{i}th trait
#' in the CS, \mjseqn{\min_{EC_{i}}} is the minimum value of the \mjseqn{i}th
#' trait in the EC and \mjseqn{n} is the total number of traits.
#'
#' The Changeable Rate of Mean (\mjseqn{CR_{\mu}}) is computed as follows.
#'
#' \mjsdeqn{CR_{\mu} = \left ( \frac{1}{n} \sum_{i=1}^{n}
#' \frac{\mu_{CS_{i}}}{\mu_{EC_{i}}} \right ) \times 100}
#'
#' Where, \mjseqn{\mu_{CS_{i}}} is the mean value of the \mjseqn{i}th trait in
#' the CS, \mjseqn{\mu_{EC_{i}}} is the mean value of the \mjseqn{i}th trait in
#' the EC and \mjseqn{n} is the total number of traits.
#'
#' @note \code{NaN} or \code{Inf} values for \mjseqn{CR_{\min}} occurs when the
#'   minimum values for some of the traits are zero.
#'
#' @inheritParams snk.evaluate.core
#'
#' @return The \mjseqn{CR} value.
#'
#' @seealso \code{\link[stats]{wilcox.test}}
#'
#' @export
#'
#' @references
#'
#' \insertAllCited{}
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                      function(x) factor(as.factor(x)))
#'
#' cr.evaluate.core(data = ec, names = "genotypes",
#'                  quantitative = quant, selected = core)
#'
cr.evaluate.core <- function(data, names, quantitative, selected) {
  # Checks
  checks.evaluate.core(data = data, names = names,
                       quantitative = quantitative,
                       selected = selected)

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  mdiff <- snk.evaluate.core(data, names, quantitative,
                    selected)

  CR <- (sum((mdiff$CS_Max - mdiff$CS_Min) / (mdiff$EC_Max - mdiff$EC_Min)) /
           length(quantitative)) * 100

  CR_Max <- (sum(mdiff$CS_Max / mdiff$EC_Max) / length(quantitative)) * 100

  CR_Min <- (sum(mdiff$CS_Min / mdiff$EC_Min) / length(quantitative)) * 100

  CR_Mean <- (sum(mdiff$CS_Mean / mdiff$EC_Mean) / length(quantitative)) * 100

  out <- c(CR = CR, CR_Max = CR_Max, CR_Min = CR_Min, CR_Mean = CR_Mean)

  return(out)

}

### This file is part of 'EvaluateCore' package for R.

### Copyright (C) 2018-2026, ICAR-NBPGR.
#
# EvaluateCore is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# EvaluateCore is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  https://www.r-project.org/Licenses/


#' Chi-squared Test for Homogeneity
#'
#' Compare the distribution frequencies of qualitative traits between entire
#' collection (EC) and core set (CS) by Chi-squared test for homogeneity
#' \insertCite{pearson_x._1900,snedecor_chi-square_1933}{EvaluateCore}.
#' \loadmathjax
#'
#' @inheritParams snk.evaluate.core
#' @param qualitative Name of columns with the qualitative traits as a character
#'   vector.
#' @param na.omit logical. If \code{TRUE}, missing values (\code{NA}) are
#'   ignored and not included as a distinct factor level for analysis. Default
#'   is \code{TRUE}.
#'
#' @return A a data frame with the following columns. \item{Trait}{The
#'   qualitative trait.} \item{EC_No.Classes}{The number of classes in the trait
#'   for EC.} \item{EC_Classes}{The frequency of the classes in the trait for
#'   EC.} \item{CS_No.Classes}{The number of classes in the trait for CS.}
#'   \item{CS_Classes}{The frequency of the classes in the trait for CS.}
#'   \item{chisq_statistic}{The \mjseqn{\chi^{2}} test statistic.}
#'   \item{chisq_pvalue}{The p value for the test statistic.}
#'   \item{chisq_significance}{The significance of the test statistic (*: p
#'   \mjseqn{\leq} 0.01; **: p \mjseqn{\leq} 0.05; ns: p \mjseqn{ > } 0.05).}
#'
#' @seealso \code{\link[stats]{chisq.test}}
#'
#' @importFrom dplyr bind_rows
#' @importFrom stats chisq.test
#' @importFrom stats pchisq
#'
#' @export
#'
#' @references
#'
#' \insertAllCited{}
#'
#' @examples
#'
#' data("cassava_CC")
#' data("cassava_EC")
#'
#' ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
#' ec$genotypes <- as.character(ec$genotypes)
#' rownames(ec) <- NULL
#'
#' core <- rownames(cassava_CC)
#'
#' quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
#'            "ARSR", "SRDM")
#' qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
#'           "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
#'           "PSTR")
#'
#' ec[, qual] <- lapply(ec[, qual],
#'                      function(x) factor(as.factor(x)))
#'
#' chisquare.evaluate.core(data = ec, names = "genotypes",
#'                         qualitative = qual, selected = core)
#'
chisquare.evaluate.core <- function(data, names, qualitative, selected,
                                    na.omit = TRUE) {
  # Checks
  checks.evaluate.core(data = data, names = names,
                       qualitative = qualitative,
                       selected = selected)

  if (any(c("tbl_dataf", "tbl") %in% class(data))) {
    warning('"data" is of type tibble\nCoercing to data frame')
    data <- as.data.frame(data)
  }

  dataf <- data[, c(names, qualitative)]

  datafcore <- dataf[dataf[, names] %in% selected, ]

  dataf$`[Type]` <- "EC"
  datafcore$`[Type]` <- "CS"

  dataf <- rbind(dataf, datafcore)
  rm(datafcore)

  dataf$`[Type]` <- as.factor(dataf$`[Type]`)

  if (!na.omit) {
    dataf[, qualitative] <- lapply(dataf[, qualitative], function(x) {
      if (any(is.na(x))) {
        addNA(x)
      } else {
        x
      }
    })
  }

  outdf <- vector(mode = "list", length = length(qualitative))
  names(outdf) <- qualitative

  for (i in seq_along(qualitative)) {

    chiout <- stats::chisq.test(dataf$`[Type]`, dataf[, qualitative[i]],
                         simulate.p.value = TRUE, B = 10000)
    ECclasses <- as.data.frame(table((dataf[dataf$`[Type]` == "EC",
                                            qualitative[i]])))
    CSclasses <- as.data.frame(table((dataf[dataf$`[Type]` == "CS",
                                            qualitative[i]])))
    ECclasses$classfreq <- paste(ECclasses$Var1, "(", ECclasses$Freq, ")",
                                 sep = "")
    CSclasses$classfreq <- paste(CSclasses$Var1, "(", CSclasses$Freq, ")",
                                 sep = "")
    outdf[[qualitative[i]]] <-
      data.frame(`Trait` = qualitative[i],
                 `Count` = sum(!is.na(dataf[dataf$`[Type]` == "EC",
                                            qualitative[i]])),
                 `EC_No.Classes` =
                   length(levels(droplevels(dataf[dataf$`[Type]` == "EC",
                                                  qualitative[i]]))),
                 `EC_Classes` = paste(ECclasses$classfreq,
                                      collapse = "; "),
                 `CS_No.Classes` =
                   length(levels(droplevels(dataf[dataf$`[Type]` == "CS",
                                                  qualitative[i]]))),
                 `CS_Classes` = paste(CSclasses$classfreq,
                                      collapse = "; "),
                 `chisq_statistic` = chiout$statistic,
                 `chisq_pvalue` = chiout$p.value,
                 stringsAsFactors = FALSE)
    rm(chiout, ECclasses, CSclasses)
  }

  outdf <- dplyr::bind_rows(outdf)

  outdf$chisq_significance <- ifelse(outdf$chisq_pvalue <= 0.01, "**",
                                      ifelse(outdf$chisq_pvalue <= 0.05, "*",
                                             "ns"))

  rownames(outdf) <- NULL

  return(outdf)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pca.evaluate.core.R
\name{pca.evaluate.core}
\alias{pca.evaluate.core}
\title{Principal Component Analysis}
\usage{
pca.evaluate.core(
  data,
  names,
  quantitative,
  selected,
  center = TRUE,
  scale = TRUE,
  npc.plot = 6
)
}
\arguments{
\item{data}{The data as a data frame object. The data frame should possess
one row per individual and columns with the individual names and multiple
trait/character data.}

\item{names}{Name of column with the individual names as a character string.}

\item{quantitative}{Name of columns with the quantitative traits as a
character vector.}

\item{selected}{Character vector with the names of individuals selected in
core collection and present in the \code{names} column.}

\item{center}{either a logical value or numeric-alike vector of length
    equal to the number of columns of \code{x}, where
    \sQuote{numeric-alike} means that \code{\link[base]{as.numeric}(.)} will
    be applied successfully if \code{\link[base]{is.numeric}(.)} is not true.}

\item{scale}{either a logical value or a numeric-alike vector of length
    equal to the number of columns of \code{x}.}

\item{npc.plot}{The number of principal components for which eigen values are
to be plotted. The default value is 6.}
}
\value{
A list with the following components. \item{EC PC Importance}{A data
  frame of importance of principal components for EC} \item{EC PC Loadings}{A
  data frame with eigen vectors of principal components for EC} \item{CS PC
  Importance}{A data frame of importance of principal components for CS}
  \item{CS PC Loadings}{A data frame with eigen vectors of principal
  components for CS} \item{Scree Plot}{The scree plot of principal components
  for EC and CS as a \code{ggplot} object.} \item{PC Loadings Plot}{A plot of
  the eigen vector values of principal components for EC and CS as specified
  by \code{npc.plot} as a \code{ggplot2} object.}
}
\description{
Compute Principal Component Analysis Statistics
\insertCite{mardia_multivariate_1979}{EvaluateCore} to compare the
probability distributions of quantitative traits between entire collection
(EC) and core set (CS).
}
\note{
If there are missing values in the quantitative data, then they will be
  imputed using the \code{\link[missMDA]{imputePCA}} function from
  \code{\link[missMDA]{missMDA}}.
}
\examples{

data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

pca.evaluate.core(data = ec, names = "genotypes",
                  quantitative = quant, selected = core,
                  center = TRUE, scale = TRUE, npc.plot = 4)

}
\references{
\insertAllCited{}
}
\seealso{
\code{\link[stats]{prcomp}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bar.evaluate.core.R
\name{bar.evaluate.core}
\alias{bar.evaluate.core}
\title{Bar Plots}
\usage{
bar.evaluate.core(
  data,
  names,
  qualitative,
  selected,
  na.omit = TRUE,
  show.count = FALSE
)
}
\arguments{
\item{data}{The data as a data frame object. The data frame should possess
one row per individual and columns with the individual names and multiple
trait/character data.}

\item{names}{Name of column with the individual names as a character string.}

\item{qualitative}{Name of columns with the qualitative traits as a character
vector.}

\item{selected}{Character vector with the names of individuals selected in
core collection and present in the \code{names} column.}

\item{na.omit}{logical. If \code{TRUE}, missing values (\code{NA}) are
ignored and not included in the plot as a distinct factor level. Default is
\code{TRUE}.}

\item{show.count}{logical. If \code{TRUE}, the accession count excluding
missing values will also be displayed. Default is \code{FALSE}.}
}
\value{
A list with the \code{ggplot} objects of relative frequency bar plots
  of CS and EC for each trait specified as \code{qualitative}.
}
\description{
Plot Bar plots to graphically compare the frequency distributions of
qualitative traits between entire collection (EC) and core set (CS).
}
\examples{

data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

\donttest{
bar.evaluate.core(data = ec, names = "genotypes",
                  qualitative = qual, selected = core)
bar.evaluate.core(data = ec, names = "genotypes",
                  qualitative = qual, selected = core,
                  show.count = TRUE)
}

}
\seealso{
\code{\link[graphics]{barplot}}, \code{\link[ggplot2]{geom_bar}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/signtest.evaluate.core.R
\name{signtest.evaluate.core}
\alias{signtest.evaluate.core}
\title{Sign Test}
\usage{
signtest.evaluate.core(data, names, quantitative, selected)
}
\arguments{
\item{data}{The data as a data frame object. The data frame should possess
one row per individual and columns with the individual names and multiple
trait/character data.}

\item{names}{Name of column with the individual names as a character string}

\item{quantitative}{Name of columns with the quantitative traits as a
character vector.}

\item{selected}{Character vector with the names of individuals selected in
core collection and present in the \code{names} column.}
}
\value{
A data frame with the following components. \item{Comparison}{The
  comparison measure.} \item{ChiSq}{The test statistic (\mjseqn{\chi^{2}}).}
  \item{p.value}{The p value for the test statistic.} \item{significance}{The
  significance of the test statistic (*: p \mjseqn{\leq} 0.01; **: p
  \mjseqn{\leq} 0.05; ns: p \mjseqn{ > } 0.05).}
}
\description{
Test difference between means and variances of entire collection (EC) and
core set (CS) for quantitative traits by Sign test (\mjseqn{+} versus
\mjseqn{-})
\insertCite{basigalup_development_1995,tai_core_2001}{EvaluateCore}.
}
\details{
The test statistic for Sign test (\mjseqn{\chi^{2}}) is computed as follows.

\mjsdeqn{\chi^{2} = \frac{(N_{1}-N_{2})^{2}}{N_{1}+N_{2}}}

Where, where \mjseqn{N_{1}} is the number of variables for which the mean or
variance of the CS is greater than the mean or variance of the EC (number of
\mjseqn{+} signs); \mjseqn{N_{2}} is the number of variables for which the
mean or variance of the CS is less than the mean or variance of the EC
(number of \mjseqn{-} signs). The value of \mjseqn{\chi^{2}} is compared with
a Chi-square distribution with 1 degree of freedom.
}
\examples{

data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

signtest.evaluate.core(data = ec, names = "genotypes",
                       quantitative = quant, selected = core)

}
\references{
\insertAllCited{}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qq.evaluate.core.R
\name{qq.evaluate.core}
\alias{qq.evaluate.core}
\title{Quantile-Quantile Plots}
\usage{
qq.evaluate.core(
  data,
  names,
  quantitative,
  selected,
  annotate = c("none", "kl", "ks", "ad"),
  show.count = FALSE
)
}
\arguments{
\item{data}{The data as a data frame object. The data frame should possess
one row per individual and columns with the individual names and multiple
trait/character data.}

\item{names}{Name of column with the individual names as a character string.}

\item{quantitative}{Name of columns with the quantitative traits as a
character vector.}

\item{selected}{Character vector with the names of individuals selected in
core collection and present in the \code{names} column.}

\item{annotate}{Adds the divergence/distance value between probability
distributions of CS and EC as an annotation to the QQ plot. Either
\code{"none"} (no annotation (Default)) or \code{"kl"} (Kullback-Leibler
divergence) or  \code{"ks"} (Kolmogorov-Smirnov distance) or  \code{"ad"}
(Anderson-Darling distance).}

\item{show.count}{logical. If \code{TRUE}, the accession count excluding
missing values will also be displayed. Default is \code{FALSE}.}
}
\value{
A list with the \code{ggplot} objects of QQ plots of CS vs EC for
  each trait specified as \code{quantitative}.
}
\description{
Plot Quantile-Quantile (QQ) plots
\insertCite{wilk_probability_1968}{EvaluateCore} to graphically compare the
probability distributions of quantitative traits between entire collection
(EC) and core set (CS).
}
\examples{

data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

\donttest{
qq.evaluate.core(data = ec, names = "genotypes",
                 quantitative = quant, selected = core)

qq.evaluate.core(data = ec, names = "genotypes",
                 quantitative = quant, selected = core, show.count = TRUE)

qq.evaluate.core(data = ec, names = "genotypes",
                 quantitative = quant, selected = core, annotate = "kl")

qq.evaluate.core(data = ec, names = "genotypes",
                 quantitative = quant, selected = core, annotate = "ks")

qq.evaluate.core(data = ec, names = "genotypes",
                 quantitative = quant, selected = core, annotate = "ad")
}

}
\references{
\insertAllCited{}
}
\seealso{
\code{\link[stats:qqnorm]{qqplot}} \code{\link[entropy]{KL.plugin}},
  \code{\link[stats]{ks.test}}, \code{\link[kSamples]{ad.test}},
  \code{\link[EvaluateCore]{pdfdist.evaluate.core}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/shannon.evaluate.core.R
\name{shannon.evaluate.core-deprecated}
\alias{shannon.evaluate.core-deprecated}
\title{Shannon-Weaver Diversity Index}
\usage{
shannon.evaluate.core(data, names, qualitative, selected)
}
\value{
A data frame with the following columns. \item{Trait}{The qualitative
  trait.} \item{EC_H}{The Shannon-Weaver Diversity Index (\mjseqn{H'}) for
  EC.} \item{EC_H}{The Shannon-Weaver Diversity Index (\mjseqn{H'}) for CS.}
  \item{EC_Hmax}{The Maximum diversity value (\mjseqn{H'_{max}}) for EC.}
  \item{CS_Hmax}{The Maximum diversity value (\mjseqn{H'_{max}}) for CS.}
  \item{EC_EH}{The Shannon Equitability Index (\mjseqn{E_{H}}) for EC.}
  \item{CS_EH}{The Shannon Equitability Index (\mjseqn{E_{H}}) for CS.}
}
\description{
Compute the Shannon-Weaver Diversity Index (\mjseqn{H'}), Maximum diversity
(\mjseqn{H'_{max}}) and Shannon Equitability Index (\mjseqn{E_{H}})
\insertCite{shannon_mathematical_1949}{EvaluateCore} to compare the
phenotypic diversity for qualitative traits between entire collection (EC)
and core set (CS).
}
\details{
Shannon-Weaver Diversity Index (\mjseqn{H'}) is computed as follows.

\mjsdeqn{H' = -\sum_{i=1}^{k}p_{i} \ln(p_{i})}

Where \mjseqn{p_{i}} denotes the proportion in the group \mjseqn{k}.

The maximum value of the index (\mjseqn{H'_{max}}) is \mjseqn{\ln(k)}. This
value occurs when each group has the same frequency.

The Shannon equitability index (\mjseqn{E_{H}}) is the Shannon diversity
index divided by the maximum diversity.

\mjsdeqn{E_{H} = \frac{H'}{\ln{(k)}}}
}
\examples{

data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

shannon.evaluate.core(data = ec, names = "genotypes",
                      qualitative = qual, selected = core)

}
\references{
\insertAllCited{}
}
\seealso{
\code{\link[psych:misc]{shannon}}

\code{\link{EvaluateCore-deprecated}}
}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/coverage.evaluate.core.R
\name{coverage.evaluate.core}
\alias{coverage.evaluate.core}
\title{Class Coverage}
\usage{
coverage.evaluate.core(data, names, qualitative, selected, na.omit = TRUE)
}
\arguments{
\item{data}{The data as a data frame object. The data frame should possess
one row per individual and columns with the individual names and multiple
trait/character data.}

\item{names}{Name of column with the individual names as a character string.}

\item{qualitative}{Name of columns with the qualitative traits as a character
vector.}

\item{selected}{Character vector with the names of individuals selected in
core collection and present in the \code{names} column.}

\item{na.omit}{logical. If \code{TRUE}, missing values (\code{NA}) are
ignored and not included as a distinct factor level for analysis. Default
is \code{TRUE}.}
}
\value{
The Class Coverage value.
}
\description{
Compute the Class Coverage \insertCite{kim_PowerCore_2007}{EvaluateCore} to
compare the distribution frequencies of qualitative traits between entire
collection (EC) and core set (CS).
}
\details{
Class Coverage \insertCite{kim_PowerCore_2007}{EvaluateCore} is computed as
follows.

\mjsdeqn{Class\, Coverage = \left ( \frac{1}{n} \sum_{i=1}^{n}
\frac{k_{CS_{i}}}{k_{EC_{i}}} \right ) \times 100}

Where, \mjseqn{k_{CS_{i}}} is the number of phenotypic classes in CS for the
\mjseqn{i}th trait, \mjseqn{k_{EC_{i}}} is the number of phenotypic classes
in EC for the \mjseqn{i}th trait and \mjseqn{n} is the total number of
traits.
}
\examples{

data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

coverage.evaluate.core(data = ec, names = "genotypes",
                       qualitative = qual, selected = core)

}
\references{
\insertAllCited{}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/corr.evaluate.core.R
\name{corr.evaluate.core}
\alias{corr.evaluate.core}
\title{Phenotypic Correlations}
\usage{
corr.evaluate.core(data, names, quantitative, qualitative, selected)
}
\arguments{
\item{data}{The data as a data frame object. The data frame should possess
one row per individual and columns with the individual names and multiple
trait/character data.}

\item{names}{Name of column with the individual names as a character string.}

\item{quantitative}{Name of columns with the quantitative traits as a
character vector.}

\item{qualitative}{Name of columns with the qualitative traits as a character
vector.}

\item{selected}{Character vector with the names of individuals selected in
core collection and present in the \code{names} column.}
}
\value{
A list with the following components. \item{Correlation Matrix}{The
  matrix with phenotypic correlations between traits in EC (below diagonal)
  and CS (above diagonal).} \item{Correologram}{A correlogram of phenotypic
  correlations between traits in EC (below diagonal) and CS (above diagonal)
  as a \code{ggplot} object.} \item{Mantel Correlation}{A data frame with
  Mantel correlation coefficient (\mjseqn{r}) between EC and CS phenotypic
  correlation matrices, it's p value and significance (*: p \mjseqn{\leq}
  0.01; **: p \mjseqn{\leq} 0.05; ns: p \mjseqn{ > } 0.05).}
}
\description{
Compute phenotypic correlations \insertCite{pearson_note_1895}{EvaluateCore}
between traits, plot correlation matrices as correlograms
\insertCite{friendly_corrgrams_2002}{EvaluateCore} and calculate mantel
correlation \insertCite{legendre_interpretation_2012}{EvaluateCore} between
them to compare entire collection (EC) and core set (CS).
}
\note{
Missing values are ignored for the computation of correlation
  coefficient.
}
\examples{

data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

corr.evaluate.core(data = ec, names = "genotypes", quantitative = quant,
                   qualitative = qual, selected = core)

}
\references{
\insertAllCited{}
}
\seealso{
\code{\link[stats]{cor}},
  \code{\link[ggcorrplot:ggcorrplot]{cor_pmat}}
  \code{\link[ggcorrplot]{ggcorrplot}}, \code{\link[vegan]{mantel}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/iqr.evaluate.core.R
\name{iqr.evaluate.core}
\alias{iqr.evaluate.core}
\title{Interquartile Range}
\usage{
iqr.evaluate.core(data, names, quantitative, selected)
}
\arguments{
\item{data}{The data as a data frame object. The data frame should possess
one row per individual and columns with the individual names and multiple
trait/character data.}

\item{names}{Name of column with the individual names as a character string.}

\item{quantitative}{Name of columns with the quantitative traits as a
character vector.}

\item{selected}{Character vector with the names of individuals selected in
core collection and present in the \code{names} column.}
}
\value{
A data frame with the accession count (excluding missing  data) as
  well as the IQR values of the EC and CS for the traits specified as
  \code{quantitative}.
}
\description{
Compute the Interquartile Range (IQR)
\insertCite{upton_general_1996}{EvaluateCore} to compare quantitative traits
of the entire collection (EC) and core set (CS).
}
\examples{

data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

iqr.evaluate.core(data = ec, names = "genotypes",
                  quantitative = quant, selected = core)

}
\references{
\insertAllCited{}
}
\seealso{
\code{\link[stats]{IQR}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diversity.evaluate.core.R
\name{diversity.evaluate.core}
\alias{diversity.evaluate.core}
\title{Diversity Indices}
\usage{
diversity.evaluate.core(
  data,
  names,
  qualitative,
  selected,
  base = 2,
  R = 1000,
  na.omit = TRUE
)
}
\arguments{
\item{data}{The data as a data frame object. The data frame should possess
one row per individual and columns with the individual names and multiple
trait/character data.}

\item{names}{Name of column with the individual names as a character string.}

\item{qualitative}{Name of columns with the qualitative traits as a character
vector.}

\item{selected}{Character vector with the names of individuals selected in
core collection and present in the \code{names} column.}

\item{base}{The logarithm base to be used for computation of Shannon-Weaver
Diversity Index (\mjseqn{I}). Default is 2.}

\item{R}{The number of bootstrap replicates. Default is 1000.}

\item{na.omit}{logical. If \code{TRUE}, missing values (\code{NA}) are
ignored and not included as a distinct factor level for computation.
Default is \code{TRUE}.}
}
\value{
A list with three data frames as follows. \item{simpson}{
  \describe{\item{Trait}{The qualitative trait.}
  \item{EC_No.Classes}{The number of classes in the trait for EC.}
  \item{CS_No.Classes}{The number of classes in the trait for CS.}
  \item{EC_d}{The Simpson's Index (\mjseqn{d}) for EC.}
  \item{EC_D}{The Simpson's Index of Diversity (\mjseqn{D}) for EC.}
  \item{EC_D.max}{The Maximum Simpson's Index of Diversity
  (\mjseqn{D_{max}}) for EC.} \item{EC_D.inv}{The Simpson's Reciprocal
  Index (\mjseqn{D_{R}}) for EC.} \item{EC_D.rel}{The Relative
  Reciprocal Index (\mjseqn{D'}) for EC.} \item{EC_D.e}{The Shannon's
  evenness or equitability (\mjseqn{D_{e}}) for EC.} \item{EC_d.V}{The
  variance of \mjseqn{d} for EC according to
  \insertCite{simpson_measurement_1949}{EvaluateCore}.}
  \item{EC_d.boot.V}{The bootstrap variance of \mjseqn{d} for EC.}
  \item{CS_d}{The Simpson's Index (\mjseqn{d}) for CS.}
  \item{CS_D}{The Simpson's Index of Diversity (\mjseqn{D}) for CS.}
  \item{CS_D.max}{The Maximum Simpson's Index of Diversity
  (\mjseqn{D_{max}}) for CS.} \item{CS_D.inv}{The Simpson's Reciprocal
  Index (\mjseqn{D_{R}}) for CS.} \item{CS_D.rel}{The Relative
  Reciprocal Index (\mjseqn{D'}) for CS.} \item{CS_D.e}{The Shannon's
  evenness or equitability (\mjseqn{D_{e}}) for CS.} \item{CS_d.V}{The
  variance of \mjseqn{d} for CS according to
  \insertCite{simpson_measurement_1949}{EvaluateCore}.}
  \item{CS_d.boot.V}{The bootstrap variance of \mjseqn{d} for CS.}
  \item{d.t.df}{The degrees of freedom for t test.}
  \item{d.t.stat}{The t statistic.} \item{d.t.pvalue}{The p
  value for t test.} \item{d.t.significance}{The  significance of t
  test for t-test} \item{d.boot.z.df}{The degrees of freedom for
  bootstrap z score.} \item{d.boot.z.stat}{The bootstrap z score.}
  \item{d.boot.z.pvalue}{The p value of z score.}
  \item{d.boot.z.significance}{The significance of z score.}} }
  \item{shannon}{ \describe{\item{Trait}{The qualitative
  trait.} \item{EC_No.Classes}{The number of classes in the trait for
  EC.} \item{CS_No.Classes}{The number of classes in the trait for
  CS.} \item{EC_I}{The Shannon-Weaver Diversity Index (\mjseqn{I}) for
  EC.} \item{EC_I.max}{The Maximum Shannon-Weaver Diversity Index
  (\mjseqn{I_{max}}) for EC.} \item{EC_I.rel}{The Relative
  Shannon-Weaver Diversity Index (\mjseqn{I'}) for EC.} \item{EC_I.ens}{The
  Effective Number of Species (or Classes) for Shannon-Weaver Diversity Index
  (\mjseqn{ENS_{H}}) for EC} \item{EC_I.V}{The variance of \mjseqn{I} for EC
  according to \insertCite{hutcheson_test_1970}{EvaluateCore}.}
  \item{EC_I.boot.V}{The bootstrap variance of \mjseqn{I} for EC.}
  \item{CS_I}{The Shannon-Weaver Diversity Index (\mjseqn{I}) for CS.}
  \item{CS_I.max}{The Maximum Shannon-Weaver Diversity Index
  (\mjseqn{I_{max}}) for CS.} \item{CS_I.rel}{The Relative
  Shannon-Weaver Diversity Index (\mjseqn{I'}) for CS.} \item{CS_I.ens}{The
  Effective Number of Species (or Classes) for Shannon-Weaver Diversity Index
  (\mjseqn{ENS_{H}}) for CS.} \item{CS_I.V}{The variance of \mjseqn{I} for
  CS according to \insertCite{hutcheson_test_1970}{EvaluateCore}.}
  \item{CS_I.boot.V}{The bootstrap variance of \mjseqn{I} for CS.}
  \item{I.t.stat}{The t statistic.} \item{I.t.df}{The degrees
  of freedom for t test.} \item{I.t.pvalue}{The p value for t test.}
  \item{I.t.significance}{The  significance of t test for t-test}
  \item{I.boot.z.df}{The degrees of freedom for bootstrap z score.}
  \item{I.boot.z.stat}{The bootstrap z score.}
  \item{I.boot.z.pvalue}{The p value of z score.}
  \item{I.boot.z.significance}{The significance of z score.}} }
  \item{mcintosh}{ \describe{\item{EC_No.Classes}{The number of
  classes in the trait for EC.} \item{CS_No.Classes}{The number of
  classes in the trait for CS.} \item{EC_D.Mc}{The McIntosh Diversity Index
  (\mjseqn{D_{Mc}}) for EC.} \item{EC_E.Mc}{The McIntosh Evenness Index
  (\mjseqn{E_{Mc}}) for EC.} \item{CS_D.Mc}{The McIntosh Diversity Index
  (\mjseqn{D_{Mc}}) for CS.} \item{CS_E.Mc}{The McIntosh Evenness Index
  (\mjseqn{E_{Mc}}) for CS.} \item{M.boot.z.stat}{The bootstrap z
  score.} \item{M.boot.z.df}{The degrees of freedom for bootstrap z
  score.} \item{M.boot.z.pvalue}{The p value of z score.}
  \item{M.boot.z.significance}{The significance of z score.}} }
}
\description{
Compute the following diversity indices and perform corresponding statistical
tests to compare the phenotypic diversity for qualitative traits between
entire collection (EC) and core set (CS). \itemize{ \item{Simpson's and
related indices} \itemize{ \item{Simpson's Index (\mjseqn{d})
\insertCite{simpson_measurement_1949,peet_measurement_1974}{EvaluateCore}}
\item{Simpson's Index of Diversity or Gini's Diversity Index or Gini-Simpson
Index or Nei's Diversity Index or Nei's Variation Index (\mjseqn{D}) or
Hurlbert’s probability of interspecific encounter (\mjseqn{PIE})
\insertCite{gini_variabilita_1912,gini_variabilita_1912-2,greenberg_measurement_1956,berger_diversity_1970,hurlbert_nonconcept_1971,nei_analysis_1973,peet_measurement_1974}{EvaluateCore}}
\item{Maximum Simpson's Index of Diversity or Maximum Nei's
Diversity/Variation Index (\mjseqn{D_{max}})
\insertCite{hennink_interpretation_1990}{EvaluateCore}} \item{Simpson's
Reciprocal Index or Hill's \mjseqn{N_{2}} (\mjseqn{D_{R}}) or Effective
number of Species (or Classes) (\mjseqn{ENS_{d}})
\insertCite{williams_patterns_1964,hill_diversity_1973}{EvaluateCore}}
\item{Relative Simpson's Index of Diversity or Relative Nei's
Diversity/Variation Index (\mjseqn{D'})
\insertCite{hennink_interpretation_1990}{EvaluateCore}} \item{Simpson’s
evenness or equitability (\mjseqn{D_{e}})
\insertCite{pielou_measurement_1966,hill_diversity_1973}{EvaluateCore}} }
\item{Shannon-Weaver and related indices} \itemize{ \item{Shannon or
Shannon-Weaver or Shannon-Wiener Diversity Index or Shannon entropy
(\mjseqn{H}) \insertCite{shannon_mathematical_1949,peet_measurement_1974}{EvaluateCore}}
\item{Maximum Shannon-Weaver Diversity Index (\mjseqn{H_{max}})
\insertCite{hennink_interpretation_1990}{EvaluateCore}} \item{Relative
Shannon-Weaver Diversity Index or Shannon Equitability Index (\mjseqn{H'})
or Pielou's Evenness (\mjseqn{J})
\insertCite{pielou_measurement_1966,hennink_interpretation_1990}{EvaluateCore}}
\item{Effective number of species (or Classes) for the Shannon - Weaver
Diversity Index (\mjseqn{ENS_{H}}) or Hill's \mjseqn{N_{1}}
\insertCite{macarthur_patterns_1965,hill_diversity_1973}{EvaluateCore}} }
\item{McIntosh's measures of diversity} \itemize{ \item{McIntosh Diversity
Index (\mjseqn{D_{Mc}}) \insertCite{mcintosh_index_1967,peet_measurement_1974}{EvaluateCore}}
\item{McIntosh Evenness Index (\mjseqn{E_{Mc}})
\insertCite{pielou_Ecological_1975}{EvaluateCore}} } }
}
\section{Details}{
 The diversity indices and the corresponding statistical
  tests implemented in \code{diversity.evaluate.core} are as follows.

  \subsection{Simpson's and Related Indices}{Simpson's index (\mjseqn{d})
  which estimates the probability that two accessions randomly selected will
  belong to the same phenotypic class of a trait, is computed as follows
  \insertCite{simpson_measurement_1949,peet_measurement_1974}{EvaluateCore}.

  \mjsdeqn{d = \sum_{i = 1}^{k}p_{i}^{2}}

  Where, \mjseqn{p_{i}} denotes the proportion/fraction/frequency of
  accessions in the \mjseqn{i}th phenotypic class for a trait and \mjseqn{k}
  is the number of phenotypic classes for the trait.

  The value of \mjseqn{d} can range from 0 to 1 with 0 representing maximum
  diversity and 1, no diversity.

  \mjseqn{d} is subtracted from 1 to give Simpson's index of diversity
  (\mjseqn{D})
  \insertCite{greenberg_measurement_1956,berger_diversity_1970,hurlbert_nonconcept_1971,peet_measurement_1974,hennink_interpretation_1990}{EvaluateCore}
   originally suggested by
  \insertCite{gini_variabilita_1912,gini_variabilita_1912-2;textual}{EvaluateCore}
   and described in literature as Gini's diversity index or Gini-Simpson
  index. It is the same as Nei's diversity index or Nei's variation index
  \insertCite{nei_analysis_1973,hennink_interpretation_1990}{EvaluateCore}.
  Greater the value of \mjseqn{D}, greater the diversity with a range from 0
  to 1.

  \mjsdeqn{D = 1 - d}

  The maximum value of \mjseqn{D}, \mjseqn{D_{max}} occurs when accessions
  are uniformly distributed across the phenotypic classes and is computed as
  follows \insertCite{hennink_interpretation_1990}{EvaluateCore}.

  \mjsdeqn{D_{max} = 1 - \frac{1}{k}}

  Reciprocal of \mjseqn{d} gives the Simpson's reciprocal index
  (\mjseqn{D_{R}})
  \insertCite{williams_patterns_1964,hennink_interpretation_1990}{EvaluateCore}
   and can range from 1 to \mjseqn{k}. This was also described in
  \insertCite{hill_diversity_1973;textual}{EvaluateCore} as \mjseqn{N_{2}} or
  as Effective number of Species (or Classes) (\mjseqn{ENS_{d}}).

  \mjsdeqn{D_{R} = \frac{1}{d}}

  Relative Simpson's index of diversity or Relative Nei's diversity/variation
  index (\mjseqn{H'}) \insertCite{hennink_interpretation_1990}{EvaluateCore}
  is defined as follows \insertCite{peet_measurement_1974}{EvaluateCore}.

  \mjsdeqn{D' = \frac{D}{D_{max}}}

  Simpson’s evenness or equitability (\mjseqn{D_{e}} is described as follows
  \insertCite{pielou_measurement_1966,hill_diversity_1973}{EvaluateCore}.

  \mjsdeqn{D_{e} = \frac{1}{d \cdot k}}

  Differences in Simpson's diversity index for qualitative traits of EC and
  CS can be tested by a t-test using the associated variance estimate
  described in \insertCite{simpson_measurement_1949;textual}{EvaluateCore}
  \insertCite{lyons_c20_1978}{EvaluateCore}.

  The t statistic is computed as follows.

  \mjsdeqn{t = \frac{d_{EC} - d_{CS}}{\sqrt{V_{d_{EC}} + V_{d_{CS}}}}}

  Where, the variance of \mjseqn{d} (\mjseqn{V_{d}}) is,

  \mjsdeqn{V_{d} = \frac{4N(N-1)(N-2)\sum_{i=1}^{k}(p_{i})^{3} +
  2N(N-1)\sum_{i=1}^{k}(p_{i})^{2} - 2N(N-1)(2N-3) \left(
  \sum_{i=1}^{k}(p_{i})^{2} \right)^{2}}{[N(N-1)]^{2}}}

  The associated degrees of freedom is computed as follows.

  \mjsdeqn{df = (k_{EC} - 1) + (k_{CS} - 1)}

  Where, \mjseqn{k_{EC}} and \mjseqn{k_{CS}} are the number of phenotypic
  classes in the trait for EC and CS respectively.

  }

  \subsection{Shannon-Weaver and Related Indices}{An index of information
  \mjseqn{H}, was described by
  \insertCite{shannon_mathematical_1949;textual}{EvaluateCore} as follows.

  \mjsdeqn{H = -\sum_{i=1}^{k}p_{i} \log_{2}(p_{i})}

  \mjseqn{H} is described as Shannon or Shannon-Weaver or Shannon-Wiener
  diversity index or Shannon entropy in literature
  \insertCite{shannon_mathematical_1949,peet_measurement_1974}{EvaluateCore}.

  Alternatively, \mjseqn{H} is also computed using natural logarithm instead
  of logarithm to base 2.

  \mjsdeqn{H = -\sum_{i=1}^{k}p_{i} \ln(p_{i})}

  The maximum value of \mjseqn{H} (\mjseqn{H_{max}}) is \mjseqn{\ln(k)}. This
  value occurs when each phenotypic class for a trait has the same proportion
  of accessions \insertCite{hennink_interpretation_1990}{EvaluateCore}.

  \mjsdeqn{H_{max} = \log_{2}(k)\;\; \textrm{OR} \;\; H_{max} = \ln(k)}

  The relative Shannon-Weaver diversity index or Shannon equitability index
  (\mjseqn{H'}) or Pielou's Evenness (\mjseqn{J}) is the Shannon diversity
  index (\mjseqn{I}) divided by the maximum diversity (\mjseqn{H_{max}})
  \insertCite{pielou_measurement_1966,hennink_interpretation_1990}{EvaluateCore}.

  \mjsdeqn{H' = \frac{H}{H_{max}}}

  \insertCite{macarthur_patterns_1965;textual}{EvaluateCore} described the
  Effective number of Species (or Classes) for the Shannon index
  (\mjseqn{ENS_{H}}) as follows.

  \mjsdeqn{ENS_{H} = e^{H}}

  Differences in Shannon-Weaver diversity index for qualitative traits of EC
  and CS can be tested by Hutcheson t-test
  \insertCite{hutcheson_test_1970}{EvaluateCore}.

  The Hutcheson t statistic is computed as follows.

  \mjsdeqn{t = \frac{H_{EC} - H_{CS}}{\sqrt{V_{H_{EC}} + V_{H_{CS}}}}}

  Where, the variance of \mjseqn{H} (\mjseqn{V_{H}}) is,

  \mjsdeqn{V_{H} = \frac{\sum_{i=1}^{k}n_{i}(\log_{2}{n_{i}})^{2}
  \frac{(\sum_{i=1}^{k}\log_{2}{n_{i}})^2}{N}}{N^{2}}}

  \mjsdeqn{\textrm{OR}}

  \mjsdeqn{V_{H} = \frac{\sum_{i=1}^{k}n_{i}(\ln{n_{i}})^{2}
  \frac{(\sum_{i=1}^{k}\ln{n_{i}})^2}{N}}{N^{2}}}

  The associated degrees of freedom is approximated as follows.

  \mjsdeqn{df = \frac{(V_{H_{EC}} +
  V_{H_{CS}})^{2}}{\frac{V_{H_{EC}}^{2}}{N_{EC}} +
  \frac{V_{H_{CS}}^{2}}{N_{CS}}}}

  }

  \subsection{McIntosh's Measure of Diversity}{A similar index of diversity was
  described by \insertCite{mcintosh_index_1967;textual}{EvaluateCore} as
  follows (\mjseqn{D_{Mc}}) \insertCite{peet_measurement_1974}{EvaluateCore}.

  \mjsdeqn{D_{Mc} = \frac{N - \sqrt{\sum_{i=1}^{k}n_{i}^2}}{N - \sqrt{N}}}

  Where, \mjseqn{n_{i}} denotes the number of accessions in the \mjseqn{i}th
  phenotypic class for a trait and \mjseqn{N} is the total number of
  accessions so that \mjseqn{p_{i} = {n_{i}}/{N}}.}

  An additional measure of evenness was proposed by
  \insertCite{pielou_Ecological_1975;textual}{EvaluateCore} as follows.

  \mjsdeqn{E_{Mc} = \frac{N - \sqrt{\sum_{i=1}^{k}n_{i}^2}}{N -
  \frac{N}{\sqrt{S}}}}

  \subsection{Testing for difference with bootstrapping}{Bootstrap statistics
  are employed to test the difference between the Simpson, Shannon-Weaver and
  McIntosh indices for  qualitative traits of EC and CS
  \insertCite{solow_simple_1993}{EvaluateCore}.

  If \mjseqn{I_{EC}} and \mjseqn{I_{CS}} are the diversity indices with the
  original number of accessions, then random samples of the same size as the
  original are repeatedly generated (with replacement) \mjseqn{R} times and
  the corresponding diversity index is computed for each sample.

  \mjsdeqn{I_{EC}^{*} = \lbrace H_{EC_{1}}, H_{EC_{}}, \cdots, H_{EC_{R}}
  \rbrace}

  \mjsdeqn{I_{CS}^{*} = \lbrace H_{CS_{1}}, H_{CS_{}}, \cdots, H_{CS_{R}}
  \rbrace}

  Then the bootstrap null sample {\mjseqn{I_{0}}} is computed as follows.

  \mjsdeqn{\Delta^{*} = I_{EC}^{*} - I_{CS}^{*}}

  \mjsdeqn{I_{0} = \Delta^{*} - \overline{\Delta^{*}}}

  Where, \mjseqn{\overline{\Delta^{*}}} is the mean of \mjseqn{\Delta^{*}}.

  Now the original difference in diversity indices (\mjseqn{\Delta_{0} =
  I_{EC} - I_{CS}}) is tested against mean of bootstrap null sample
  (\mjseqn{I_{0}}) by a z test. The z score test statistic is computed as
  follows.

  \mjsdeqn{z = \frac{\Delta_{0} - \overline{H_{0}}}{\sqrt{V_{H_{0}}}}}

  Where,  \mjseqn{\overline{H_{0}}} and \mjseqn{V_{H_{0}}} are the mean and
  variance of the bootstrap null sample \mjseqn{H_{0}}.

  The corresponding degrees of freedom is estimated as follows.

  \mjsdeqn{df = (k_{EC} - 1) + (k_{CS} - 1)}

  }
}

\examples{

data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

\donttest{
diversity.evaluate.core(data = ec, names = "genotypes",
                        qualitative = qual, selected = core)
}

}
\references{
\insertAllCited{}
}
\seealso{
\code{\link[psych:misc]{shannon}}, \code{\link[vegan]{diversity}},
  \code{\link[boot]{boot}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cassava_EC.R
\docType{data}
\name{cassava_EC}
\alias{cassava_EC}
\title{IITA Cassava Germplasm Data - Entire Collection}
\format{
A data frame with 58 columns: \describe{ \item{CUAL}{Colour of
  unexpanded apical leaves} \item{LNGS}{Length of stipules}
  \item{PTLC}{Petiole colour} \item{DSTA}{Distribution of anthocyanin}
  \item{LFRT}{Leaf retention} \item{LBTEF}{Level of branching at the end of
  flowering} \item{CBTR}{Colour of boiled tuberous root} \item{NMLB}{Number
  of levels of branching} \item{ANGB}{Angle of branching}
  \item{CUAL9M}{Colours of unexpanded apical leaves at 9 months}
  \item{LVC9M}{Leaf vein colour at 9 months} \item{TNPR9M}{Total number of
  plants remaining per accession at 9 months} \item{PL9M}{Petiole length at 9
  months} \item{STRP}{Storage root peduncle} \item{STRC}{Storage root
  constrictions} \item{PSTR}{Position of root} \item{NMSR}{Number of storage
  root per plant} \item{TTRN}{Total root number per plant} \item{TFWSR}{Total
  fresh weight of storage root per plant} \item{TTRW}{Total root weight per
  plant} \item{TFWSS}{Total fresh weight of storage shoot per plant}
  \item{TTSW}{Total shoot weight per plant} \item{TTPW}{Total plant weight}
  \item{AVPW}{Average plant weight} \item{ARSR}{Amount of rotted storage root
  per plant} \item{SRDM}{Storage root dry matter} }
}
\usage{
cassava_EC
}
\description{
An example germplasm characterisation data of a subset of IITA Cassava
collection
\insertCite{international_institute_of_tropical_agriculture_cassava_2019}{EvaluateCore}.
Includes data on 26 (out of 62) descriptors for 1684 (out of 2170)
accessions. It is used to demonstrate the various functions of
\code{EvaluateCore} package.
}
\details{
Further details on how the example dataset was built from the original data
is available
\href{https://aravind-j.github.io/EvaluateCore/articles/additional/Example_Core_Data.html}{online}.
}
\examples{

data(cassava_EC)
summary(cassava_EC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

lapply(seq_along(cassava_EC[, qual]),
       function(i) barplot(table(cassava_EC[, qual][, i]),
                           xlab = names(cassava_EC[, qual])[i]))

lapply(seq_along(cassava_EC[, quant]),
       function(i) hist(table(cassava_EC[, quant][, i]),
                        xlab = names(cassava_EC[, quant])[i],
                        main = ""))

}
\references{
\insertAllCited{}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pdfdist.evaluate.core.R
\name{pdfdist.evaluate.core}
\alias{pdfdist.evaluate.core}
\title{Distance Between Probability Distributions}
\usage{
pdfdist.evaluate.core(data, names, quantitative, selected)
}
\arguments{
\item{data}{The data as a data frame object. The data frame should possess
one row per individual and columns with the individual names and multiple
trait/character data.}

\item{names}{Name of column with the individual names as a character string.}

\item{quantitative}{Name of columns with the quantitative traits as a
character vector.}

\item{selected}{Character vector with the names of individuals selected in
core collection and present in the \code{names} column.}
}
\value{
A data frame with the following columns. \item{Trait}{The
  quantitative trait.} \item{Count}{The accession count (excluding missing
  data).} \item{KL_Distance}{The Kullback-Leibler distance
  \insertCite{kullback_information_1951}{EvaluateCore} between EC and CS.}
  \item{KS_Distance}{The Kolmogorov-Smirnov distance
  \insertCite{kolmogorov_sulla_1933,smirnov_table_1948}{EvaluateCore} between
  EC and CS.} \item{KS_pvalue}{The p value of the Kolmogorov-Smirnov
  distance.} \item{AD_Distance}{Anderson-Darling distance
  \insertCite{anderson_asymptotic_1952}{EvaluateCore} between EC and CS.}
  \item{AD_pvalue}{The p value of the Anderson-Darling distance.}
  \item{KS_significance}{The significance of the Kolmogorov-Smirnov distance
  (*: p \mjseqn{\leq} 0.01; **: p \mjseqn{\leq} 0.05; ns: p \mjseqn{>}
  0.05).} \item{AD_pvalue}{The significance of the Anderson-Darling distance
  (*: p \mjseqn{\leq} 0.01; **: p \mjseqn{\leq} 0.05; ns: p \mjseqn{>}
  0.05).}
}
\description{
Compute Kullback-Leibler
\insertCite{kullback_information_1951}{EvaluateCore}, Kolmogorov-Smirnov
\insertCite{kolmogorov_sulla_1933,smirnov_table_1948}{EvaluateCore} and
Anderson-Darling distances
\insertCite{anderson_asymptotic_1952}{EvaluateCore} between the probability
distributions of collection (EC) and core set (CS) for quantitative traits.
}
\examples{

data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

pdfdist.evaluate.core(data = ec, names = "genotypes",
                      quantitative = quant, selected = core)

}
\seealso{
\code{\link[entropy]{KL.plugin}}, \code{\link[stats]{ks.test}},
  \code{\link[kSamples]{ad.test}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dist.evaluate.core.R
\name{dist.evaluate.core}
\alias{dist.evaluate.core}
\title{Distance Measures}
\usage{
dist.evaluate.core(data, names, quantitative, qualitative, selected, d = NULL)
}
\arguments{
\item{data}{The data as a data frame object. The data frame should possess
one row per individual and columns with the individual names and multiple
trait/character data.}

\item{names}{Name of column with the individual names as a character string.}

\item{quantitative}{Name of columns with the quantitative traits as a
character vector.}

\item{qualitative}{Name of columns with the qualitative traits as a character
vector.}

\item{selected}{Character vector with the names of individuals selected in
core collection and present in the \code{names} column.}

\item{d}{A distance matrix of class "\code{dist}" with individual names in
the \code{names} column in \code{data} as labels. If \code{NULL} (default),
then a distance matrix is computed using Gower's metric.
\insertCite{gower_general_1971}{EvaluateCore}.}
}
\value{
A data frame with the average values of
\mjteqn{E\textrm{-}EN}{E\text{-}EN}{E-EN},
\mjteqn{A\textrm{-}EN}{E\text{-}EN}{A-EN} and
\mjteqn{E\textrm{-}E}{E\text{-}EN}{E-E}.
}
\description{
Compute average Entry-to-nearest-entry distance
(\mjteqn{E\textrm{-}EN}{E\text{-}EN}{E-EN}),
Accession-to-nearest-entry distance
(\mjteqn{A\textrm{-}EN}{E\text{-}EN}{A-EN}) and
Entry-to-entry distance (\mjteqn{E\textrm{-}E}{E\text{-}EN}{E-E})
\insertCite{odong_quality_2013}{EvaluateCore}
to evaluate a core set (CS) selected from an entire collection (EC).
}
\examples{

data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

dist.evaluate.core(data = ec, names = "genotypes", quantitative = quant,
                   qualitative = qual, selected = core)

\donttest{
####################################
# Compare with corehunter
####################################

library(corehunter)
# Prepare phenotype dataset
dtype <- c(rep("RD", length(quant)),
           rep("NS", length(qual)))
rownames(ec) <- ec[, "genotypes"]
ecdata <- corehunter::phenotypes(data = ec[, c(quant, qual)],
                                 types = dtype)

# Compute average distances
EN <- evaluateCore(core = rownames(cassava_CC), data = ecdata,
                   objective = objective("EN", "GD"))
AN <- evaluateCore(core = rownames(cassava_CC), data = ecdata,
                   objective = objective("AN", "GD"))
EE <- evaluateCore(core = rownames(cassava_CC), data = ecdata,
                   objective = objective("EE", "GD"))
EN
AN
EE
}

}
\references{
\insertAllCited{}
}
\seealso{
\code{\link[corehunter]{evaluateCore}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/snk.evaluate.core.R
\name{snk.evaluate.core}
\alias{snk.evaluate.core}
\title{Student-Newman-Keuls Test}
\usage{
snk.evaluate.core(data, names, quantitative, selected)
}
\arguments{
\item{data}{The data as a data frame object. The data frame should possess
one row per individual and columns with the individual names and multiple
trait/character data.}

\item{names}{Name of column with the individual names as a character string.}

\item{quantitative}{Name of columns with the quantitative traits as a
character vector.}

\item{selected}{Character vector with the names of individuals selected in
core collection and present in the \code{names} column.}
}
\value{
A data frame with the following components. \item{Trait}{The
  quantitative trait.} \item{Count}{The accession count (excluding missing
  data).} \item{Df}{The degrees of freedom for the test.} \item{EC_Min}{The
  minimum value of the trait in EC.} \item{EC_Max}{The maximum value of the
  trait in EC.} \item{EC_Mean}{The mean value of the trait in EC.}
  \item{EC_SE}{The standard error of the trait in EC.} \item{CS_Min}{The
  minimum value of the trait in CS.} \item{CS_Max}{The maximum value of the
  trait in CS.} \item{CS_Mean}{The mean value of the trait in CS.}
  \item{CS_SE}{The standard error of the trait in CS.} \item{SNK_pvalue}{The
  p value of the Student-Newman-Keuls test for equality of means of EC and
  CS.} \item{SNK_significance}{The significance of the Student-Newman-Keuls
  test for equality of means of EC and CS.}
}
\description{
Test difference between means of entire collection (EC) and core set (CS) for
quantitative traits by Newman-Keuls or Student-Newman-Keuls test
\insertCite{newman_distribution_1939,keuls_use_1952}{EvaluateCore}.
}
\examples{

data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

snk.evaluate.core(data = ec, names = "genotypes",
                  quantitative = quant, selected = core)

}
\references{
\insertAllCited{}
}
\seealso{
\code{\link[agricolae]{SNK.test}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/levene.evaluate.core.R
\name{levene.evaluate.core}
\alias{levene.evaluate.core}
\title{Levene's Test}
\usage{
levene.evaluate.core(data, names, quantitative, selected)
}
\arguments{
\item{data}{The data as a data frame object. The data frame should possess
one row per individual and columns with the individual names and multiple
trait/character data.}

\item{names}{Name of column with the individual names as a character string.}

\item{quantitative}{Name of columns with the quantitative traits as a
character vector.}

\item{selected}{Character vector with the names of individuals selected in
core collection and present in the \code{names} column.}
}
\value{
A data frame with the following columns \item{Trait}{The quantitative
  trait.} \item{Count}{The accession count (excluding missing data).}
  \item{Df}{The degrees of freedom for the test.} \item{EC_V}{The variance of
  the EC.} \item{CS_V}{The variance of the CS.} \item{EC_CV}{The coefficient
  of variance of the EC.} \item{CS_CV}{The coefficient of variance of the
  CS.} \item{Levene_Fvalue}{The test statistic.} \item{Levene_pvalue}{The p
  value for the test statistic.} \item{Levene_significance}{The significance
  of the test statistic (*: p \mjseqn{\leq} 0.01; **: p \mjseqn{\leq} 0.05;
  ns: p \mjseqn{ > } 0.05).}
}
\description{
Test for  of variances of the entire collection (EC) and core set (CS) for
quantitative traits by Levene's test
\insertCite{levene_robust_1960}{EvaluateCore}.
}
\examples{

data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

levene.evaluate.core(data = ec, names = "genotypes",
                     quantitative = quant, selected = core)

}
\references{
\insertAllCited{}
}
\seealso{
\code{\link[car]{leveneTest}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/freqdist.evaluate.core.R
\name{freqdist.evaluate.core}
\alias{freqdist.evaluate.core}
\title{Frequency Distribution Histogram}
\usage{
freqdist.evaluate.core(
  data,
  names,
  quantitative,
  qualitative,
  selected,
  highlight = NULL,
  include.highlight = TRUE,
  highlight.se = NULL,
  highlight.col = "red",
  show.count = FALSE
)
}
\arguments{
\item{data}{The data as a data frame object. The data frame should possess
one row per individual and columns with the individual names and multiple
trait/character data.}

\item{names}{Name of column with the individual names as a character string.}

\item{quantitative}{Name of columns with the quantitative traits as a
character vector.}

\item{qualitative}{Name of columns with the qualitative traits as a character
vector.}

\item{selected}{Character vector with the names of individuals selected in
core collection and present in the \code{names} column.}

\item{highlight}{Individual names to be highlighted as a character vector.}

\item{include.highlight}{If \code{TRUE}, the highlighted individuals are
included in the frequency distribution histogram. Default is \code{TRUE}.}

\item{highlight.se}{Optional data frame of standard errors for the
individuals specified in \code{highlight}. It should have the same column
names as in \code{data}.}

\item{highlight.col}{The colour(s) to be used to highlighting individuals in
the plot as a character vector of the same length as \code{highlight}. Must
be valid colour values in R (named colours, hexadecimal representation,
index of colours [\code{1:8}] in default R \code{palette()} etc.).}

\item{show.count}{logical. If \code{TRUE}, the accession count excluding
missing values will also be displayed. Default is \code{FALSE}.}
}
\value{
A list with the \code{ggplot} objects of stacked frequency
  distribution histograms plots for each trait specified as
  \code{quantitative} and \code{qualitative}.
}
\description{
Plot stacked frequency distribution histogram to graphically compare the
probability distributions of traits between entire collection (EC) and core
set (CS).
}
\examples{

data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

\donttest{
freqdist.evaluate.core(data = ec, names = "genotypes",
                       quantitative = quant, qualitative = qual,
                       selected = core)

checks <- c("TMe-1199", "TMe-1957", "TMe-3596", "TMe-3392")

freqdist.evaluate.core(data = ec, names = "genotypes",
                       quantitative = quant, qualitative = qual,
                       selected = core,
                       highlight = checks, highlight.col = "red")

quant.se <- data.frame(genotypes = checks,
                       NMSR = c(0.107, 0.099, 0.106, 0.062),
                       TTRN = c(0.081, 0.072, 0.057, 0.049),
                       TFWSR = c(0.089, 0.031, 0.092, 0.097),
                       TTRW = c(0.064, 0.031, 0.071, 0.071),
                       TFWSS = c(0.106, 0.071, 0.121, 0.066),
                       TTSW = c(0.084, 0.045, 0.066, 0.054),
                       TTPW = c(0.098, 0.052, 0.111, 0.082),
                       AVPW = c(0.074, 0.038, 0.054, 0.061),
                       ARSR = c(0.104, 0.019, 0.204, 0.044),
                       SRDM = c(0.078, 0.138, 0.076, 0.079))

freqdist.evaluate.core(data = ec, names = "genotypes",
                       quantitative = quant,
                       selected = core,
                       highlight = checks, highlight.col = "red",
                       highlight.se = quant.se)

freqdist.evaluate.core(data = ec, names = "genotypes",
                       quantitative = quant, qualitative = qual,
                       selected = core,
                       highlight = checks, highlight.col = "red",
                       show.count = TRUE)
}

}
\seealso{
\code{\link[graphics]{hist}}, \code{\link[ggplot2]{geom_histogram}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/percentdiff.evaluate.core.R
\name{percentdiff.evaluate.core}
\alias{percentdiff.evaluate.core}
\title{Percentage Difference of Means and Variances}
\usage{
percentdiff.evaluate.core(
  data,
  names,
  quantitative,
  selected,
  alpha = 0.05,
  rr.crit = 0.7
)
}
\arguments{
\item{data}{The data as a data frame object. The data frame should possess
one row per individual and columns with the individual names and multiple
trait/character data.}

\item{names}{Name of column with the individual names as a character string.}

\item{quantitative}{Name of columns with the quantitative traits as a
character vector.}

\item{selected}{Character vector with the names of individuals selected in
core collection and present in the \code{names} column.}

\item{alpha}{Type I error probability (Significance level) of difference.}

\item{rr.crit}{The critical value of range ratio considered to be acceptable
for a representative CS. The default value is 0.7.}
}
\value{
A data frame with the values of
  \mjteqn{MD\\\%_{Hu}}{MD\\\\\\\%_{Hu}}{MD\%_{Hu}},
  \mjteqn{VD\\\%_{Hu}}{VD\\\\\\\%_{Hu}}{VD\%_{Hu}},
  \mjteqn{MD\\\%_{Kim}}{MD\\\\\\\%_{Kim}}{MD\%_{Kim}},
  \mjteqn{VD\\\%_{Kim}}{VD\\\\\\\%_{Kim}}{VD\%_{Kim}} and
  \mjteqn{\overline{d}D\\\%}{\overline{d}D\\\\\\\%}{\overline{d}D\%}.
}
\description{
Compute the following differences between the entire collection (EC) and core
set (CS). \itemize{ \item Percentage of significant differences of mean
(\mjteqn{MD\\\%_{Hu}}{MD\\\\\\\%_{Hu}}{MD\%_{Hu}})
\insertCite{hu_methods_2000}{EvaluateCore} \item Percentage of significant
differences of variance (\mjteqn{VD\\\%_{Hu}}{VD\\\\\\\%_{Hu}}{VD\%_{Hu}})
\insertCite{hu_methods_2000}{EvaluateCore} \item Average of absolute
differences between means
(\mjteqn{MD\\\%_{Kim}}{MD\\\\\\\%_{Kim}}{MD\%_{Kim}})
\insertCite{kim_PowerCore_2007}{EvaluateCore} \item Average of absolute
differences between variances
(\mjteqn{VD\\\%_{Kim}}{VD\\\\\\\%_{Kim}}{VD\%_{Kim}})
\insertCite{kim_PowerCore_2007}{EvaluateCore} \item Percentage difference
between the mean squared Euclidean distance among accessions
(\mjteqn{\overline{d}D\\\%}{\overline{d}D\\\\\\\%}{\overline{d}D\%})
\insertCite{studnicki_comparing_2013}{EvaluateCore} \item Percentage of range
ratios smaller than 0.70 (\mjseqn{S_{RR_{0.7}}})
\insertCite{diwan_methods_1995}{EvaluateCore} }
}
\details{
The differences are computed as follows.

\mjtdeqn{MD\\\%_{Hu} = \left ( \frac{S_{t}}{n} \right ) \times
100}{MD\\\\\\\%_{Hu} = \left ( \frac{S_{t}}{n} \right ) \times 100}{MD\%_{Hu}
= \left ( \frac{S_{t}}{n} \right ) \times 100}

Where, \mjseqn{S_{t}} is the number of traits with a significant difference
between the means of the EC and the CS and \mjseqn{n} is the total number of
traits. A representative core should have
\mjteqn{MD\\\%_{Hu}}{MD\\\\\\\%_{Hu}}{MD\%_{Hu}} < 20 \% and \mjseqn{CR} > 80
\% \insertCite{hu_methods_2000}{EvaluateCore}.

\mjtdeqn{VD\\\%_{Hu} = \left ( \frac{S_{F}}{n} \right ) \times
100}{VD\\\\\\\%_{Hu} = \left ( \frac{S_{F}}{n} \right ) \times 100}{VD\%_{Hu}
= \left ( \frac{S_{F}}{n} \right ) \times 100}

Where, \mjseqn{S_{F}} is the number of traits with a significant difference
between the variances of the EC and the CS and \mjseqn{n} is the total number
of traits. Larger \mjteqn{VD\\\%_{Hu}}{VD\\\\\\\%_{Hu}}{VD\%_{Hu}} value
indicates a more diverse core set.

\mjtdeqn{MD\\\%_{Kim} = \left ( \frac{1}{n}\sum_{i=1}^{n} \frac{\left |
M_{EC_{i}}-M_{CS_{i}} \right |}{M_{CS_{i}}} \right ) \times
100}{MD\\\\\\\%_{Kim} = \left ( \frac{1}{n}\sum_{i=1}^{n} \frac{\left |
M_{EC_{i}}-M_{CS_{i}} \right |}{M_{CS_{i}}} \right ) \times 100}{MD\%_{Kim} =
\left ( \frac{1}{n}\sum_{i=1}^{n} \frac{\left | M_{EC_{i}}-M_{CS_{i}} \right
|}{M_{CS_{i}}} \right ) \times 100}

Where, \mjseqn{M_{EC_{i}}} is the mean of the EC for the \mjseqn{i}th trait,
\mjseqn{M_{CS_{i}}} is the mean of the CS for the \mjseqn{i}th trait and
\mjseqn{n} is the total number of traits.

\mjtdeqn{VD\\\%_{Kim} = \left ( \frac{1}{n}\sum_{i=1}^{n} \frac{\left |
V_{EC_{i}}-V_{CS_{i}} \right |}{V_{CS_{i}}} \right ) \times
100}{VD\\\\\\\%_{Kim} = \left ( \frac{1}{n}\sum_{i=1}^{n} \frac{\left |
V_{EC_{i}}-V_{CS_{i}} \right |}{V_{CS_{i}}} \right ) \times 100}{VD\%_{Kim} =
\left ( \frac{1}{n}\sum_{i=1}^{n} \frac{\left | V_{EC_{i}}-V_{CS_{i}} \right
|}{V_{CS_{i}}} \right ) \times 100}

Where, \mjseqn{V_{EC_{i}}} is the variance of the EC for the \mjseqn{i}th
trait, \mjseqn{V_{CS_{i}}} is the variance of the CS for the \mjseqn{i}th
trait and \mjseqn{n} is the total number of traits.

\mjtdeqn{\overline{d}D\\\% =
\frac{\overline{d}_{CS}-\overline{d}_{EC}}{\overline{d}_{EC}} \times
100}{\overline{d}D\\\\\\\% =
\frac{\overline{d}_{CS}-\overline{d}_{EC}}{\overline{d}_{EC}} \times
100}{\overline{d}D\\% =
\frac{\overline{d}_{CS}-\overline{d}_{EC}}{\overline{d}_{EC}} \times 100}

Where, \mjseqn{\overline{d}_{CS}} is the mean squared Euclidean distance
among accessions in the CS and \mjseqn{\overline{d}_{EC}} is the mean squared
Euclidean distance among accessions in the EC.

Percentage of range ratios smaller than 0.70
\insertCite{diwan_methods_1995}{EvaluateCore} is computed as follows.

\mjtdeqn{RR\\\%_{0.7} = \left ( \frac{S_{RR_{0.7}}}{n} \right ) \times
100}{RR\\\\\\\%_{0.7} = \left ( \frac{S_{RR_{0.7}}}{n} \right ) \times
100}{RR\%_{0.7} = \left ( \frac{S_{RR_{0.7}}}{n} \right ) \times 100}

Where, \mjseqn{S_{RR_{0.7}}} is the number of traits with a range ratio
smaller than 0.7 (\mjteqn{\frac{R_{CS_{i}}}{R_{EC_{i}}} <
0.7}{\frac{R_{CS_{i}}}{R_{EC_{i}}} &lt; 0.7}{(R_CS_i / R_EC_i) < 0.7}).
\mjseqn{R_{CS_{i}}} is the range of the \mjseqn{i}th trait in the CS,
\mjseqn{R_{EC_{i}}} is the range of the \mjseqn{i}th trait in the EC and
\mjseqn{n} is the total number of traits.
}
\examples{

data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

percentdiff.evaluate.core(data = ec, names = "genotypes",
                          quantitative = quant, selected = core)

}
\references{
\insertAllCited{}
}
\seealso{
\code{\link[EvaluateCore]{snk.evaluate.core}},
  \code{\link[EvaluateCore]{snk.evaluate.core}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cr.evaluate.core.R
\name{cr.evaluate.core}
\alias{cr.evaluate.core}
\title{Coincidence Rate of Range}
\usage{
cr.evaluate.core(data, names, quantitative, selected)
}
\arguments{
\item{data}{The data as a data frame object. The data frame should possess
one row per individual and columns with the individual names and multiple
trait/character data.}

\item{names}{Name of column with the individual names as a character string.}

\item{quantitative}{Name of columns with the quantitative traits as a
character vector.}

\item{selected}{Character vector with the names of individuals selected in
core collection and present in the \code{names} column.}
}
\value{
The \mjseqn{CR} value.
}
\description{
Compute the following metrics to compare quantitative traits of the entire
collection (EC) and core set (CS). \itemize{\item{Coincidence Rate of Range
(\mjseqn{CR}) \insertCite{hu_methods_2000}{EvaluateCore} (originally
described by \insertCite{diwan_methods_1995}{EvaluateCore} as Mean range
ratio)} \item{Changeable Rate of Maximum (\mjseqn{CR_{\max}})
\insertCite{wang_assessment_2007}{EvaluateCore}} \item{Changeable Rate of
Minimum (\mjseqn{CR_{\min}}) \insertCite{wang_assessment_2007}{EvaluateCore}}
\item{Changeable Rate of Mean (\mjseqn{CR_{\mu}})
\insertCite{wang_assessment_2007}{EvaluateCore}} }
}
\details{
The Coincidence Rate of Range (\mjseqn{CR}) is computed as follows.

\mjsdeqn{CR = \left ( \frac{1}{n} \sum_{i=1}^{n}
\frac{R_{CS_{i}}}{R_{EC_{i}}} \right ) \times 100}

Where, \mjseqn{R_{CS_{i}}} is the range of the \mjseqn{i}th trait in the CS,
\mjseqn{R_{EC_{i}}} is the range of the \mjseqn{i}th trait in the EC and
\mjseqn{n} is the total number of traits.

A representative CS should have a \mjseqn{CR} value no less than 70\%
\insertCite{diwan_methods_1995}{EvaluateCore} or 80\%
\insertCite{hu_methods_2000}{EvaluateCore}.

The Changeable Rate of Maximum (\mjseqn{CR_{\max}}) is computed as follows.

\mjsdeqn{CR_{\max} = \left ( \frac{1}{n} \sum_{i=1}^{n}
\frac{\max_{CS_{i}}}{\max_{EC_{i}}} \right ) \times 100}

Where, \mjseqn{\max_{CS_{i}}} is the maximum value of the \mjseqn{i}th trait
in the CS, \mjseqn{\max_{EC_{i}}} is the maximum value of the \mjseqn{i}th
trait in the EC and \mjseqn{n} is the total number of traits.

The Changeable Rate of Minimum (\mjseqn{CR_{\min}}) is computed as follows.

\mjsdeqn{CR_{\min} = \left ( \frac{1}{n} \sum_{i=1}^{n}
\frac{\min_{CS_{i}}}{\min_{EC_{i}}} \right ) \times 100}

Where, \mjseqn{\min_{CS_{i}}} is the minimum value of the \mjseqn{i}th trait
in the CS, \mjseqn{\min_{EC_{i}}} is the minimum value of the \mjseqn{i}th
trait in the EC and \mjseqn{n} is the total number of traits.

The Changeable Rate of Mean (\mjseqn{CR_{\mu}}) is computed as follows.

\mjsdeqn{CR_{\mu} = \left ( \frac{1}{n} \sum_{i=1}^{n}
\frac{\mu_{CS_{i}}}{\mu_{EC_{i}}} \right ) \times 100}

Where, \mjseqn{\mu_{CS_{i}}} is the mean value of the \mjseqn{i}th trait in
the CS, \mjseqn{\mu_{EC_{i}}} is the mean value of the \mjseqn{i}th trait in
the EC and \mjseqn{n} is the total number of traits.
}
\note{
\code{NaN} or \code{Inf} values for \mjseqn{CR_{\min}} occurs when the
  minimum values for some of the traits are zero.
}
\examples{

data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

cr.evaluate.core(data = ec, names = "genotypes",
                 quantitative = quant, selected = core)

}
\references{
\insertAllCited{}
}
\seealso{
\code{\link[stats]{wilcox.test}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/checks.evaluate.core.R
\name{checks.evaluate.core}
\alias{checks.evaluate.core}
\title{Common checks for all functions}
\usage{
checks.evaluate.core(
  data,
  names,
  quantitative = NULL,
  qualitative = NULL,
  selected
)
}
\arguments{
\item{data}{The data as a data frame object. The data frame should possess
one row per individual and columns with the individual names and multiple
trait/character data.}

\item{names}{Name of column with the individual names as a character string.}

\item{quantitative}{Name of columns with the quantitative traits as a
character vector.}

\item{qualitative}{Name of columns with the qualitative traits as a character
vector.}

\item{selected}{Character vector with the names of individuals selected in
core collection and present in the \code{names} column.}
}
\description{
Not exported. Strictly internal
}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/chisquare.evalueate.core.R
\name{chisquare.evaluate.core}
\alias{chisquare.evaluate.core}
\title{Chi-squared Test for Homogeneity}
\usage{
chisquare.evaluate.core(data, names, qualitative, selected, na.omit = TRUE)
}
\arguments{
\item{data}{The data as a data frame object. The data frame should possess
one row per individual and columns with the individual names and multiple
trait/character data.}

\item{names}{Name of column with the individual names as a character string.}

\item{qualitative}{Name of columns with the qualitative traits as a character
vector.}

\item{selected}{Character vector with the names of individuals selected in
core collection and present in the \code{names} column.}

\item{na.omit}{logical. If \code{TRUE}, missing values (\code{NA}) are
ignored and not included as a distinct factor level for analysis. Default
is \code{TRUE}.}
}
\value{
A a data frame with the following columns. \item{Trait}{The
  qualitative trait.} \item{EC_No.Classes}{The number of classes in the trait
  for EC.} \item{EC_Classes}{The frequency of the classes in the trait for
  EC.} \item{CS_No.Classes}{The number of classes in the trait for CS.}
  \item{CS_Classes}{The frequency of the classes in the trait for CS.}
  \item{chisq_statistic}{The \mjseqn{\chi^{2}} test statistic.}
  \item{chisq_pvalue}{The p value for the test statistic.}
  \item{chisq_significance}{The significance of the test statistic (*: p
  \mjseqn{\leq} 0.01; **: p \mjseqn{\leq} 0.05; ns: p \mjseqn{ > } 0.05).}
}
\description{
Compare the distribution frequencies of qualitative traits between entire
collection (EC) and core set (CS) by Chi-squared test for homogeneity
\insertCite{pearson_x._1900,snedecor_chi-square_1933}{EvaluateCore}.
\loadmathjax
}
\examples{

data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

chisquare.evaluate.core(data = ec, names = "genotypes",
                        qualitative = qual, selected = core)

}
\references{
\insertAllCited{}
}
\seealso{
\code{\link[stats]{chisq.test}}
}
